@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: d3366b32e2b4e34a4669d6f7c936012bd53cec64 $
 
 #include "Database.h"
 
@@ -792,7 +791,7 @@ int Database::registerSimpleTable(const std::string & name,
                 createquery += " text";
             } else {
                 char buf[32];
-                snprintf(buf, 32, "%d", size);
+                snprintf(buf, 32, "%zd", size);
                 createquery += " varchar(";
                 createquery += buf;
                 createquery += ")";
@@ -1018,13 +1017,26 @@ int Database::insertEntity(const std::string & id,
 
 int Database::updateEntity(const std::string & id,
                            int seq,
-                           const std::string & value)
+                           const std::string & location_data,
+                           const std::string & location_entity_id)
 {
-    std::string query = compose("UPDATE entities SET seq = %1, location = '%2'"
-                                " WHERE id = %3", seq, value, id);
+    std::string query = compose("UPDATE entities SET seq = %1, location = '%2',"
+                                " loc = '%3'"
+                                " WHERE id = %4", seq, location_data,
+                                location_entity_id, id);
     return scheduleCommand(query);
 }
 
+int Database::updateEntityWithoutLoc(const std::string & id,
+                 int seq,
+                 const std::string & location_data)
+{
+    std::string query = compose("UPDATE entities SET seq = %1, location = '%2'"
+                                " WHERE id = %3", seq, location_data, id);
+    return scheduleCommand(query);
+}
+
+
 const DatabaseResult Database::selectEntities(const std::string & loc)
 {
     std::string query = compose("SELECT id, type, seq, location FROM entities"
@@ -1045,6 +1057,10 @@ int Database::dropEntity(long id)
 
     scheduleCommand(query);
 
+    query = compose("DELETE FROM thoughts WHERE id = %1", id);
+
+    scheduleCommand(query);
+
     return 0;
 }
 
@@ -1129,6 +1145,64 @@ int Database::updateProperties(const std::string & id,
     return 0;
 }
 
+int Database::registerThoughtsTable()
+{
+    assert(m_connection != 0);
+
+    clearPendingQuery();
+    int status = PQsendQuery(m_connection, "SELECT * FROM thoughts");
+    if (!status) {
+        log(ERROR, "registerThoughtsTable(): Database query error.");
+        reportError();
+        return -1;
+    }
+    if (!tuplesOk()) {
+        debug(reportError(););
+        debug(std::cout << "Table does not yet exist"
+                        << std::endl << std::flush;);
+    } else {
+        allTables.insert("thoughts");
+        debug(std::cout << "Table exists" << std::endl << std::flush;);
+        return 0;
+    }
+    allTables.insert("properties");
+    std::string query = "CREATE TABLE thoughts ("
+                        "id integer REFERENCES entities "
+                        "ON DELETE CASCADE, "
+                        "thought text)";
+    if (runCommandQuery(query) != 0) {
+        reportError();
+        return -1;
+    }
+    return 0;
+}
+
+const DatabaseResult Database::selectThoughts(const std::string & loc)
+{
+    std::string query = compose("SELECT thought FROM thoughts"
+                                " WHERE id = %1", loc);
+
+    debug(std::cout << "Selecting on id = " << loc << " ... "
+                    << std::endl << std::flush;);
+
+    return runSimpleSelectQuery(query);
+}
+
+int Database::replaceThoughts(const std::string & id,
+                         const std::vector<std::string>& thoughts)
+{
+
+    std::string deleteQuery = compose("DELETE FROM thoughts WHERE id=%1", id);
+    scheduleCommand(deleteQuery);
+
+    for (auto& thought : thoughts) {
+        std::string insertQuery = compose("INSERT INTO thoughts (id, thought)"
+                                          " VALUES (%1, '%2')", id, thought);
+        scheduleCommand(insertQuery);
+    }
+    return 0;
+}
+
 #if 0
 // Interface for tables for sparse sequences or arrays of data. Terrain
 // control points and other spatial data.
@@ -1499,73 +1573,73 @@ int Database::runMaintainance(int command)
 
 const char * DatabaseResult::field(const char * column, int row) const
 {
-    int col_num = PQfnumber(m_res, column);
+    int col_num = PQfnumber(m_res.get(), column);
     if (col_num == -1) {
         return "";
     }
-    return PQgetvalue(m_res, row, col_num);
+    return PQgetvalue(m_res.get(), row, col_num);
 }
 
 const char * DatabaseResult::const_iterator::column(const char * column) const
 {
-    int col_num = PQfnumber(m_dr.m_res, column);
+    int col_num = PQfnumber(m_dr.m_res.get(), column);
     if (col_num == -1) {
         return "";
     }
-    return PQgetvalue(m_dr.m_res, m_row, col_num);
+    return PQgetvalue(m_dr.m_res.get(), m_row, col_num);
 }
 
 void DatabaseResult::const_iterator::readColumn(const char * column,
                                                 int & val) const
 {
-    int col_num = PQfnumber(m_dr.m_res, column);
+    int col_num = PQfnumber(m_dr.m_res.get(), column);
     if (col_num == -1) {
         return;
     }
-    const char * v = PQgetvalue(m_dr.m_res, m_row, col_num);
+    const char * v = PQgetvalue(m_dr.m_res.get(), m_row, col_num);
     val = strtol(v, 0, 10);
 }
 
 void DatabaseResult::const_iterator::readColumn(const char * column,
                                                 float & val) const
 {
-    int col_num = PQfnumber(m_dr.m_res, column);
+    int col_num = PQfnumber(m_dr.m_res.get(), column);
     if (col_num == -1) {
         return;
     }
-    const char * v = PQgetvalue(m_dr.m_res, m_row, col_num);
+    const char * v = PQgetvalue(m_dr.m_res.get(), m_row, col_num);
     val = strtof(v, 0);
 }
 
 void DatabaseResult::const_iterator::readColumn(const char * column,
                                                 double & val) const
 {
-    int col_num = PQfnumber(m_dr.m_res, column);
+    int col_num = PQfnumber(m_dr.m_res.get(), column);
     if (col_num == -1) {
         return;
     }
-    const char * v = PQgetvalue(m_dr.m_res, m_row, col_num);
+    const char * v = PQgetvalue(m_dr.m_res.get(), m_row, col_num);
     val = strtod(v, 0);
 }
 
 void DatabaseResult::const_iterator::readColumn(const char * column,
                                                 std::string & val) const
 {
-    int col_num = PQfnumber(m_dr.m_res, column);
+    int col_num = PQfnumber(m_dr.m_res.get(), column);
     if (col_num == -1) {
         return;
     }
-    const char * v = PQgetvalue(m_dr.m_res, m_row, col_num);
+    const char * v = PQgetvalue(m_dr.m_res.get(), m_row, col_num);
     val = v;
 }
 
 void DatabaseResult::const_iterator::readColumn(const char * column,
                                                 MapType & val) const
 {
-    int col_num = PQfnumber(m_dr.m_res, column);
+    int col_num = PQfnumber(m_dr.m_res.get(), column);
     if (col_num == -1) {
         return;
     }
-    const char * v = PQgetvalue(m_dr.m_res, m_row, col_num);
+    const char * v = PQgetvalue(m_dr.m_res.get(), m_row, col_num);
     Database::instance()->decodeMessage(v, val);
 }
