@@ -15,24 +15,19 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 34de8a2b5b34b729bfbbbfe1e9184cd7c8ca6041 $
 
 #ifndef COMMON_OPERATION_ROUTER_H
 #define COMMON_OPERATION_ROUTER_H
 
 #include <Atlas/Objects/ObjectsFwd.h>
 
-#include <map>
 #include <vector>
 
 #define OP_INVALID (-1)
 
-class Entity;
-
 typedef Atlas::Objects::Operation::RootOperation Operation;
 
 typedef std::vector<Operation> OpVector;
-typedef int OpNo;
 
 typedef enum {
     OPERATION_BLOCKED, // Handler has determined that op should stop here
@@ -40,7 +35,4 @@ typedef enum {
     OPERATION_IGNORED, // Handler has done nothing
 } HandlerResult;
 
-typedef HandlerResult (*Handler)(Entity *, const Operation &, OpVector &);
-typedef std::map<int, Handler> HandlerMap;
-
 #endif // COMMON_OPERATION_ROUTER_H
