@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: cb3ac30755e962b18e121b1b79d35f061ac65350 $
 
 #ifndef COMMON_PROPERTY_FACTORY_IMPL_H
 #define COMMON_PROPERTY_FACTORY_IMPL_H
@@ -28,4 +27,10 @@ PropertyBase * PropertyFactory<T>::newProperty()
     return new T();
 }
 
+template <class T>
+PropertyFactory<T> * PropertyFactory<T>::duplicateFactory() const
+{
+    return new PropertyFactory<T>;
+}
+
 #endif // COMMON_PROPERTY_FACTORY_IMPL_H
