@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: fbc407c0c9d97110ff4fe1f1038f26ac77e43f80 $
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -25,8 +24,6 @@
 
 namespace consts {
 
-  // Admin password used by admin account
-  const char * defaultAdminPasswordHash = "$1$1A67C3C65EECBBCE$A51127573498DCB08992378D07A36A20";
   // Id of root world entity
   const char * rootWorldId = "0";
   // Integer id of root world entity
