@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: fb4345bb9a7aa362989590ccb30dab83cb33ba5e $
 
 #ifndef COMMON_CUSTOM_H
 #define COMMON_CUSTOM_H
@@ -39,6 +38,9 @@ extern int TICK_NO;
 extern int UNSEEN_NO;
 extern int UPDATE_NO;
 extern int TELEPORT_NO;
+extern int COMMUNE_NO;
+extern int THINK_NO;
+extern int RELAY_NO;
 
 } } }
 
