@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 5de55c05e83f79e0ee7e5f909ad4233f0445f916 $
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -54,7 +53,12 @@ std::string share_directory(DATADIR);
 std::string etc_directory(SYSCONFDIR);
 std::string var_directory(LOCALSTATEDIR);
 std::string ruleset_name(DEFAULT_RULESET);
+std::string server_uuid("");
+std::string server_key("");
+
 bool exit_flag = false;
+bool exit_flag_soft = false;
+bool exit_soft_enabled = false;
 bool daemon_flag = false;
 bool database_flag = true;
 int timeoffset = SPM * MPH * 9; // Morning
