@@ -15,11 +15,10 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 5fadb38e1d522e7743645bd3b1f05fca15136a76 $
 
 #include "EntityRef.h"
 
-#include "rulesets/Entity.h"
+#include "rulesets/LocatedEntity.h"
 
 #include <sigc++/slot.h>
 
@@ -30,7 +29,7 @@ void EntityRef::setup()
     }
 }
 
-EntityRef::EntityRef(Entity* e) : m_inner(e)
+EntityRef::EntityRef(LocatedEntity* e) : m_inner(e)
 {
     setup();
 }
