@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: a05c4238f1e65029f0bb242296fbeee74c3d61e4 $
 
 #include "modules/TerrainContext.h"
 
@@ -23,7 +22,7 @@ TerrainContext::TerrainContext()
 {
 }
 
-TerrainContext::TerrainContext(Entity * e) : m_entity(e)
+TerrainContext::TerrainContext(LocatedEntity * e) : m_entity(e)
 {
 }
 
