@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 1a43ec337451d3b123a26ba7519ffa275c27309b $
 
 #ifndef MODULES_TERRAIN_CONTEXT_H
 #define MODULES_TERRAIN_CONTEXT_H
@@ -32,7 +31,7 @@ class TerrainContext : public Mercator::Effector::Context
   public:
     TerrainContext();
 
-    explicit TerrainContext(Entity*);
+    explicit TerrainContext(LocatedEntity*);
 
     virtual ~TerrainContext();
 
