@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: cccd1d018cab1f2d5193d8bcbce005732af1d10e $
 
 #ifndef RULESETS_AREA_PROPERTY_H
 #define RULESETS_AREA_PROPERTY_H
@@ -31,15 +30,21 @@ class AreaProperty : public TerrainEffectorProperty {
   protected:
     int m_layer;
     Form<2> * m_shape;
+
+    AreaProperty(const AreaProperty &);
+    // Assignment isn't banned, but it's gotta be implemented before it'll
+    // work. Default should not be used.
+    AreaProperty & operator=(const AreaProperty &) = delete;
   public:
     explicit AreaProperty();
     virtual ~AreaProperty();
 
     const Form<2> * shape() const { return m_shape; }
 
-    virtual void apply(Entity *);
+    virtual void apply(LocatedEntity *);
 
     virtual void set(const Atlas::Message::Element & val);
+    virtual AreaProperty * copy() const;
 };
 
 #endif // RULESETS_AREA_PROPERTY_H
