@@ -15,13 +15,12 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 8c4991f4a2fe05eb4ff5b0fe778687b3604470d4 $
 
 #ifndef RULESETS_ARITHMETIC_FACTORY_H
 #define RULESETS_ARITHMETIC_FACTORY_H
 
 class ArithmeticScript;
-class Entity;
+class LocatedEntity;
 
 /// \brief Base class for for factories for creating arithmetic scripts
 class ArithmeticKit {
@@ -31,7 +30,7 @@ class ArithmeticKit {
     /// \brief Create a new arithmetic model object
     ///
     /// @param chr The Character object for which the model should be created
-    virtual ArithmeticScript * newScript(Entity * owner) = 0;
+    virtual ArithmeticScript * newScript(LocatedEntity * owner) = 0;
 };
 
 #endif // RULESETS_ARITHMETIC_FACTORY_H
