@@ -15,23 +15,26 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 3d9028eea13acf90d58bc07ae0a2ffe55be2923d $
 
 #include "Character.h"
 
 #include "Pedestrian.h"
 #include "BaseMind.h"
 #include "EntityProperty.h"
+#include "ExternalMind.h"
+#include "ExternalProperty.h"
 #include "OutfitProperty.h"
 #include "StatusProperty.h"
 #include "TasksProperty.h"
 
+#include "common/BaseWorld.h"
 #include "common/op_switch.h"
 #include "common/const.h"
 #include "common/custom.h"
 #include "common/debug.h"
 #include "common/globals.h"
 #include "common/log.h"
+#include "common/Link.h"
 #include "common/TypeNode.h"
 #include "common/serialno.h"
 #include "common/compose.hpp"
@@ -51,6 +54,7 @@
 #include <Atlas/Objects/Anonymous.h>
 
 #include <sigc++/functors/mem_fun.h>
+#include <sigc++/adaptors/hide.h>
 
 #include <cassert>
 
@@ -58,6 +62,7 @@ using Atlas::Message::Element;
 using Atlas::Message::ListType;
 using Atlas::Message::MapType;
 using Atlas::Objects::Root;
+using Atlas::Objects::Operation::Info;
 using Atlas::Objects::Operation::Set;
 using Atlas::Objects::Operation::Sight;
 using Atlas::Objects::Operation::Sound;
@@ -74,6 +79,8 @@ using Atlas::Objects::smart_dynamic_cast;
 
 static const bool debug_flag = false;
 
+long int Character::s_serialNumberNext = 0L;
+
 // This figure is calculated to allow a character to live for 4 weeks
 // without food, during which time they will lose 40% of their mass
 // before starving.
@@ -101,7 +108,6 @@ static const std::string OUTFIT = "outfit";
 static const std::string RIGHT_HAND_WIELD = "right_hand_wield";
 static const std::string SERIALNO = "serialno";
 static const std::string STAMINA = "stamina";
-static const std::string STATISTICS = "statistics";
 static const std::string STATUS = "status";
 static const std::string TASKS = "tasks";
 
@@ -250,7 +256,7 @@ LocatedEntity * Character::findInInventory(const std::string & id)
 /// @param id String identifier
 /// @param intId Integer identifier
 Character::Character(const std::string & id, long intId) :
-           Character_parent(id, intId),
+           Thing(id, intId),
                m_movement(*new Pedestrian(*this)),
                m_mind(0), m_externalMind(0)
 {
@@ -263,11 +269,80 @@ Character::Character(const std::string & id, long intId) :
 
 Character::~Character()
 {
+    if (m_rightHandWieldConnection.connected()) {
+        m_rightHandWieldConnection.disconnect();
+    }
     delete &m_movement;
     delete m_mind;
     delete m_externalMind;
 }
 
+int Character::linkExternal(Link * link)
+{
+    if (m_externalMind == 0) {
+        m_externalMind = new ExternalMind(*this);
+    } else if (m_externalMind->isLinked()) {
+        return -1;
+    }
+    m_externalMind->linkUp(link);
+
+    if (getProperty("external") == 0) {
+        ExternalProperty * ep = new ExternalProperty(m_externalMind);
+        // FIXME ensure this is install()ed and apply()ed
+        setProperty("external", ep);
+    }
+
+    Anonymous update_arg;
+    update_arg->setId(getId());
+    update_arg->setAttr("external", 1);
+
+    Update update;
+    update->setTo(getId());
+    update->setArgs1(update_arg);
+
+    sendWorld(update);
+    return 0;
+}
+
+int Character::unlinkExternal(Link * link)
+{
+    if (m_externalMind == 0) {
+        log(ERROR, "Character is not connected.");
+        return -1;
+    }
+
+    if  (!m_externalMind->isLinkedTo(link)) {
+        if (m_externalMind->isLinked()) {
+            return -2;
+        }
+        return -1;
+    }
+
+    // Send a move op stopping the current movement
+    Anonymous move_arg;
+    move_arg->setId(getId());
+    // Include the EXTERNAL property which is changing to zero.
+    // It would be more correct at this point to send a separate
+    // update to have the property update itself, but this
+    // will be much less of an issue once Sight(Set) is created
+    // more correctly
+    move_arg->setAttr("external", 0);
+    ::addToEntity(Vector3D(0,0,0), move_arg->modifyVelocity());
+
+    Move move;
+    move->setFrom(getId());
+    move->setArgs1(move_arg);
+
+    filterExternalOperation(move);
+
+
+    // We used to delete the external mind here, but now we
+    // leave it in place, as it takes care of the disconnected
+    // character.
+    m_externalMind->linkUp(0);
+    return 0;
+}
+
 /// \brief Set up a new task as the one being performed by the Character
 ///
 /// @param task The new task to be assigned to the Character
@@ -441,13 +516,13 @@ void Character::UseOperation(const Operation & op, OpVector & res)
     // Are we going to modify this really?
     EntityProperty * rhw = modPropertyClass<EntityProperty>(RIGHT_HAND_WIELD);
     if (rhw == 0) {
-        error(op, "Character::UseOp No tool wielded.", res, getId());
+        error(op, "Character::UseOp No tool wielded, no right_hand_wield property found.", res, getId());
         return;
     }
 
-    Entity * tool = rhw->data().get();
+    LocatedEntity * tool = rhw->data().get();
     if (tool == 0) {
-        error(op, "Character::UseOp No tool wielded.", res, getId());
+        error(op, "Character::UseOp No tool wielded, no entity found.", res, getId());
         return;
     }
     // FIXME Get a tool id from the op attributes?
@@ -590,7 +665,8 @@ void Character::UseOperation(const Operation & op, OpVector & res)
 
     rop->setTo(tool->getId());
 
-    Entity * target_ent = BaseWorld::instance().getEntity(entity_arg->getId());
+    LocatedEntity * target_ent =
+          BaseWorld::instance().getEntity(entity_arg->getId());
     if (target_ent == 0) {
         error(op, "Character::UseOperation Target does not exist", res, getId());
         return;
@@ -625,9 +701,9 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
 
         // FIXME Make sure we stop wielding if the container changes,
         // but connections are cleared, and don't build up.
-        // if (m_rightHandWieldConnection.connected()) {
-            // m_rightHandWieldConnection.disconnect();
-        // }
+        if (m_rightHandWieldConnection.connected()) {
+            m_rightHandWieldConnection.disconnect();
+        }
 
         Update update;
         update->setTo(getId());
@@ -641,7 +717,7 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
         return;
     }
     const std::string & id = arg->getId();
-    Entity * item = BaseWorld::instance().getEntity(id);
+    LocatedEntity * item = BaseWorld::instance().getEntity(id);
     if (item == 0) {
         error(op, "Wield arg does not exist", res, getId());
         return;
@@ -680,16 +756,16 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
         EntityProperty * rhw = requirePropertyClass<EntityProperty>(RIGHT_HAND_WIELD);
         // FIXME Make sure we don't stay linked to the previous wielded
         // tool.
-        // if (m_rightHandWieldConnection.connected()) {
-            // m_rightHandWieldConnection.disconnect();
-        // }
+        if (m_rightHandWieldConnection.connected()) {
+            m_rightHandWieldConnection.disconnect();
+        }
 
         // The value is ignored by the update handler, but should be the
         // right type.
         rhw->data() = EntityRef(item);
         rhw->setFlags(flag_unsent);
 
-        item->containered.connect(sigc::mem_fun(this, &Character::wieldDropped));
+        m_rightHandWieldConnection = item->containered.connect(sigc::hide<0>(sigc::mem_fun(this, &Character::wieldDropped)));
 
         debug(std::cout << "Wielding " << item->getId() << std::endl << std::flush;);
     }
@@ -706,12 +782,13 @@ void Character::AttackOperation(const Operation & op, OpVector & res)
         return;
     }
 
-    Entity * attack_ent = BaseWorld::instance().getEntity(op->getFrom());
+    LocatedEntity * attack_ent = BaseWorld::instance().getEntity(op->getFrom());
     if (attack_ent == 0) {
         log(ERROR, "AttackOperation: Attack op from non-existant ID");
         return;
     }
 
+    // FIXME Is this dynamic cast required?
     Character * attacker = dynamic_cast<Character *>(attack_ent);
 
     if (attacker == 0) {
@@ -832,7 +909,7 @@ void Character::ActuateOperation(const Operation & op, OpVector & res)
         return;
     }
 
-    Entity * device = BaseWorld::instance().getEntity(entity_arg->getId());
+    LocatedEntity * device = BaseWorld::instance().getEntity(entity_arg->getId());
 
     Element deviceOpAttr;
     std::set<std::string> deviceOps;
@@ -903,6 +980,123 @@ void Character::ActuateOperation(const Operation & op, OpVector & res)
     // res.push_back(sight);
 }
 
+void Character::RelayOperation(const Operation & op, OpVector & res)
+{
+    //A Relay operation with refno sent to ourselves signals that we should prune
+    //our registered relays in m_relays. This is a feature to allow for a timeout; if
+    //no Relay has been received from the destination Entity after a certain period
+    //we'll shut down the relay link.
+    if (op->getTo() == getId() && op->getFrom() == getId() && !op->isDefaultRefno()) {
+        auto I = m_relays.find(op->getRefno());
+        if (I != m_relays.end()) {
+            //Also send a no-op to any client to make it stop waiting for any response.
+            Operation noop;
+            noop->setRefno(I->second.serialno);
+            noop->setTo(getId());
+            noop->setFrom(getId());
+            sendMind(noop, res);
+            m_relays.erase(I);
+        }
+    } else {
+        if (op->getArgs().empty()) {
+            log(ERROR, "Character::RelayOperation no args.");
+            return;
+        }
+        Operation relayedOp = Atlas::Objects::smart_dynamic_cast<Operation>(
+                op->getArgs().front());
+
+        if (!relayedOp.isValid()) {
+            log(ERROR,
+                    "Character::RelayOperation first arg is not an operation.");
+            return;
+        }
+
+
+        //If a relay op has a refno, it's a response to a Relay op previously sent out to another
+        //entity, and we should send the incoming relayed operation to the mind.
+        if (!op->isDefaultRefno()) {
+            //Note that the relayed op should be considered untrusted in this case, as it has originated
+            //from a random entity or its mind.
+            auto I = m_relays.find(op->getRefno());
+            if (I == m_relays.end()) {
+                log(WARNING,
+                        "Character::RelayOperation could not find registrered Relay with refno.");
+                return;
+            }
+
+            //Make sure that this op really comes from the entity the original Relay op was sent to.
+            if (op->getFrom() != I->second.destination) {
+                log(WARNING,
+                        "Character::RelayOperation got relay op with mismatching 'from'.");
+                return;
+            }
+
+            //Get the relayed operation and send to mind.
+            //Note that we don't send the operation to the entity; this is because we have
+            //to treat the relayed operation as "unsafe". This is since it originated from an random
+            //entity's mind and could in effect be anything (Set, Logout etc.)
+            //We should therefore handle it with care and only send it on to the mind.
+            //This of course hinges on the mind client code making sure to handle it correctly, given
+            //its refno.
+            relayedOp->setRefno(I->second.serialno);
+            sendMind(relayedOp, res);
+            m_relays.erase(I);
+
+        } else {
+
+            //Check if the mind should handle the relayed operation; else we'll just let the
+            //standard Entity relay code do it's thing.
+            if (!world2mind(relayedOp))
+            {
+                //This operation won't be sent to the mind, we'll pass it on to the standard
+                //relay method which will generate a Sight as response.
+                Entity::RelayOperation(op, res);
+                return;
+            }
+
+            //If the Relay op instead has a serial no, it's a Relay op sent from us by another Entity
+            //which expects a response. We should send it on to the mind (efter registering an entry in
+            //m_relays to be handled by mind2body).
+            //Note that the relayed operation in this case should be considered "trusted", as it has originated
+            //from either the server itself or a trusted client.
+
+            //Extract the contained operation, and register the relay into m_relays
+            if (op->isDefaultSerialno()) {
+                log(ERROR, "Character::RelayOperation no serial number.");
+                return;
+            }
+
+            Relay relay;
+            relay.serialno = op->getSerialno();
+            relay.destination = op->getFrom();
+
+            //Generate a local serial number which we'll register in m_relays. When a response is received
+            //we'll check the refno and match it against what we've stored
+            long int serialNo = ++s_serialNumberNext;
+            relayedOp->setSerialno(serialNo);
+            m_relays.insert(std::make_pair(serialNo, relay));
+
+            //Make sure that the contained op is addressed to the entity
+            relayedOp->setTo(getId());
+
+            //Now send the contained op to the entity
+            operation(relayedOp, res);
+
+            //Also send a future Relay op to ourselves to make sure that the registered relay in m_relays
+            //is removed in the case that we don't get any response.
+            Atlas::Objects::Operation::Generic pruneOp;
+            pruneOp->setType("relay", Atlas::Objects::Operation::RELAY_NO);
+            pruneOp->setTo(getId());
+            pruneOp->setFrom(getId());
+            pruneOp->setRefno(serialNo);
+            //5 seconds should be more than enough.
+            pruneOp->setFutureSeconds(5);
+            sendWorld(pruneOp);
+        }
+    }
+}
+
+
 /// \brief Filter an Actuate operation coming from the mind
 ///
 /// @param op The operation to be filtered.
@@ -1024,7 +1218,7 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
     const std::string & other_id = arg->getId();
     if (other_id != getId()) {
         debug( std::cout << "Moving something else. " << other_id << std::endl << std::flush;);
-        Entity * other = BaseWorld::instance().getEntity(other_id);
+        LocatedEntity * other = BaseWorld::instance().getEntity(other_id);
         if (other == 0) {
             Unseen u;
 
@@ -1090,7 +1284,7 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
                      << ":" << std::endl << std::flush;);
     if (!new_loc.empty() && (new_loc != m_location.m_loc->getId())) {
         debug(std::cout << "Changing loc" << std::endl << std::flush;);
-        Entity * target_loc = BaseWorld::instance().getEntity(new_loc);
+        LocatedEntity * target_loc = BaseWorld::instance().getEntity(new_loc);
         if (target_loc == 0) {
             Unseen u;
 
@@ -1504,6 +1698,27 @@ bool Character::w2mSoundOperation(const Operation & op)
     return true;
 }
 
+/// \brief Filter a Thought operation coming from the world to the mind
+///
+/// @param op The operation to be filtered.
+/// @return true if the operation should be passed.
+bool Character::w2mThoughtOperation(const Operation & op)
+{
+    //Only allow thoughts which are sent from the mind
+    return op->getFrom() == getId();
+}
+
+bool Character::w2mThinkOperation(const Operation & op)
+{
+    return true;
+}
+
+bool Character::w2mCommuneOperation(const Operation & op)
+{
+    return true;
+}
+
+
 /// \brief Filter a Touch operation coming from the world to the mind
 ///
 /// @param op The operation to be filtered.
@@ -1513,6 +1728,16 @@ bool Character::w2mTouchOperation(const Operation & op)
     return true;
 }
 
+/// \brief Filter a Relay operation coming from the world to the mind
+///
+/// @param op The operation to be filtered.
+/// @return true if the operation should be passed.
+bool Character::w2mRelayOperation(const Operation & op)
+{
+    //Relay is an internal op.
+    return false;
+}
+
 /// \brief Send an operation to the current active part of the mind
 ///
 /// The operation can potentially go to an external mind if one is
@@ -1558,7 +1783,32 @@ void Character::mind2body(const Operation & op, OpVector & res)
 {
     debug( std::cout << "Character::mind2body(" << std::endl << std::flush;);
 
+    //Check if we have any relays registered for this op.
+    if (!op->isDefaultRefno()) {
+        auto I = m_relays.find(op->getRefno());
+        if (I != m_relays.end()) {
+            //The operation is a response to a relayed op, and we should send it on to the originating
+            //entity. When doing this, we're basically wrapping an unsafe operation (i.e. the operation from
+            //the mind could be anything), so it's important that the client or code which receives
+            //the relayed op handles it with case.
+
+            //Wrap the operation in a relay op
+            Atlas::Objects::Operation::Generic relayOp;
+            relayOp->setType("relay", Atlas::Objects::Operation::RELAY_NO);
+            relayOp->setArgs1(op);
+            relayOp->setTo(I->second.destination);
+            relayOp->setRefno(I->second.serialno);
+            res.push_back(relayOp);
+            m_relays.erase(I);
+
+            //The operation should not be processed anymore after it has been relayed.
+            return;
+        }
+    }
+
+
     if (!op->isDefaultTo()) {
+
         log(ERROR, String::compose("Operation \"%1\" from mind with TO set.",
                                    op->getParents().front()));
         return;
@@ -1568,7 +1818,7 @@ void Character::mind2body(const Operation & op, OpVector & res)
                                    "FUTURE_SECONDS set.",
                                    op->getParents().front()));
     }
-    OpNo op_no = op->getClassNo();
+    auto op_no = op->getClassNo();
     switch (op_no) {
         case Atlas::Objects::Operation::COMBINE_NO:
             mindCombineOperation(op, res);
@@ -1639,29 +1889,13 @@ void Character::mind2body(const Operation & op, OpVector & res)
 bool Character::world2mind(const Operation & op)
 {
     debug( std::cout << "Character::world2mind(" << op->getParents().front() << ")" << std::endl << std::flush;);
-    OpNo otype = op->getClassNo();
+    auto otype = op->getClassNo();
     POLL_OP_SWITCH(op, otype, w2m)
     return false;
 }
 
-void Character::operation(const Operation & op, OpVector & res)
+void Character::filterExternalOperation(const Operation & op)
 {
-    debug( std::cout << "Character::operation(" << op->getParents().front() << ")" << std::endl << std::flush;);
-    Entity::operation(op, res);
-    if (world2mind(op)) {
-        debug( std::cout << "Character::operation(" << op->getParents().front() << ") passed to mind" << std::endl << std::flush;);
-        OpVector mres;
-        sendMind(op, mres);
-        OpVector::const_iterator Iend = mres.end();
-        for (OpVector::const_iterator I = mres.begin(); I != Iend; ++I) {
-            externalOperation(*I);
-        }
-    }
-}
-
-void Character::externalOperation(const Operation & op)
-{
-    debug( std::cout << "Character::externalOperation(" << op->getParents().front() << ")" << std::endl << std::flush;);
     OpVector mres;
     mind2body(op, mres);
     
@@ -1679,3 +1913,39 @@ void Character::externalOperation(const Operation & op)
         sendWorld(*I);
     }
 }
+
+void Character::operation(const Operation & op, OpVector & res)
+{
+    debug( std::cout << "Character::operation(" << op->getParents().front() << ")" << std::endl << std::flush;);
+    Entity::operation(op, res);
+    if (world2mind(op)) {
+        debug( std::cout << "Character::operation(" << op->getParents().front() << ") passed to mind" << std::endl << std::flush;);
+        OpVector mres;
+        sendMind(op, mres);
+        OpVector::const_iterator Iend = mres.end();
+        for (OpVector::const_iterator I = mres.begin(); I != Iend; ++I) {
+            filterExternalOperation(*I);
+        }
+    }
+}
+
+void Character::externalOperation(const Operation & op, Link & link)
+{
+    debug( std::cout << "Character::externalOperation(" << op->getParents().front() << ")" << std::endl << std::flush;);
+    if (linkExternal(&link) == 0) {
+        debug(std::cout << "Subscribing existing character" << std::endl
+                        << std::flush;);
+
+        Info info;
+        Anonymous info_arg;
+        addToEntity(info_arg);
+        info->setArgs1(info_arg);
+
+        link.send(info);
+
+        logEvent(TAKE_CHAR, String::compose("%1 - %2 Taken character (%3)",
+                                            getId(), getId(),
+                                            getType()));
+    }
+    filterExternalOperation(op);
+}
