@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 65fb329146a0c3a8c5660b2e320ffb5f15d370b0 $
 
 #ifndef RULESETS_MIND_PROPERTY_H
 #define RULESETS_MIND_PROPERTY_H
@@ -29,16 +28,23 @@ class MindKit;
 class MindProperty : public PropertyBase {
   protected:
     MindKit * m_factory;
+
+    MindProperty(const MindProperty &);
   public:
     MindProperty();
+    virtual ~MindProperty();
 
     MindKit * factory() {
         return m_factory;
     }
 
+    /// \brief Returns true if mind scripting is enabled.
+    bool isMindEnabled() const;
+
     virtual int get(Atlas::Message::Element & val) const;
     virtual void set(const Atlas::Message::Element & val);
-    virtual void apply(Entity *);
+    virtual MindProperty * copy() const;
+    virtual void apply(LocatedEntity *);
 };
 
 #endif // RULESETS_MIND_PROPERTY_H
