@@ -15,24 +15,13 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 7af9bc6cd87a73ed3c46ba8112b1d53212b59d0f $
 
 #include "Movement.h"
 
-#include "Character.h"
+#include "modules/Location.h"
 
-#include "physics/Collision.h"
-
-#include "common/debug.h"
-
-#include "common/Tick.h"
-
-#include <Atlas/Objects/Operation.h>
-
-static const bool debug_flag = false;
-
-Movement::Movement(Entity & body) : m_body(body),
-                                    m_serialno(0)
+Movement::Movement(LocatedEntity & body) : m_body(body),
+                                           m_serialno(0)
 {
 }
 
