@@ -15,20 +15,17 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: ac236f2aebc9e2b449143e4dd636c8ab1e6321d1 $
 
 #ifndef RULESETS_PEDESTRIAN_H
 #define RULESETS_PEDESTRIAN_H
 
 #include "Movement.h"
 
-class Entity;
-
 /// \brief Class for handling movement of a Pedestrian Character
 class Pedestrian : public Movement {
     // friend class Character;
   public:
-    explicit Pedestrian(Entity & body);
+    explicit Pedestrian(LocatedEntity & body);
     virtual ~Pedestrian();
 
     double getTickAddition(const Point3D & coordinates,
