@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 31f3a6906dbdf3f0d7fd7729c5ff48fb3bce282c $
 
 #include "Py_Shape.h"
 
@@ -212,7 +211,7 @@ static PyBBox * Box_extrude(PyShape * self, PyObject * args)
         return NULL;
     }
     float low, high;
-    if (!PyArg_ParseTuple(args, "dd", &low, &high)) {
+    if (!PyArg_ParseTuple(args, "ff", &low, &high)) {
         return NULL;
     }
     PyBBox * ret = newPyBBox();
@@ -222,7 +221,7 @@ static PyBBox * Box_extrude(PyShape * self, PyObject * args)
                                 low),
                         Point3D(shape->shape().highCorner().x(),
                                 shape->shape().highCorner().y(),
-                                high));
+                                high), true);
     }
     return ret;
 }
@@ -450,7 +449,7 @@ PyShape * Area_sq_item(PyShape * self, Py_ssize_t index)
         return 0;
     }
 #endif // NDEBUG
-    if (index >= self->shape.s->size()) {
+    if (static_cast<size_t>(index) >= self->shape.s->size()) {
         PyErr_SetString(PyExc_IndexError, "Number of corners exceded");
         return 0;
     }
@@ -474,7 +473,7 @@ PyPoint3D * Body_sq_item(PyShape * self, Py_ssize_t index)
         return 0;
     }
 #endif // NDEBUG
-    if (index >= self->shape.s->size()) {
+    if (static_cast<size_t>(index) >= self->shape.s->size()) {
         PyErr_SetString(PyExc_IndexError, "Number of corners exceded");
         return 0;
     }
