@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 5b6cddf57a3a20cf8dab7ff595f97ec78364020c $
 
 #include "Py_Thing.h"
 
@@ -234,6 +233,12 @@ static PyObject * Entity_getattro(PyEntity *self, PyObject *oname)
         }
         return list;
     }
+    if (strcmp(name, "visible") == 0) {
+        if (self->m_entity.e->isVisible()) {
+            Py_RETURN_TRUE;
+        }
+        Py_RETURN_FALSE;
+    }
     Entity * entity = self->m_entity.e;
     PropertyBase * prop = entity->modProperty(name);
     if (prop != 0) {
