@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 9f36136dc80a4cd5b3dfcf0665de76b0c9959336 $
 
 #ifndef RULESETS_PYTHON_ARITHMETIC_FACTORY_H
 #define RULESETS_PYTHON_ARITHMETIC_FACTORY_H
@@ -35,7 +34,7 @@ class PythonArithmeticFactory : public ArithmeticKit, private PythonClass {
 
     int setup();
 
-    virtual ArithmeticScript * newScript(Entity * owner);
+    virtual ArithmeticScript * newScript(LocatedEntity * owner);
 };
 
 #endif // RULESETS_PYTHON_ARITHMETIC_FACTORY_H
