@@ -15,11 +15,12 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: dd607da79ed5756ec9382c06df7f0ef5e3004e37 $
 
 #include "SpawnProperty.h"
 
-#include "Entity.h"
+#include "rulesets/LocatedEntity.h"
+
+#include "common/BaseWorld.h"
 
 using Atlas::Message::MapType;
 
@@ -27,7 +28,16 @@ SpawnProperty::SpawnProperty()
 {
 }
 
-void SpawnProperty::apply(Entity * ent)
+SpawnProperty::~SpawnProperty()
+{
+}
+
+SpawnProperty * SpawnProperty::copy() const
+{
+    return new SpawnProperty(*this);
+}
+
+void SpawnProperty::apply(LocatedEntity * ent)
 {
     BaseWorld::instance().createSpawnPoint(m_data, ent);
 }
