@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 9897a6812cb1ce0bd53ece3a2985e90b764c0215 $
 
 #ifndef RULESETS_SPAWN_PROPERTY_H
 #define RULESETS_SPAWN_PROPERTY_H
@@ -34,8 +33,11 @@ namespace Atlas {
 class SpawnProperty : public Property<Atlas::Message::MapType> {
   public:
     SpawnProperty();
+    virtual ~SpawnProperty();
 
-    virtual void apply(Entity *);
+    virtual SpawnProperty * copy() const;
+
+    virtual void apply(LocatedEntity *);
 };
 
 #endif // RULESETS_SPAWN_PROPERTY_H
