@@ -15,11 +15,10 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: ef00c299349f475d2707a21456e30be35e63cbc1 $
 
 #include "StatusProperty.h"
 
-#include "Entity.h"
+#include "LocatedEntity.h"
 
 #include <Atlas/Objects/Operation.h>
 #include <Atlas/Objects/Anonymous.h>
@@ -32,7 +31,12 @@ StatusProperty::StatusProperty()
 {
 }
 
-void StatusProperty::apply(Entity * owner)
+StatusProperty * StatusProperty::copy() const
+{
+    return new StatusProperty(*this);
+}
+
+void StatusProperty::apply(LocatedEntity * owner)
 {
     if (m_data < 0) {
         Delete del;
