@@ -15,15 +15,12 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 8d0c7966d16a4ff4987ef821236637427902ed24 $
 
 #ifndef RULESETS_STATUS_PROPERTY_H
 #define RULESETS_STATUS_PROPERTY_H
 
 #include "common/Property.h"
 
-class Entity;
-
 /// \brief Class to handle whether or not an entity is solid for collisions.
 /// \ingroup PropertyClasses
 class StatusProperty : public Property<double> {
@@ -31,7 +28,9 @@ class StatusProperty : public Property<double> {
     /// \brief Constructor
     explicit StatusProperty();
 
-    virtual void apply(Entity *);
+    virtual StatusProperty * copy() const;
+
+    virtual void apply(LocatedEntity *);
 };
 
 #endif // RULESETS_STATUS_PROPERTY_H
