@@ -15,19 +15,18 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: c4187760c56825e19551dd51852133ba8dd5c39d $
 
 #include "TerrainEffectorProperty.h"
 
-#include "Entity.h"
-#include "TerrainProperty.h"
+#include "rulesets/LocatedEntity.h"
+#include "rulesets/TerrainProperty.h"
 
 #include "modules/Location.h"
 #include "modules/TerrainContext.h"
 
 #include <Mercator/TerrainMod.h>
 
-const TerrainProperty * TerrainEffectorProperty::getTerrain(Entity * owner)
+const TerrainProperty * TerrainEffectorProperty::getTerrain(LocatedEntity * owner)
 {
     const PropertyBase * terr;
     LocatedEntity * ent = owner;
