@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 33ee7175aa6c6a6133deb14cc1aeac91da6f71d7 $
 
 #ifndef RULESETS_TERRAIN_EFFECTOR_PROPERTY_H
 #define RULESETS_TERRAIN_EFFECTOR_PROPERTY_H
@@ -28,7 +27,7 @@ class TerrainProperty;
 /// \ingroup PropertyClasses
 class TerrainEffectorProperty : public Property<Atlas::Message::MapType> {
   protected:
-    const TerrainProperty* getTerrain(Entity * owner);
+    const TerrainProperty* getTerrain(LocatedEntity * owner);
 
     friend class TerrainEffectorPropertytest;
 };
