@@ -15,13 +15,13 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: e3a188c1e1a901f080e3b1bb0b229e70d4f22a8f $
 
 #include "Thing.h"
 
 #include "Motion.h"
 #include "Domain.h"
 
+#include "common/BaseWorld.h"
 #include "common/log.h"
 #include "common/const.h"
 #include "common/debug.h"
@@ -63,7 +63,7 @@ static const bool debug_flag = false;
 
 /// \brief Constructor for physical or tangiable entities.
 Thing::Thing(const std::string & id, long intId) :
-       Thing_parent(id, intId)
+       Entity(id, intId)
 {
     m_motion = new Motion(*this);
 }
@@ -84,6 +84,15 @@ void Thing::DeleteOperation(const Operation & op, OpVector & res)
     }
     // The actual destruction and removal of this entity will be handled
     // by the WorldRouter
+
+    //We need to send a sight operation directly to the entity.
+    //The reason is that else the entity will be deleted before it can receive the broadcast Sight
+    //of the Delete op, which will leave any external clients hanging.
+    Sight sToEntity;
+    sToEntity->setArgs1(op);
+    sToEntity->setTo(getId());
+    operation(sToEntity, res);
+
     Sight s;
     s->setArgs1(op);
     res.push_back(s);
@@ -121,7 +130,7 @@ void Thing::MoveOperation(const Operation & op, OpVector & res)
         return;
     }
     const std::string & new_loc_id = ent->getLoc();
-    Entity * new_loc = 0;
+    LocatedEntity * new_loc = 0;
     if (new_loc_id != m_location.m_loc->getId()) {
         // If the LOC has not changed, we don't need to look it up, or do
         // any of the following checks.
@@ -336,17 +345,16 @@ void Thing::checkVisibility(const Point3D & old_pos, OpVector & res)
     LocatedEntitySet::const_iterator I = m_location.m_loc->m_contains->begin();
     LocatedEntitySet::const_iterator Iend = m_location.m_loc->m_contains->end();
     for(; I != Iend; ++I) {
-        float old_dist = squareDistance((*I)->m_location.pos(), old_pos),
-              new_dist = squareDistance((*I)->m_location.pos(), m_location.pos()),
-              squ_size = (*I)->m_location.squareBoxSize();
+        LocatedEntity * other = *I;
+        assert(other != 0);
+        float old_dist = squareDistance(other->m_location.pos(), old_pos),
+              new_dist = squareDistance(other->m_location.pos(), m_location.pos()),
+              squ_size = other->m_location.squareBoxSize();
 
         // Build appear and disappear lists, and send operations
         // Also so operations to (dis)appearing perceptive
         // entities saying that we are (dis)appearing
-        // FIXME Should this be Entity *
-        Entity * viewer = dynamic_cast<Entity *>(*I);
-        assert(viewer != 0);
-        if (viewer->isPerceptive()) {
+        if (other->isPerceptive()) {
             bool was_in_range = ((fromSquSize / old_dist) > consts::square_sight_factor),
                  is_in_range = ((fromSquSize / new_dist) > consts::square_sight_factor);
             if (was_in_range != is_in_range) {
@@ -355,7 +363,7 @@ void Thing::checkVisibility(const Point3D & old_pos, OpVector & res)
                     // knows it is losing sight of us.
                     Disappearance d;
                     d->setArgs1(this_ent);
-                    d->setTo((*I)->getId());
+                    d->setTo(other->getId());
                     res.push_back(d);
                 } else /*if (is_in_range)*/ {
                     // Send operation to the entity in question so it
@@ -364,7 +372,7 @@ void Thing::checkVisibility(const Point3D & old_pos, OpVector & res)
                     // to get our Sight(Move)
                     Appearance a;
                     a->setArgs1(this_ent);
-                    a->setTo((*I)->getId());
+                    a->setTo(other->getId());
                     res.push_back(a);
                 }
             }
@@ -374,18 +382,18 @@ void Thing::checkVisibility(const Point3D & old_pos, OpVector & res)
              can_see = ((squ_size / new_dist) > consts::square_sight_factor);
         if (could_see ^ can_see) {
             Anonymous that_ent;
-            that_ent->setId((*I)->getId());
-            that_ent->setStamp((*I)->getSeq());
+            that_ent->setId(other->getId());
+            that_ent->setStamp(other->getSeq());
             if (could_see) {
                 // We are losing sight of that object
                 disappear.push_back(that_ent);
                 debug(std::cout << getId() << ": losing site of "
-                                << (*I)->getId() << std::endl;);
+                                << other->getId() << std::endl;);
             } else /*if (can_see)*/ {
                 // We are gaining sight of that object
                 appear.push_back(that_ent);
                 debug(std::cout << getId() << ": gaining site of "
-                                << (*I)->getId() << std::endl;);
+                                << other->getId() << std::endl;);
             }
         }
     }
@@ -667,7 +675,7 @@ void Thing::CreateOperation(const Operation & op, OpVector & res)
         const std::string & type = parents.front();
         debug( std::cout << getId() << " creating " << type;);
 
-        Entity * obj = BaseWorld::instance().addNewEntity(type,ent);
+        LocatedEntity * obj = BaseWorld::instance().addNewEntity(type,ent);
 
         if (obj == 0) {
             error(op, "Create op failed.", res, op->getFrom());
