@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: c1a0184dbb50633dbf322216909a0bc712ecb241 $
 
 #ifndef RULESETS_TRANSIENT_PROPERTY_H
 #define RULESETS_TRANSIENT_PROPERTY_H
@@ -27,10 +26,13 @@
 class TransientProperty : public Property<double> {
   public:
     TransientProperty();
+    virtual ~TransientProperty();
 
-    virtual void install(Entity *);
+    virtual TransientProperty * copy() const;
 
-    virtual void apply(Entity *);
+    virtual void install(LocatedEntity *, const std::string &);
+
+    virtual void apply(LocatedEntity *);
 };
 
 #endif // RULESETS_TRANSIENT_PROPERTY_H
