@@ -15,11 +15,10 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 945365f3fb2c349a110a54e931f69edf3f080ebc $
 
 #include "VisibilityProperty.h"
 
-#include "rulesets/Entity.h"
+#include "rulesets/LocatedEntity.h"
 
 #include "common/log.h"
 
@@ -27,7 +26,16 @@ VisibilityProperty::VisibilityProperty()
 {
 }
 
-void VisibilityProperty::apply(Entity * ent)
+VisibilityProperty::~VisibilityProperty()
+{
+}
+
+VisibilityProperty * VisibilityProperty::copy() const
+{
+    return new VisibilityProperty(*this);
+}
+
+void VisibilityProperty::apply(LocatedEntity * ent)
 {
     ent->m_location.setVisibility(m_data);
 }
