@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 33f0459ad2edc1a1e77146aeea65e29d19f12b1b $
 
 #ifndef RULESETS_VISIBILITY_PROPERTY_H
 #define RULESETS_VISIBILITY_PROPERTY_H
@@ -27,8 +26,11 @@
 class VisibilityProperty : public Property<float> {
   public:
     VisibilityProperty();
+    virtual ~VisibilityProperty();
 
-    virtual void apply(Entity *);
+    virtual VisibilityProperty * copy() const;
+
+    virtual void apply(LocatedEntity *);
 };
 
 #endif // RULESETS_VISIBILITY_PROPERTY_H
