@@ -2,6 +2,7 @@
 #Copyright (C) 1999 Aloril (See the file COPYING for details).
 
 import random
+import traceback
 
 from atlas import *
 from physics import *
@@ -71,6 +72,7 @@ class NPCMind(server.Mind):
         self.map.add_hooks_append("add_map")
         self.map.update_hooks_append("update_map")
         self.map.delete_hooks_append("delete_map")
+        self.goal_id_counter=0
     def find_op_method(self, op_id, prefix="",undefined_op_method=None):
         """find right operation to invoke"""
         if not undefined_op_method: undefined_op_method=self.undefined_op_method
@@ -158,6 +160,226 @@ class NPCMind(server.Mind):
             if obj.type[0]=="coin" and op.from_ != self.id:
                 self.money_transfers.append([op.from_, 1])
                 return Operation("imaginary", Entity(description="accepts"))
+
+    def commune_operation(self, op):
+        """A 'commune' operation is used to inquire about the status of a mind.
+        It's often sent from authoring clients, as well as the server itself when 
+        it wants to persist the thoughts of a mind.
+        An commune op without any args means that the mind should dump all its thoughts.
+        If there are args however, the meaning of what's to return differs depending on the
+        args.
+        * If "goal" is specified, a "think" operation only pertaining to goals is returned. The 
+        "goal" arg should be a map, where the keys and values are used to specify exactly what goals
+        to return. An empty map returns all goals.
+        * If "goal_info" is specified, an "info" operation with debug information about the 
+        current state of one or many goals is returned. The "goal_info" arg should be a map, 
+        where the keys and values are used to specify exactly what goals to return info about.
+        An empty map returns all goals.  
+        """
+        
+        args=op.getArgs()
+        #If there are no args we should send all of our thoughts
+        if len(args) == 0:
+            return self.commune_all_thoughts(op)
+        else:
+            argEntity=args[0]
+
+            if hasattr(argEntity, "goal"):
+                goal_entity = argEntity.goal
+                return self.commune_goals(op, goal_entity)
+            elif hasattr(argEntity, "goal_info"):
+                goal_info_entity = argEntity.goal_info
+                return self.commune_goal_info(op, goal_info_entity)
+            #TODO: allow for finer grained query of specific thoughts
+        
+    def commune_goals(self, op, goal_entity):
+        """Sends back information about goals only."""
+        thinkOp = Operation("think")
+        thoughts = []
+
+        #It's important that the order of the goals is retained
+        for goal in self.goals:
+            goalEntity=Entity(id=str(goal.id))
+            if hasattr(goal, "str"):
+                goalEntity.definition = goal.str
+            else:
+                goalEntity.definition = goal.__class__.__name__
+            if hasattr(goal, "key"):
+                goalEntity.key=str(goal.key)
+
+            thoughts.append(goalEntity)
+            
+        for (trigger, goallist) in sorted(self.trigger_goals.items()):
+            for goal in goallist:
+                goalEntity=Entity(id=str(goal.id))
+                if hasattr(goal, "str"):
+                    goalEntity.definition = goal.str
+                else:
+                    goalEntity.definition = goal.__class__.__name__
+                if hasattr(goal, "key"):
+                    goalEntity.key=str(goal.key)
+                    
+                thoughts.append(goalEntity)
+            
+        
+        thinkOp.setArgs(thoughts)
+        thinkOp.setRefno(op.getSerialno())
+        res = Oplist()
+        res = res + thinkOp
+        return res
+    
+    def find_goal(self, id):
+        #Goals are either stored in "self.goals" or "self.trigger_goals", so we need
+        #to check both
+        for goal in self.goals:
+            if goal.id == id:
+                return goal
+        for (trigger, goallist) in sorted(self.trigger_goals.items()):
+            for goal in goallist:
+                if goal.id == id:
+                    return goal
+        return None
+        
+    def commune_goal_info(self, op, goal_info_entity):
+        """Sends back information about goals. This is mainly to be used for debugging minds.
+        If no arguments are specified all goals will be reported, else a match will be done
+        using 'subject' and 'goal'.
+        The information will be sent back as an "info" operation.
+        """
+        goalInfoOp = Operation("info")
+        goal_infos = []
+
+        if "id" in goal_info_entity:
+            id = str(goal_info_entity["id"])
+            goal = self.find_goal(id)
+            if goal:
+                goal_infos.append(Entity(id=id, report=goal.report()))
+        else:
+            #get all goals
+            for goal in self.goals:
+                goal_infos.append(Entity(id=id, report=goal.report()))
+            for (trigger, goallist) in sorted(self.trigger_goals.items()):
+                for goal in goallist:
+                    goal_infos.append(Entity(id=id, report=goal.report()))
+        
+        goalInfoOp.setArgs(goal_infos)
+        goalInfoOp.setRefno(op.getSerialno())
+        res = Oplist()
+        res = res + goalInfoOp
+        return res
+        
+    
+    def commune_all_thoughts(self, op):
+        """Sends back information on all thoughts. This includes knowledge and goals, 
+        as well as known things.
+        The thoughts will be sent back as a "think" operations, in a manor such that if the
+        same think operation is sent back to the mind all thoughts will be restored. In
+        this way the mind can support server side persistence of its thoughts.
+        """
+        thinkOp = Operation("think")
+        thoughts = []
+
+        for attr in sorted(dir(self.knowledge)):
+            d=getattr(self.knowledge, attr)
+            if getattr(d, '__iter__', False):
+               for key in sorted(d):
+                    if attr!="goal":
+                        objectVal=d[key]
+                        if type(objectVal) is Location:
+                            #Serialize Location as tuple, with parent if available
+                            if objectVal.parent is None:
+                                location=objectVal.coordinates
+                            else:
+                                location=(objectVal.parent.id,objectVal.coordinates)
+                            object=str(location)
+                        else:
+                            object=str(d[key])
+                        
+                        thoughts.append(Entity(predicate=attr, subject=str(key), object=object))
+        
+        #It's important that the order of the goals is retained
+        for goal in self.goals:
+            if hasattr(goal, "str"):
+                thoughts.append(Entity(predicate="goal", subject=str(goal.key), object=goal.str))
+
+        for (trigger, goallist) in sorted(self.trigger_goals.items()):
+            for goal in goallist:
+                if hasattr(goal, "str"):
+                    thoughts.append(Entity(predicate="goal", subject=str(goal.key), object=goal.str))
+            
+        if len(self.things) > 0:
+            things={}
+            for (id, thinglist) in sorted(self.things.items()):
+                idlist=[]
+                for thing in thinglist:
+                    idlist.append(thing.id)
+                things[id] = idlist
+            thoughts.append(Entity(things=things))
+
+        if len(self.pending_things) > 0:            
+            thoughts.append(Entity(pending_things=self.pending_things))
+                
+        thinkOp.setArgs(thoughts)
+        thinkOp.setRefno(op.getSerialno())
+        res = Oplist()
+        res = res + thinkOp
+        return res
+
+    def think_operation(self, op):
+        args=op.getArgs()
+        for thought in args:
+            #Check if there's a 'predicate' set; if so handle it as knowledge. 
+            #Else check if it's things that we know we own or ought to own. 
+            if hasattr(thought, "predicate") == False:
+                if hasattr(thought, "things"):
+                    things=thought.things
+                    for (id, thinglist) in things.items():
+                        #We can't iterate directly over the list, as it's of type atlas.Message; we must first "pythonize" it. 
+                        #This should be reworked into a better way. 
+                        thinglist=thinglist.pythonize()
+                        for thingId in thinglist:
+                            thingId=str(thingId)
+                            thing = self.map.get(thingId)
+                            if thing and thing.type[0]:
+                                self.add_thing(thing)
+                            else:
+                                self.pending_things.append(thingId)
+                elif hasattr(thought, "pending_things"):
+                    for id in thought.pending_things:
+                        self.pending_things.append(str(id))
+                elif hasattr(thought, "goal"):
+                    goalElem=thought.goal
+                    id=str(goalElem["id"])
+                    goal = self.find_goal(id)
+                    if goal:
+                        if "definition" in goalElem:
+                            self.update_goal(goal, str(goalElem["definition"]))
+                        else:
+                            self.remove_goal(goal)
+            else:
+                subject=thought.subject
+                predicate=thought.predicate
+                object=thought.object
+                #handle goals in a special way
+                if predicate == "goal":
+                    self.add_goal(subject, object)
+                else:
+                    #Handle locations.
+                    if len(object) > 0 and object[0]=='(':
+                        #CHEAT!: remove eval
+                        locdata=eval(object)
+                        #If only coords are supplied, it's handled as a location within the same parent space as ourselves
+                        if (len(locdata) == 3):
+                            loc=self.location.copy()
+                            loc.coordinates=Vector3D(list(locdata))
+                        elif (len(locdata) == 2):
+                            where=self.map.get_add(locdata[0])
+                            coords=Point3D(list(locdata[1]))
+                            loc=Location(where, coords)
+                        self.add_knowledge(predicate,subject,loc)
+                    else:
+                        self.add_knowledge(predicate,subject,object)
+    
     ########## Talk operations
     def admin_sound(self, op):
         assert(op.from_ == op.to)
@@ -410,8 +632,8 @@ class NPCMind(server.Mind):
         else:
             thought_value = value
         desc="%s knowledge about %s is %s" % (what,key,thought_value)
-        ent = Entity(description=desc, what=what, key=key, value=thought_value)
-        self.send(Operation("thought",ent))
+#        ent = Entity(description=desc, what=what, key=key, value=thought_value)
+#        self.send(Operation("thought",ent))
         if what=="location":
             #and reverse too
             self.reverse_knowledge.add("location",value,key)
@@ -458,10 +680,10 @@ class NPCMind(server.Mind):
         if not name:
             self.pending_things.append(thing.id)
             return
-        desc="I own %s." % name
-        what=thing.as_entity()
-        ent = Entity(description=desc, what=what)
-        self.send(Operation("thought",ent))
+#        desc="I own %s." % name
+#        what=thing.as_entity()
+#        ent = Entity(description=desc, what=what)
+#        self.send(Operation("thought",ent))
         dictlist.add_value(self.things,name,thing)
         log.debug(3,"\tafter: "+str(self.things))
     def find_thing(self, thing):
@@ -478,14 +700,14 @@ class NPCMind(server.Mind):
     ########## goals
     def add_goal(self, name, str_goal):
         """add goal..."""
-        #CHEAT!: remove eval (this and later)
-        goal=eval("mind.goals."+str_goal)
-        if const.debug_thinking:
-            goal.debug=1
-        goal.str=str_goal
-        if type(name)==StringType: goal.key=eval(name)
-        else: goal.key=name
-        self.add_knowledge("goal",name,goal)
+        goal = self.create_goal(name, str_goal)
+        self.insert_goal(goal)
+    def insert_goal(self, goal, id=None):
+        if not id:
+            self.goal_id_counter = self.goal_id_counter + 1
+            id=str(self.goal_id_counter)
+            
+        goal.id = id
         if hasattr(goal,"trigger"):
             dictlist.add_value(self.trigger_goals, goal.trigger(), goal)
             return
@@ -494,14 +716,65 @@ class NPCMind(server.Mind):
                 self.goals.insert(i+1,goal)
                 return
         self.goals.insert(0,goal)
+        
+    def update_goal(self, goal, str_goal):
+        new_goal = self.create_goal(goal.key, str_goal)
+        new_goal.id = goal.id
+        #We need to handle the case where a goal which had a trigger is replaced by one
+        #that hasn't, and the opposite
+        if hasattr(goal,"trigger"):
+            dictlist.remove_value(self.trigger_goals, goal)
+            self.insert_goal(new_goal, goal.id)
+        else:
+            if hasattr(new_goal,"trigger"):
+                self.goals.remove(goal)
+                self.insert_goal(new_goal, goal.id)
+            else:
+                index=self.goals.index(goal)
+                self.goals[index] = new_goal
+        
+        
+    def create_goal(self, name, str_goal):
+        #CHEAT!: remove eval (this and later)
+        goal=eval("mind.goals."+str_goal)
+        if const.debug_thinking:
+            goal.debug=1
+        goal.str=str_goal
+        if type(name)==StringType: goal.key=eval(name)
+        else: goal.key=name
+        return goal
+    def remove_goal(self, goal):
+        """Removes a goal."""
+        if hasattr(goal,"trigger"):
+            dictlist.remove_value(self.trigger_goals, goal)
+        else:
+            self.goals.remove(goal)
+        
     def fulfill_goals(self,time):
         "see if all goals are fulfilled: if not try to fulfill them"
         for g in self.goals[:]:
             if g.irrelevant:
                 self.goals.remove(g)
                 continue
-            res=g.check_goal(self,time)
-            if res: return res
+            #Don't process goals which have had three errors in them.
+            #The idea is to allow for some leeway in goal processing, but to punish repeat offenders.
+            if g.errors > 3:
+                continue
+            try:
+                res=g.check_goal(self,time)
+                if res: return res
+            except:
+                stacktrace=traceback.format_exc()
+                g.errors += 1
+                g.lastError=stacktrace
+                #If there's an error, print to the log, mark the goal, and continue with the next goal
+                #Some goals have a "str" attribute which represents the constructor; if so use that
+                if hasattr(g, "str"):
+                    goalstring=g.str
+                else:
+                    goalstring=g.__class__.__name__
+                print "Error in NPC with id " + self.id + " when checking goal " + goalstring + "\n" + stacktrace
+                continue
             # if res!=None: return res
     def teach_children(self, child):
         res=Oplist()
@@ -524,10 +797,10 @@ class NPCMind(server.Mind):
     ########## thinking (needs rewrite)
     def think(self):
         if const.debug_thinking:
-            log.thinking("think: "+str(self))
+            log.thinking("think: "+str(self.id))
         output=self.fulfill_goals(self.time)
-        if output and const.debug_thinking:
-            log.thinking(str(self)+" result at "+str(self.time)+": "+output[-1][0].description)
+#        if output and const.debug_thinking:
+#            log.thinking(str(self)+" result at "+str(self.time)+": "+output[-1][0].description)
         return output
     ########## communication: here send it locally
     def send(self, op):
