@@ -38,6 +38,8 @@ class move_me(Goal):
         return location_
     def am_I_at_loc(self, me):
         location=self.get_location_instance(me)
+        if me.location is None:
+            return 1
         if not location:
             #print "No location"
             return 1
@@ -233,7 +235,7 @@ class move_me_to_possession(Goal):
 
 class move_me_to_focus(Goal):
     """Move me to something I am interested in."""
-    def __init__(self, what):
+    def __init__(self, what, distance=2):
         Goal.__init__(self,"move me to this thing",
                       self.am_i_at_it,
                       [self.move_me_to_it])
@@ -241,7 +243,9 @@ class move_me_to_focus(Goal):
             self.what = what
         else:
             self.what = [ what ]
-        self.vars=["what"]
+        #How close we need to get to the thing.
+        self.distance=distance
+        self.vars=["what", "distance"]
     def am_i_at_it(self, me):
         for what in self.what:
             id = me.get_knowledge('focus', what)
@@ -250,7 +254,13 @@ class move_me_to_focus(Goal):
             if thing == None:
                 me.remove_knowledge('focus', what)
                 continue
-            if square_horizontal_distance(me.location, thing.location) < 4:
+            
+            #Only move to the edge of the entity, since else we'll just collide with it.
+            #TODO: Make this check better, taking into account the real collision volume, rotated and all.
+            bbox_size = thing.location.bbox.square_horizontal_bounding_radius()
+            #TODO: Add a check for solid and non solid entities.
+            #When moving to a non solid entity, we should try to get at its center.
+            if square_horizontal_distance(me.location, thing.location) < ((self.distance * self.distance) + bbox_size):
                 return 1
         return 0
 
@@ -267,6 +277,66 @@ class move_me_to_focus(Goal):
                 target.velocity=me.location.coordinates.unit_vector_to(target.coordinates)
                 return Operation("move", Entity(me.id, location=target))
 
+
+class move_me_near_focus(Goal):
+    """Move me to something I am interested in, first really close, and the allowing movement within a certain radius."""
+    def __init__(self, what, distance=2, allowed_movement_radius=10):
+        Goal.__init__(self,"move me near this thing",
+                      self.am_i_at_it,
+                      [self.move_me_to_it])
+        if type(what) == types.ListType:
+            self.what = what
+        else:
+            self.what = [ what ]
+        #The radius within which we're allowed movement.
+        self.allowed_movement_radius = allowed_movement_radius
+        #How close we need to get to the thing.
+        self.distance=distance
+        self.vars=["what", "distance", "allowed_movement_radius"]
+        #Keeps track of if we're close enough to a thing to consider us near it.
+        #If this is true, i.e. we're near a thing, we consider this goal fulfilled as long as we're within the allowed_movement_radius
+        self.is_close_to_thing=False
+    def am_i_at_it(self, me):
+        for what in self.what:
+            id = me.get_knowledge('focus', what)
+            if id == None: continue
+            thing = me.map.get(id)
+            if thing == None:
+                me.remove_knowledge('focus', what)
+                continue
+            
+            #Only move to the edge of the entity, since else we'll just collide with it.
+            #TODO: Make this check better, taking into account the real collision volume, rotated and all.
+            bbox_size = thing.location.bbox.square_horizontal_bounding_radius()
+            #TODO: Add a check for solid and non solid entities.
+            #When moving to a non solid entity, we should try to get at its center.
+            squared_distance_to_thing = square_horizontal_distance(me.location, thing.location)
+            if squared_distance_to_thing < ((self.distance * self.distance) + bbox_size):
+                self.is_close_to_thing=True
+                return 1
+            #If we've already moved close to the thing, we are allowed movement within a certain movement radius
+            if self.is_close_to_thing:
+                if squared_distance_to_thing < ((self.allowed_movement_radius * self.allowed_movement_radius) + bbox_size):
+                    return 1
+        self.is_close_to_thing=False
+        return 0
+
+    def move_me_to_it(self, me):
+        for what in self.what:
+            id = me.get_knowledge('focus', what)
+            if id == None:
+                continue
+            thing = me.map.get(id)
+            if thing == None:
+                me.remove_knowledge('focus', what)
+                return
+            target=thing.location.copy()
+            if target.parent.id==me.location.parent.id:
+                target.velocity=me.location.coordinates.unit_vector_to(target.coordinates)
+                return Operation("move", Entity(me.id, location=target))
+
+
+
 ############################ MOVE THING TO ME ####################################
 
 class pick_up_possession(Goal):
@@ -340,15 +410,14 @@ class pick_up_focus(Goal):
 class wander(Goal):
     """Move in a non-specific way."""
     def __init__(self):
-        Goal.__init__(self,"wander randomly",false,[self.do_wandering])
+        Goal.__init__(self,"wander randomly",false,
+                      [move_me(None),
+                       self.do_wandering])
     def do_wandering(self, me):
-        #copied from build_home.find_place, but changed max amount to -5,5
         loc = me.location.copy()
         loc.coordinates=Point3D(map(lambda c:c+uniform(-5,5),
                                      loc.coordinates))
-        ent=Entity(me,location=loc)
-        return Operation("move",ent)
-
+        self.subgoals[0].location = loc
 
 ############################ WANDER & SEARCH ############################
 
@@ -423,18 +492,18 @@ class hunt_for(pursuit):
         square_dist = square_distance(me.location, thing.location)
         return square_dist < self.square_proximity
 
-################################ HUNT ################################
+################################ PATROL ##############################
 
 class patrol(Goal):
     """Move around an area defined by some waypoints."""
-    def __init__(self, whlist):
+    def __init__(self, locations):
         Goal.__init__(self, "patrol an area",
                       false,
-                      [move_me(whlist[0]),
+                      [move_me(locations[0]),
                        self.increment])
-        self.list = whlist
+        self.list = locations
         self.stage = 0
-        self.count = len(whlist)
+        self.count = len(locations)
         self.vars = ["stage", "list"]
     def increment(self, me):
         self.stage = self.stage + 1
@@ -489,3 +558,27 @@ class accompany(Goal):
             #print "We must be close - stop"
             target.velocity = Vector3D(0,0,0)
         return Operation("move", Entity(me.id, location=target))
+
+############################ ROAM ####################################
+
+class roam(Goal):
+    """Move in a non-specific way within one or many locations."""
+    def __init__(self, radius, locations):
+        Goal.__init__(self,"roam randomly",false,
+                      [move_me(None),
+                       self.do_roaming])
+        self.list = locations
+        self.radius = radius
+        self.count = len(locations)
+        self.vars = ["radius", "list"]
+    def do_roaming(self, me):
+        move_me_goal = self.subgoals[0]
+        #We need to set a new direction if we've either haven't set one, or if we've arrived.
+        if move_me_goal.location == None or move_me_goal.fulfilled(me) == True:
+            waypointName = self.list[randint(0, self.count - 1  )]
+            waypoint = me.get_knowledge("location",waypointName)
+            
+            loc = me.location.copy()
+            loc.coordinates=Point3D(map(lambda c:c+uniform(-self.radius,self.radius),
+                                         waypoint.coordinates))
+            move_me_goal.location = loc
