@@ -15,19 +15,19 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 6fd48231e5d475157bc437d8be0fd1dd8f144405 $
 
 #include "Account.h"
 
 #include "Connection.h"
 #include "ServerRouting.h"
 #include "Lobby.h"
-#include "ExternalMind.h"
+#include "rulesets/ExternalMind.h"
 #include "Persistence.h"
 #include "TeleportAuthenticator.h"
 
 #include "rulesets/Character.h"
 
+#include "common/BaseWorld.h"
 #include "common/id.h"
 #include "common/log.h"
 #include "common/const.h"
@@ -71,7 +71,7 @@ Account::Account(Connection * conn,
                  const std::string & passwd,
                  const std::string & id,
                  long intId) :
-         ConnectedRouter(id, intId, conn),
+         ConnectableRouter(id, intId, conn),
          m_username(uname), m_password(passwd)
 {
 }
@@ -86,7 +86,7 @@ Account::~Account()
 void Account::characterDestroyed(long id)
 {
     m_charactersDict.erase(id);
-    if (consts::enable_persistence) {
+    if (database_flag && isPersisted()) {
         Persistence::instance()->delCharacter(String::compose("%1", id));
     }
 }
@@ -95,18 +95,19 @@ void Account::characterDestroyed(long id)
 ///
 /// \brief chr The character to connect to this account
 /// \return Returns 0 on success and -1 on failure.
-int Account::connectCharacter(Entity *chr)
+int Account::connectCharacter(LocatedEntity *chr)
 {
     Character * character = dynamic_cast<Character *>(chr);
     if (character != 0) {
-        m_connection->connectAvatar(character);
+        character->linkExternal(m_connection);
+
         // Only genuinely playable characters should go in here. Otherwise
         // if a normal entity gets into the account, and connection, it
         // starts getting hard to tell whether or not they exist.
         m_charactersDict[chr->getIntId()] = chr;
         chr->destroyed.connect(sigc::bind(sigc::mem_fun(this, &Account::characterDestroyed), chr->getIntId()));
         m_connection->addEntity(chr);
-        if (consts::enable_persistence) {
+        if (database_flag && isPersisted()) {
             Persistence::instance()->addCharacter(*this, *chr);
         }
         return 0;
@@ -117,7 +118,7 @@ int Account::connectCharacter(Entity *chr)
 /// \brief Add a Character to those that belong to this Account
 ///
 /// @param chr Character object to be adddded
-void Account::addCharacter(Entity * chr)
+void Account::addCharacter(LocatedEntity * chr)
 {
     Character * pchar = dynamic_cast<Character *>(chr);
     if (pchar == 0) {
@@ -131,16 +132,16 @@ void Account::addCharacter(Entity * chr)
 ///
 /// @param typestr The type name of the Character to be created
 /// @param ent Atlas description of the Character to be created
-Entity * Account::addNewCharacter(const std::string & typestr,
-                                  const RootEntity & ent,
-                                  const Root & arg)
+LocatedEntity * Account::addNewCharacter(const std::string & typestr,
+                                         const RootEntity & ent,
+                                         const Root & arg)
 {
     if (m_connection == 0) {
         return 0;
     }
     BaseWorld & world = m_connection->m_server.m_world;
     debug(std::cout << "Account::Add_character" << std::endl << std::flush;);
-    Entity * chr;
+    LocatedEntity * chr;
     Element spawn;
     if (arg->copyAttr("spawn_name", spawn) == 0 && spawn.isString()) {
         chr = world.spawnNewEntity(spawn.String(), typestr, ent);
@@ -192,11 +193,17 @@ const char * Account::getType() const
 
 void Account::store() const
 {
-    if (database_flag) {
+    if (database_flag && isPersisted()) {
         Persistence::instance()->putAccount(*this);
     }
 }
 
+bool Account::isPersisted() const
+{
+    return true;
+}
+
+
 void Account::addToMessage(MapType & omap) const
 {
     omap["username"] = m_username;
@@ -249,9 +256,28 @@ void Account::addToEntity(const Atlas::Objects::Entity::RootEntity & ent) const
     ent->setId(getId());
 }
 
+void Account::externalOperation(const Operation & op, Link &)
+{
+    assert(m_connection != 0);
+    OpVector reply;
+    long serialno = op->getSerialno();
+    operation(op, reply);
+    OpVector::const_iterator Iend = reply.end();
+    for(OpVector::const_iterator I = reply.begin(); I != Iend; ++I) {
+        if (!op->isDefaultSerialno()) {
+            // Should we respect existing refnos?
+            if ((*I)->isDefaultRefno()) {
+                (*I)->setRefno(serialno);
+            }
+        }
+        // FIXME detect socket failure here
+        m_connection->send(*I);
+    }
+}
+
 void Account::operation(const Operation & op, OpVector & res)
 {
-    const OpNo op_no = op->getClassNo();
+    auto op_no = op->getClassNo();
     switch (op_no) {
         case Atlas::Objects::Operation::CREATE_NO:
             CreateOperation(op, res);
@@ -305,7 +331,7 @@ void Account::createObject(const std::string & type_str,
                            const Operation & op,
                            OpVector & res)
 {
-    if (characterError(op, arg, res)) {
+    if (characterError(op, arg, res) != 0) {
         return;
     }
 
@@ -320,7 +346,7 @@ void Account::createObject(const std::string & type_str,
         new_character->setName(arg->getName());
     }
 
-    Entity * entity = addNewCharacter(type_str, new_character, arg);
+    LocatedEntity * entity = addNewCharacter(type_str, new_character, arg);
 
     if (entity == 0) {
         error(op, "Character creation failed", res, getId());
@@ -405,7 +431,7 @@ void Account::SetOperation(const Operation & op, OpVector & res)
         return error(op, "Permission denied.", res, getId());
     }
 
-    Entity * e = J->second;
+    LocatedEntity * e = J->second;
     Anonymous new_arg;
     bool argument_valid = false;
     Element guise;
@@ -551,7 +577,7 @@ void Account::LookOperation(const Operation & op, OpVector & res)
     Element key;
     if (arg->copyAttr("possess_key", key) == 0 && key.isString()) {
         const std::string & key_str = key.String();
-        Entity *character;
+        LocatedEntity * character;
         character = TeleportAuthenticator::instance()->authenticateTeleport(to, key_str);
         // FIXME Not finding the character should be fatal
         // FIXME TA needs to generate clientError ops for the client
