@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: ad6f3d0e22716cefef7b7c8a161eeadba2275ad7 $
 
 #ifndef SERVER_ARITHMETIC_BUILDER_H
 #define SERVER_ARITHMETIC_BUILDER_H
@@ -23,7 +22,7 @@
 #include <string>
 
 class ArithmeticScript;
-class Entity;
+class LocatedEntity;
 
 /// \brief Builder to handle the creation of arithmetic objects
 class ArithmeticBuilder {
@@ -35,7 +34,7 @@ class ArithmeticBuilder {
     static ArithmeticBuilder * instance();
     static void del();
 
-    ArithmeticScript * newArithmetic(const std::string &, Entity *);
+    ArithmeticScript * newArithmetic(const std::string &, LocatedEntity *);
 };
 
 #endif // SERVER_ARITHMETIC_BUILDER_H
