@@ -15,19 +15,16 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: a5368d6544f9f203aa3a311f4550288509305152 $
 
 #include "Connection.h"
 
 #include "ServerRouting.h"
 #include "Lobby.h"
-#include "CommClient.h"
-#include "CommServer.h"
 #include "Player.h"
-#include "ExternalMind.h"
-#include "ExternalProperty.h"
 
 #include "rulesets/Character.h"
+#include "rulesets/ExternalMind.h"
+#include "rulesets/ExternalProperty.h"
 
 #include "common/id.h"
 #include "common/log.h"
@@ -55,6 +52,8 @@ using Atlas::Objects::Operation::Move;
 using Atlas::Objects::Operation::Update;
 using Atlas::Objects::Entity::Anonymous;
 
+using String::compose;
+
 static const bool debug_flag = false;
 
 Connection::Connection(CommSocket & socket,
@@ -95,12 +94,15 @@ Account * Connection::newAccount(const std::string & type,
     return new Player(this, username, hash, id, intId);
 }
 
+static const int hash_salt_size = 8;
+
 Account * Connection::addNewAccount(const std::string & type,
                                     const std::string & username,
                                     const std::string & password)
 {
     std::string hash;
-    encrypt_password(password, hash);
+    std::string salt = m_server.getShaker().generateSalt(hash_salt_size);
+    hash_password(password,salt,hash);
     std::string newAccountId;
 
     long intId = newId(newAccountId);
@@ -128,8 +130,9 @@ Account * Connection::addNewAccount(const std::string & type,
 void Connection::disconnectObject(RouterMap::iterator I,
                                   const std::string & event)
 {
-    ConnectedRouter * cr = dynamic_cast<ConnectedRouter *>(I->second);
+    ConnectableRouter * cr = dynamic_cast<ConnectableRouter *>(I->second);
     if (cr != 0) {
+        // FIXME assert that the connection pointer points to this
         cr->m_connection = 0;
         Account * ac = dynamic_cast<Account *>(cr);
         if (ac != 0) {
@@ -139,48 +142,28 @@ void Connection::disconnectObject(RouterMap::iterator I,
     }
     Character * chr = dynamic_cast<Character *>(I->second);
     if (chr != 0) {
-        if (chr->m_externalMind != 0) {
-            ExternalMind * mind = dynamic_cast<ExternalMind*>(chr->m_externalMind);
-            if (mind != 0 && mind->isLinkedTo(this)) {
-                // Send a move op stopping the current movement
-                Anonymous move_arg;
-                move_arg->setId(chr->getId());
-                // Include the EXTERNAL property which is changing to zero.
-                // It would be more correct at this point to send a separate
-                // update to have the property update itself, but this
-                // will be much less of an issue once Sight(Set) is created
-                // more correctly
-                move_arg->setAttr("external", 0);
-                ::addToEntity(Vector3D(0,0,0), move_arg->modifyVelocity());
-
-                Move move;
-                move->setFrom(chr->getId());
-                move->setArgs1(move_arg);
-                chr->externalOperation(move);
-
-                // We used to delete the external mind here, but now we
-                // leave it in place, as it takes care of the disconnected
-                // character.
-                mind->linkUp(0);
-                logEvent(DROP_CHAR, String::compose("%1 - %2 %4 character (%3)",
-                                                    getId(), chr->getId(),
-                                                    chr->getType()->name(),
-                                                    event));
-            } else if (mind != 0 && mind->isLinked()) {
-                log(ERROR, String::compose("Connection(%1) requested to "
-                                           "remove active character %2(%3) "
-                                           "which is subscribed to another "
-                                           "Connection(%4).", getId(),
-                                           chr->getType()->name(),
-                                           chr->getId(),
-                                           mind->connectionId()));
-            }
+        int taken = chr->unlinkExternal(this);
+        if (taken == 0) {
+            logEvent(DROP_CHAR, String::compose("%1 - %2 %4 character (%3)",
+                                                getId(), chr->getId(),
+                                                chr->getType()->name(),
+                                                event));
+        } else if (taken == -2) {
+            // FIXME This may not be an error if we allow IG entities
+            // to belong to multiple accounts
+            log(ERROR, String::compose("Connection(%1) requested to "
+                                       "remove active character %2(%3) "
+                                       "which is subscribed to another "
+                                       "Connection(%4).", getId(),
+                                       chr->getType()->name(),
+                                       chr->getId(),
+                                       chr->m_externalMind->connectionId()));
         }
     }
     return;
 }
 
-void Connection::addEntity(Entity * ent)
+void Connection::addEntity(LocatedEntity * ent)
 {
     addObject(ent);
     ent->destroyed.connect(sigc::bind(sigc::mem_fun(this,
@@ -205,39 +188,6 @@ void Connection::objectDeleted(long id)
     removeObject(id);
 }
 
-void Connection::connectAvatar(Character * chr)
-{
-    ExternalMind * mind = 0;
-    if (chr->m_externalMind != 0) {
-        mind = dynamic_cast<ExternalMind*>(chr->m_externalMind);
-    }
-    if (mind == 0) {
-        chr->m_externalMind = mind = new ExternalMind(*chr);
-    }
-
-    if (mind->isLinked()) {
-        log(ERROR, "Character is already connected.");
-        return;
-    }
-    mind->linkUp(this);
-
-    if (chr->getProperty("external") == 0) {
-        ExternalProperty * ep = new ExternalProperty(chr->m_externalMind);
-        // FIXME ensure this is install()ed and apply()ed
-        chr->setProperty("external", ep);
-    }
-
-    Anonymous update_arg;
-    update_arg->setId(chr->getId());
-    update_arg->setAttr("external", 1);
-
-    Update update;
-    update->setTo(chr->getId());
-    update->setArgs1(update_arg);
-
-    chr->sendWorld(update);
-}
-
 int Connection::verifyCredentials(const Account & account,
                                   const Root & creds) const
 {
@@ -250,30 +200,26 @@ int Connection::verifyCredentials(const Account & account,
     return check_password(passwd, account.password());
 }
 
-void Connection::operation(const Operation & op, OpVector & res)
+
+void Connection::externalOperation(const Operation & op, Link & link)
 {
-    debug(std::cout << "Connection::operation" << std::endl << std::flush;);
-    if (!op->hasAttrFlag(Atlas::Objects::Operation::FROM_FLAG)) {
+    debug(std::cout << "Connection::externalOperation"
+                    << std::endl << std::flush;);
+    if (op->isDefaultFrom()) {
         debug(std::cout << "deliver locally" << std::endl << std::flush;);
-        const OpNo op_no = op->getClassNo();
-        switch (op_no) {
-            case Atlas::Objects::Operation::CREATE_NO:
-                CreateOperation(op, res);
-                break;
-            case Atlas::Objects::Operation::GET_NO:
-                GetOperation(op, res);
-                break;
-            case Atlas::Objects::Operation::LOGIN_NO:
-                LoginOperation(op, res);
-                break;
-            case Atlas::Objects::Operation::LOGOUT_NO:
-                LogoutOperation(op, res);
-                break;
-            case OP_INVALID:
-                break;
-            default:
-                error(op, "Unknown operation", res);
-                break;
+        OpVector reply;
+        long serialno = op->getSerialno();
+        operation(op, reply);
+        OpVector::const_iterator Iend = reply.end();
+        for(OpVector::const_iterator I = reply.begin(); I != Iend; ++I) {
+            if (!op->isDefaultSerialno()) {
+                // Should we respect existing refnos?
+                if ((*I)->isDefaultRefno()) {
+                    (*I)->setRefno(serialno);
+                }
+            }
+            // FIXME detect socket failure here
+            send(*I);
         }
         return;
     }
@@ -281,41 +227,37 @@ void Connection::operation(const Operation & op, OpVector & res)
     debug(std::cout << "send on to " << from << std::endl << std::flush;);
     RouterMap::const_iterator I = m_objects.find(integerId(from));
     if (I == m_objects.end()) {
-        error(op, String::compose("Client \"%1\" op from \"%2\" is from "
-                                  "non-existant object.",
-                                  op->getParents().front(), from),
-              res);
+        sendError(op, String::compose("Client \"%1\" op from \"%2\" is from "
+                                      "non-existant object.",
+                                      op->getParents().front(), from), from);
         return;
     }
-    Router * obj = I->second;
-    Entity * ig_ent = dynamic_cast<Entity *>(obj);
-    if (ig_ent == NULL) {
-        obj->operation(op, res);
-        return;
-    }
-    Character * chr = dynamic_cast<Character *>(obj);
-    if (chr != NULL) {
-        ExternalMind * mind = 0;
-        if (chr->m_externalMind != 0) {
-            mind = dynamic_cast<ExternalMind*>(chr->m_externalMind);
-        }
-        if (mind == 0 || !mind->isLinked()) {
-            debug(std::cout << "Subscribing existing character" << std::endl
-                            << std::flush;);
-            connectAvatar(chr);
-            Info info;
-            Anonymous info_arg;
-            chr->addToEntity(info_arg);
-            info->setArgs1(info_arg);
+    I->second->externalOperation(op, link);
+}
 
-            res.push_back(info);
-
-            logEvent(TAKE_CHAR, String::compose("%1 - %2 Taken character (%3)",
-                                                getId(), ig_ent->getId(),
-                                                ig_ent->getType()));
-        }
+void Connection::operation(const Operation & op, OpVector & res)
+{
+    debug(std::cout << "Connection::operation" << std::endl << std::flush;);
+    auto op_no = op->getClassNo();
+    switch (op_no) {
+        case Atlas::Objects::Operation::CREATE_NO:
+            CreateOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::GET_NO:
+            GetOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::LOGIN_NO:
+            LoginOperation(op, res);
+            break;
+        case Atlas::Objects::Operation::LOGOUT_NO:
+            LogoutOperation(op, res);
+            break;
+        case OP_INVALID:
+            break;
+        default:
+            error(op, "Unknown operation", res);
+            break;
     }
-    ig_ent->externalOperation(op);
 }
 
 void Connection::LoginOperation(const Operation & op, OpVector & res)
@@ -507,41 +449,43 @@ void Connection::disconnectAccount(Account * ac,
     EntityDict::const_iterator J = ac->getCharacters().begin();
     EntityDict::const_iterator Jend = ac->getCharacters().end();
     for (; J != Jend; ++J) {
-        Entity * chr = J->second;
-        Character * character = dynamic_cast<Character *>(chr);
-        if (character != 0) {
-            if (character->m_externalMind != 0) {
-                ExternalMind * em = dynamic_cast<ExternalMind *>(character->m_externalMind);
-                if (em == 0) {
-                    log(ERROR, String::compose("Character %1(%2) has "
-                                               "external mind object which "
-                                               "is not an ExternalMind",
-                                               chr->getType(),
-                                               chr->getId()));
-                } else {
-                    if (!em->isLinked()) {
-                        log(ERROR,
-                            String::compose("Connection(%1) has found a "
-                                            "character in its dictionery "
-                                            "which is not connected.",
-                                            getId()));
-                        removeObject(chr->getIntId());
-                    } else if (!em->isLinkedTo(this)) {
-                        log(ERROR,
-                            String::compose("Connection(%1) has found a "
-                                            "character in its dictionery "
-                                            "which is connected to another "
-                                            "Connection(%2)", getId(),
-                                            em->connectionId()));
-                        removeObject(chr->getIntId());
-                    }
+        LocatedEntity * ent = J->second;
+        Character * chr = dynamic_cast<Character *>(ent);
+        // This code removes from this connection any of the accounts IG
+        // entities, except one which is currently in use by this connection.
+        // IE A player can log out their account, but continue using their
+        // exisiting character. The only case where removeObject() is not
+        // called is if the character has an external mind linked to this
+        // connection.
+        if (chr != 0) {
+            if (chr->m_externalMind != 0) {
+                if (!chr->m_externalMind->isLinked()) {
+                    // FIXME This is probably not an error. This can happen
+                    // if the account used this character in a previous
+                    // session, but not in this one. The ExternalMind gets
+                    // left behind, but would not be linked if it wasn't used
+                    // this time.
+                    log(ERROR, compose("Connection(%1) has found a "
+                                       "character in its dictionery "
+                                       "which is not connected.",
+                                       getId()));
+                    removeObject(ent->getIntId());
+                } else if (!chr->m_externalMind->isLinkedTo(this)) {
+                    // FIXME This is not an error _if_ we allow IG entities
+                    // to be owned by multiple accounts.
+                    log(ERROR, compose("Connection(%1) has found a "
+                                       "character in its dictionery "
+                                       "which is connected to another "
+                                       "Connection(%2)", getId(),
+                                       chr->m_externalMind->connectionId()));
+                    removeObject(ent->getIntId());
                 }
             } else {
-                removeObject(chr->getIntId());
+                removeObject(ent->getIntId());
             }
         } else {
             // Non character entity
-            removeObject(chr->getIntId());
+            removeObject(ent->getIntId());
         }
     }
 }
