@@ -15,12 +15,9 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: a089b453a0a4a4e060ec4842a973d8057315d895 $
 
 #include "EntityFactory_impl.h"
 
-#include "rulesets/Entity.h"
-#include "rulesets/Thing.h"
 #include "rulesets/Character.h"
 #include "rulesets/Creator.h"
 #include "rulesets/Plant.h"
@@ -30,7 +27,8 @@
 using Atlas::Message::MapType;
 
 template <>
-Entity * EntityFactory<World>::newEntity(const std::string & id, long intId)
+LocatedEntity * EntityFactory<World>::newEntity(const std::string & id,
+                                                long intId)
 {
     return 0;
 }
