@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 3df5fdf48bcf0573c79077592305ce7d57a2465a $
 
 #ifndef SERVER_ENTITY_FACTORY_H
 #define SERVER_ENTITY_FACTORY_H
@@ -31,7 +30,7 @@ class EntityFactory : public EntityKit {
     EntityFactory();
     virtual ~EntityFactory();
 
-    virtual Entity * newEntity(const std::string & id, long intId);
+    virtual LocatedEntity * newEntity(const std::string & id, long intId);
     virtual EntityKit * duplicateFactory();
 };
 
