@@ -15,14 +15,17 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: dcf30355d7f73a51eb49a8244509fe5fcc891a20 $
 
 #include "StorageManager.h"
 
 #include "WorldRouter.h"
 #include "EntityBuilder.h"
+#include "MindInspector.h"
+#include "CommServer.h"
 
-#include "rulesets/Entity.h"
+#include "rulesets/LocatedEntity.h"
+#include "rulesets/Character.h"
+#include "rulesets/MindProperty.h"
 
 #include "common/Database.h"
 #include "common/TypeNode.h"
@@ -34,8 +37,14 @@
 #include "common/log.h"
 #include "common/compose.hpp"
 #include "common/Variable.h"
+#include "common/custom.h"
+#include "common/Think.h"
+#include "common/Commune.h"
+#include "common/SystemTime.h"
 
 #include <Atlas/Objects/Anonymous.h>
+#include <Atlas/Objects/Operation.h>
+#include <Atlas/Message/Element.h>
 
 #include <wfmath/atlasconv.h>
 
@@ -54,6 +63,7 @@ typedef Database::KeyValues KeyValues;
 static const bool debug_flag = false;
 
 StorageManager:: StorageManager(WorldRouter & world) :
+        m_mindInspector(nullptr),
       m_insertEntityCount(0), m_updateEntityCount(0),
       m_insertPropertyCount(0), m_updatePropertyCount(0),
       m_insertQps(0), m_updateQps(0),
@@ -62,6 +72,10 @@ StorageManager:: StorageManager(WorldRouter & world) :
       m_insertQpsIndex(0), m_updateQpsIndex(0)
 {
     if (database_flag) {
+
+        m_mindInspector = new MindInspector();
+        m_mindInspector->ThoughtsReceived.connect(sigc::mem_fun(*this, &StorageManager::thoughtsReceived));
+
         world.inserted.connect(sigc::mem_fun(this,
               &StorageManager::entityInserted));
 
@@ -91,8 +105,13 @@ StorageManager:: StorageManager(WorldRouter & world) :
     }
 }
 
+StorageManager::~StorageManager()
+{
+    delete m_mindInspector;
+}
+
 /// \brief Called when a new Entity is inserted in the world
-void StorageManager::entityInserted(Entity * ent)
+void StorageManager::entityInserted(LocatedEntity * ent)
 {
     if (ent->getFlags() & (entity_ephem)) {
         // This entity is not persisted.
@@ -105,6 +124,7 @@ void StorageManager::entityInserted(Entity * ent)
         // signal will be connected later once the initial database insert
         // has been done.
         ent->updated.connect(sigc::bind(sigc::mem_fun(this, &StorageManager::entityUpdated), ent));
+        ent->containered.connect(sigc::bind(sigc::mem_fun(this, &StorageManager::entityContainered), ent));
         return;
     }
     // Queue the entity to be inserted into the persistence tables.
@@ -113,7 +133,7 @@ void StorageManager::entityInserted(Entity * ent)
 }
 
 /// \brief Called when an Entity is modified
-void StorageManager::entityUpdated(Entity * ent)
+void StorageManager::entityUpdated(LocatedEntity * ent)
 {
     if (ent->isDestroyed()) {
         m_destroyedEntities.push_back(ent->getIntId());
@@ -131,6 +151,11 @@ void StorageManager::entityUpdated(Entity * ent)
     ent->setFlags(entity_queued);
 }
 
+void StorageManager::entityContainered(const LocatedEntity *oldLocation, LocatedEntity *entity)
+{
+    entityUpdated(entity);
+}
+
 void StorageManager::encodeProperty(PropertyBase * prop, std::string & store)
 {
     Atlas::Message::MapType map;
@@ -138,7 +163,7 @@ void StorageManager::encodeProperty(PropertyBase * prop, std::string & store)
     Database::instance()->encodeObject(map, store);
 }
 
-void StorageManager::restoreProperties(Entity * ent)
+void StorageManager::restoreProperties(LocatedEntity * ent)
 {
     Database * db = Database::instance();
     PropertyManager * pm = PropertyManager::instance();
@@ -178,15 +203,71 @@ void StorageManager::restoreProperties(Entity * ent)
         const TypeNode * type = ent->getType();
         assert(type != 0);
         if (type->defaults().find(name) == type->defaults().end()) {
-            prop->install(ent);
+            prop->install(ent, name);
         }
         prop->apply(ent);
     }
     // Iterate over res and create the property values.
 }
 
+void StorageManager::restoreThoughts(LocatedEntity * ent)
+{
+    Database * db = Database::instance();
+    const DatabaseResult res = db->selectThoughts(ent->getId());
+    Atlas::Message::ListType thoughts_data;
 
-void StorageManager::insertEntity(Entity * ent)
+    DatabaseResult::const_iterator I = res.begin();
+    DatabaseResult::const_iterator Iend = res.end();
+    for (; I != Iend; ++I) {
+        const std::string thought = I.column("thought");
+        if (thought.empty()) {
+            log(ERROR,
+                    compose("No thought column in property row for %1",
+                            ent->getId()));
+            continue;
+        }
+        MapType thought_data;
+        db->decodeMessage(thought, thought_data);
+        thoughts_data.push_back(thought_data);
+    }
+
+    if (!thoughts_data.empty()) {
+        OpVector opRes;
+
+        Atlas::Objects::Operation::Think thoughtOp;
+        thoughtOp->setArgsAsList(thoughts_data);
+        //Make the thought come from the entity itself
+        thoughtOp->setTo(ent->getId());
+        thoughtOp->setFrom(ent->getId());
+
+        ent->sendWorld(thoughtOp);
+    }
+}
+
+bool StorageManager::storeThoughts(LocatedEntity * ent)
+{
+    if (ent->getFlags() & (entity_ephem)) {
+        // This entity is not persisted.
+        return false;
+    }
+    //Check if the entity has a mind. Perhaps do this in another way than using dynamic cast?
+    Character* character = dynamic_cast<Character*>(ent);
+    if (character) {
+
+        const MindProperty* mindProperty = character->getPropertyClass<MindProperty>("mind");
+        if (mindProperty) {
+            if (mindProperty->isMindEnabled()) {
+                m_mindInspector->queryEntityForThoughts(character->getId());
+                m_outstandingThoughtRequests.insert(character->getId());
+                return true;
+            }
+        }
+    }
+    return false;
+}
+
+
+void StorageManager::insertEntity(LocatedEntity * ent)
 {
     std::string location;
     Atlas::Message::MapType map;
@@ -221,9 +302,11 @@ void StorageManager::insertEntity(Entity * ent)
     ent->resetFlags(entity_queued);
     ent->setFlags(entity_clean | entity_pos_clean | entity_orient_clean);
     ent->updated.connect(sigc::bind(sigc::mem_fun(this, &StorageManager::entityUpdated), ent));
+    ent->containered.connect(sigc::bind(sigc::mem_fun(this, &StorageManager::entityContainered), ent));
+
 }
 
-void StorageManager::updateEntity(Entity * ent)
+void StorageManager::updateEntity(LocatedEntity * ent)
 {
     std::string location;
     Atlas::Message::MapType map;
@@ -233,9 +316,17 @@ void StorageManager::updateEntity(Entity * ent)
     }
     Database::instance()->encodeObject(map, location);
 
-    Database::instance()->updateEntity(ent->getId(),
+    //Under normal circumstances only the top world won't have a location.
+    if (ent->m_location.m_loc) {
+        Database::instance()->updateEntity(ent->getId(),
+                                       ent->getSeq(),
+                                       location,
+                                       ent->m_location.m_loc->getId());
+    } else {
+        Database::instance()->updateEntityWithoutLoc(ent->getId(),
                                        ent->getSeq(),
                                        location);
+    }
     ++m_updateEntityCount;
     KeyValues new_property_tuples;
     KeyValues upd_property_tuples;
@@ -269,7 +360,7 @@ void StorageManager::updateEntity(Entity * ent)
     ent->setFlags(entity_clean);
 }
 
-void StorageManager::restoreChildren(Entity * parent)
+void StorageManager::restoreChildren(LocatedEntity * parent)
 {
     Database * db = Database::instance();
     DatabaseResult res = db->selectEntities(parent->getId());
@@ -284,7 +375,7 @@ void StorageManager::restoreChildren(Entity * parent)
         const int int_id = forceIntegerId(id);
         const std::string type = I.column("type");
         Atlas::Objects::Entity::Anonymous attrs;
-        Entity * child = eb->newEntity(id, int_id, type, attrs, BaseWorld::instance());
+        LocatedEntity * child = eb->newEntity(id, int_id, type, attrs, BaseWorld::instance());
         if (!child) {
             log(ERROR, compose("Could not restore entity with id %1 of type %2"
                     ", most likely caused by this type missing.",
@@ -306,8 +397,34 @@ void StorageManager::restoreChildren(Entity * parent)
         child->m_location.m_loc = parent;
         child->setFlags(entity_clean | entity_pos_clean | entity_orient_clean);
         BaseWorld::instance().addEntity(child);
-        restoreChildren(child);
+        //Restore properties before we restore children, so that any mind instances are set up to listen correctly.
         restoreProperties(child);
+        restoreChildren(child);
+
+
+        //We must send a sight op to the entity informing it of itself before we send any thoughts.
+        //Else the mind won't have any information about itself.
+        {
+            Atlas::Objects::Operation::Sight sight;
+            sight->setTo(child->getId());
+            Atlas::Objects::Entity::Anonymous args;
+            child->addToEntity(args);
+            sight->setArgs1(args);
+            child->sendWorld(sight);
+        }
+        //We should also send a sight op to the parent entity which owns the entity.
+        //TODO: should this really be necessary or should we rely on other Sight functionality?
+        {
+            Atlas::Objects::Operation::Sight sight;
+            sight->setTo(parent->getId());
+            Atlas::Objects::Entity::Anonymous args;
+            child->addToEntity(args);
+            sight->setArgs1(args);
+            parent->sendWorld(sight);
+        }
+
+        restoreThoughts(child);
+
     }
 }
 
@@ -366,8 +483,8 @@ void StorageManager::tick()
     m_insertQpsAvg = m_insertQps / 32;
     m_insertQpsNow = insert_queries;
 
-    debug(std::cout << "Ins: " << insert_queries << ", " << m_insertQps / 32
-                    << std::endl << std::flush;);
+    debug(if (insert_queries) { std::cout << "Ins: " << insert_queries << ", " << m_insertQps / 32
+                    << std::endl << std::flush;});
 
     int update_queries = m_updateEntityCount + m_updatePropertyCount 
                          - old_update_queries;
@@ -381,13 +498,42 @@ void StorageManager::tick()
     m_updateQpsAvg = m_updateQps / 32;
     m_updateQpsNow = update_queries;
 
-    debug(std::cout << "Ups: " << update_queries << ", " << m_updateQps / 32
-                    << std::endl << std::flush;);
+    debug(if (update_queries) { std::cout << "Ups: " << update_queries << ", " << m_updateQps / 32
+                    << std::endl << std::flush;});
+}
+
+void StorageManager::thoughtsReceived(const std::string& entityId, const Operation& op)
+{
+    m_outstandingThoughtRequests.erase(entityId);
+    //Note that the received operation originated from an external mind, so we must
+    // treat it as unsafe.
+    if (op->getClassNo() == Atlas::Objects::Operation::THINK_NO) {
+        Database * db = Database::instance();
+        std::vector<std::string> thoughtsList;
+        Atlas::Message::ListType thoughts = op->getArgsAsList();
+        for (auto& thoughtElement : thoughts) {
+            if (thoughtElement.isMap()) {
+                std::string value;
+                db->encodeObject(thoughtElement.asMap(), value);
+                thoughtsList.push_back(value);
+            }
+        }
+        db->replaceThoughts(entityId, thoughtsList);
+    } else if (op->getClassNo()
+            == Atlas::Objects::Operation::ROOT_OPERATION_NO) {
+        //A RootOperation indicates that the relay timed out; we'll just ignore it
+    } else {
+        log(WARNING,
+                String::compose(
+                        "Got response to a Commune request from mind %1 with an operation of type %2. This could signal a malicious client.",
+                        op->getFrom(), op->getParents().front()));
+    }
+
 }
 
 int StorageManager::initWorld()
 {
-    Entity * ent = &BaseWorld::instance().m_gameWorld;
+    LocatedEntity * ent = &BaseWorld::instance().m_gameWorld;
 
     ent->updated.connect(sigc::bind(sigc::mem_fun(this, &StorageManager::entityUpdated), ent));
     ent->setFlags(entity_clean);
@@ -397,11 +543,47 @@ int StorageManager::initWorld()
 
 int StorageManager::restoreWorld()
 {
-    Entity * ent = &BaseWorld::instance().m_gameWorld;
-
-    restoreChildren(ent);
+    LocatedEntity * ent = &BaseWorld::instance().m_gameWorld;
 
     restoreProperties(ent);
 
+    restoreChildren(ent);
+
     return 0;
 }
+
+int StorageManager::shutdown(bool& exit_flag, const std::map<long, LocatedEntity *>& entites)
+{
+    tick();
+    while (Database::instance()->queryQueueSize()) {
+        //Allow for any user to abort the process.
+        if(exit_flag) {
+            log(NOTICE, "Aborted entity persisting. This might lead to lost entities.");
+            return 0;
+        }
+        if (!Database::instance()->queryInProgress()) {
+            Database::instance()->launchNewQuery();
+        } else {
+            Database::instance()->clearPendingQuery();
+        }
+    }
+    return 0;
+}
+
+size_t StorageManager::requestMinds(const std::map<long, LocatedEntity *>& entites)
+{
+    size_t requests = 0;
+    for (auto& pair : entites) {
+        if (storeThoughts(pair.second)) {
+            requests++;
+        }
+    }
+    return requests;
+}
+
+
+size_t StorageManager::numberOfOutstandingThoughtRequests() const
+{
+    return m_outstandingThoughtRequests.size();
+}
+
