@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 37911229e84173e5bb4dd374bf97db65c22f4ae4 $
 
 #include "server/SystemAccount.h"
 
@@ -36,6 +35,7 @@ const char * SystemAccount::getType() const
     return "sys";
 }
 
-void SystemAccount::store() const
+bool SystemAccount::isPersisted() const
 {
+    return false;
 }
