@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: b3abae0fe1b04f855c9aa067c15b945698be1725 $
 
 #ifndef SERVER_SYSTEM_ACCOUNT_H
 #define SERVER_SYSTEM_ACCOUNT_H
@@ -31,7 +30,7 @@ class SystemAccount : public Admin {
     ~SystemAccount();
 
     virtual const char * getType() const;
-    virtual void store() const;
+    virtual bool isPersisted() const;
 };
 
 
