@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 4d78db423086ee93dfdc9cc286cd2b80116c76d5 $
 
 #include "WorldRouter.h"
 
@@ -40,6 +39,7 @@
 #include "common/Monitors.h"
 #include "common/SystemTime.h"
 #include "common/Variable.h"
+#include "common/Tick.h"
 
 #include <Atlas/Objects/Operation.h>
 #include <Atlas/Objects/Anonymous.h>
@@ -59,9 +59,9 @@ static const bool debug_flag = false;
 /// when broadcasting.
 struct OpQueEntry {
     Operation op;
-    Entity & from;
+    LocatedEntity & from;
 
-    explicit OpQueEntry(const Operation & o, Entity & f);
+    explicit OpQueEntry(const Operation & o, LocatedEntity & f);
     OpQueEntry(const OpQueEntry & o);
     ~OpQueEntry();
 
@@ -74,7 +74,8 @@ struct OpQueEntry {
     }
 };
 
-inline OpQueEntry::OpQueEntry(const Operation & o, Entity & f) : op(o), from(f)
+inline OpQueEntry::OpQueEntry(const Operation & o, LocatedEntity & f) : op(o),
+                                                                        from(f)
 {
     from.incRef();
 }
@@ -152,7 +153,7 @@ WorldRouter::~WorldRouter()
 /// queue. The From attribute of the operation is set to the id of
 /// the entity that is responsible for adding the operation to the
 /// queue.
-void WorldRouter::addOperationToQueue(const Operation & op, Entity & ent)
+void WorldRouter::addOperationToQueue(const Operation & op, LocatedEntity & ent)
 {
     assert(op.isValid());
     assert(op->getFrom() != "cheat");
@@ -187,7 +188,7 @@ Operation WorldRouter::getOperationFromQueue()
         return NULL;
     }
     debug(std::cout << "pulled op off queue" << std::endl << std::flush;);
-    const Operation & op = (**I);
+    Operation op = (**I);
     m_operationQueue.pop_front();
     return op;
 }
@@ -199,7 +200,7 @@ Operation WorldRouter::getOperationFromQueue()
 /// the default spawn area if necessary. Handle inserting the
 /// entity into the loc/contains tree maintained by the Entity
 /// class. Send a Setup op to the entity.
-Entity * WorldRouter::addEntity(Entity * ent)
+LocatedEntity * WorldRouter::addEntity(LocatedEntity * ent)
 {
     debug(std::cout << "WorldRouter::addEntity(" << ent->getIntId() << ")" << std::endl
                     << std::flush;);
@@ -256,8 +257,8 @@ Entity * WorldRouter::addEntity(Entity * ent)
 /// Construct a new entity using the entity description provided,
 /// and pass it to addEntity().
 /// @return a pointer to the new entity.
-Entity * WorldRouter::addNewEntity(const std::string & typestr,
-                                   const RootEntity & attrs)
+LocatedEntity * WorldRouter::addNewEntity(const std::string & typestr,
+                                          const RootEntity & attrs)
 {
     debug(std::cout << "WorldRouter::addNewEntity(\"" << typestr << "\", attrs)"
                     << std::endl << std::flush;);
@@ -269,7 +270,7 @@ Entity * WorldRouter::addNewEntity(const std::string & typestr,
         return 0;
     }
 
-    Entity * ent = EntityBuilder::instance()->newEntity(id, intId, typestr, attrs, *this);
+    LocatedEntity * ent = EntityBuilder::instance()->newEntity(id, intId, typestr, attrs, *this);
     if (ent == 0) {
         log(ERROR, String::compose("Attempt to create an entity of type \"%1\" "
                                    "but type is unknown or forbidden",
@@ -279,20 +280,28 @@ Entity * WorldRouter::addNewEntity(const std::string & typestr,
     return addEntity(ent);
 }
 
-int WorldRouter::createSpawnPoint(const MapType & data, Entity * ent)
+int WorldRouter::createSpawnPoint(const MapType & data, LocatedEntity * ent)
 {
     MapType::const_iterator I = data.find("name");
     if (I == data.end() || !I->second.isString()) {
         log(ERROR, "No name on spawn point");
         return -1;
     }
+    SpawnEntity * new_spawn = new SpawnEntity(ent);
+    if (new_spawn->setup(data) != 0) {
+        delete new_spawn;
+        log(ERROR, "Error setting up spawn point");
+        return -1;
+    }
+
     const std::string & name = I->second.String();
     SpawnDict::iterator J = m_spawns.find(name);
     if (J != m_spawns.end()) {
-        delete J->second;
-        m_spawns.insert(J, std::make_pair(name, new SpawnEntity(ent, data)));
+        Spawn * old = J->second;
+        J->second = new_spawn;
+        delete old;
     } else {
-        m_spawns.insert(std::make_pair(name, new SpawnEntity(ent, data)));
+        m_spawns.insert(std::make_pair(name, new_spawn));
     }
     return 0;
 }
@@ -310,9 +319,9 @@ int WorldRouter::getSpawnList(Atlas::Message::ListType & data)
     return 0;
 }
 
-Entity * WorldRouter::spawnNewEntity(const std::string & name,
-                                     const std::string & type,
-                                     const RootEntity & desc)
+LocatedEntity * WorldRouter::spawnNewEntity(const std::string & name,
+                                            const std::string & type,
+                                            const RootEntity & desc)
 {
     SpawnDict::const_iterator I = m_spawns.find(name);
     if (I == m_spawns.end()) {
@@ -325,7 +334,7 @@ Entity * WorldRouter::spawnNewEntity(const std::string & name,
         log(ERROR, String::compose("Spawn not permitting %1", type));
         return 0;
     }
-    Entity * e = addNewEntity(type, desc);
+    LocatedEntity * e = addNewEntity(type, desc);
     if (e == 0) {
         log(ERROR, String::compose("Entity creation failed %1", type));
         return e;
@@ -377,7 +386,7 @@ Task * WorldRouter::activateTask(const std::string & tool,
 }
 
 ArithmeticScript * WorldRouter::newArithmetic(const std::string & name,
-                                              Entity * owner)
+                                              LocatedEntity * owner)
 {
     return ArithmeticBuilder::instance()->newArithmetic(name, owner);
 }
@@ -390,7 +399,7 @@ ArithmeticScript * WorldRouter::newArithmetic(const std::string & name,
 /// reference held by the world is decremented. There may still be
 /// a reference held by an operation in the queue from the removed
 /// entity.
-void WorldRouter::delEntity(Entity * ent)
+void WorldRouter::delEntity(LocatedEntity * ent)
 {
     if (ent == &m_gameWorld) {
         log(WARNING, "Attempt to delete game world");
@@ -405,11 +414,21 @@ void WorldRouter::delEntity(Entity * ent)
     ent->decRef();
 }
 
+void WorldRouter::resumeWorld()
+{
+    //Take all suspended operations and add them to be executed.
+    for (OpQueue::const_iterator I = m_suspendedQueue.begin(); I != m_suspendedQueue.end(); ++I) {
+        addOperationToQueue(I->op, I->from);
+    }
+    m_suspendedQueue.clear();
+}
+
+
 /// \brief Pass an operation to the World.
 ///
 /// Pass an operation to addOperationToQueue()
 /// so it gets added to the queue for dispatch.
-void WorldRouter::message(const Operation & op, Entity & ent)
+void WorldRouter::message(const Operation & op, LocatedEntity & ent)
 {
     addOperationToQueue(op, ent);
     debug(std::cout << "WorldRouter::message {"
@@ -446,8 +465,16 @@ bool WorldRouter::broadcastPerception(const Operation & op) const
 /// Pass the operation to the target entity. The resulting operations
 /// have their ref numbers set, and are added to the queue for
 /// dispatch.
-void WorldRouter::deliverTo(const Operation & op, Entity & ent)
+void WorldRouter::deliverTo(const Operation & op, LocatedEntity & ent)
 {
+    //If the world is suspended and the op is a tick, we should store it
+    //(to be resent when the world is resumed) and not process it now.
+    if (m_isSuspended) {
+        if (op->getClassNo() == Atlas::Objects::Operation::TICK_NO) {
+            m_suspendedQueue.push_back(OpQueEntry(op, ent));
+            return;
+        }
+    }
     OpVector res;
     ent.operation(op, res);
     OpVector::const_iterator Iend = res.end();
@@ -473,7 +500,7 @@ void WorldRouter::deliverTo(const Operation & op, Entity & ent)
 /// that it is possible that this entity has been destroyed, but it
 /// should still have a valid location, so can be used for range
 /// calculations.
-void WorldRouter::operation(const Operation & op, Entity & from)
+void WorldRouter::operation(const Operation & op, LocatedEntity & from)
 {
     debug(std::cout << "WorldRouter::operation {"
                     << op->getParents().front() << ":"
@@ -485,7 +512,7 @@ void WorldRouter::operation(const Operation & op, Entity & from)
     if (!op->isDefaultTo()) {
         const std::string & to = op->getTo();
         assert(!to.empty());
-        Entity * to_entity = 0;
+        LocatedEntity * to_entity = 0;
 
         if (to == from.getId()) {
             if (from.isDestroyed()) {
@@ -543,7 +570,7 @@ void WorldRouter::operation(const Operation & op, Entity & from)
 /// to the entity to the set of perceptive entities. This method is
 /// called when key events occur that indicate that the entity in
 /// question can receive broadcast perception operations.
-void WorldRouter::addPerceptive(Entity * perceptive)
+void WorldRouter::addPerceptive(LocatedEntity * perceptive)
 {
     debug(std::cout << "WorldRouter::addPerceptive" << std::endl << std::flush;);
     m_perceptives.insert(perceptive);
@@ -564,9 +591,9 @@ void WorldRouter::addPerceptive(Entity * perceptive)
 bool WorldRouter::idle(const SystemTime & time)
 {
     updateTime(time);
-    unsigned int op_count = 0;
-    OpQueue::iterator I = m_operationQueue.begin();
-    OpQueue::iterator Iend = m_operationQueue.end();
+	unsigned int op_count = 0;
+	OpQueue::iterator I = m_operationQueue.begin();
+	OpQueue::iterator Iend = m_operationQueue.end();
     while (++op_count < 10 && I != Iend && (*I)->getSeconds() <= m_realTime) {
         assert(I != m_operationQueue.end());
         OpQueEntry & oqe = *I;
@@ -575,13 +602,13 @@ bool WorldRouter::idle(const SystemTime & time)
             operation(oqe.op, oqe.from);
         }
         catch (const std::exception& ex) {
-            log(ERROR, String::compose("Exception caught in world.idle() "
+            log(ERROR, String::compose("Exception caught in WorldRouter::idle() "
                                        "thrown while processing operation "
-                                       "sent to \"%1\" from \"%2\"",
-                                       oqe->getTo(), oqe->getFrom()));
+                                       "sent to \"%1\" from \"%2\": %3",
+                                       oqe->getTo(), oqe->getFrom(), ex.what()));
         }
         catch (...) {
-            log(ERROR, String::compose("Exception caught in world.idle() "
+            log(ERROR, String::compose("Unspecified exception caught in WorldRouter::idle() "
                                        "thrown while processing operation "
                                        "sent to \"%1\" from \"%2\"",
                                        oqe->getTo(), oqe->getFrom()));
@@ -600,13 +627,13 @@ bool WorldRouter::idle(const SystemTime & time)
             operation(oqe.op, oqe.from);
         }
         catch (const std::exception& ex) {
-            log(ERROR, String::compose("Exception caught in world.idle() "
+            log(ERROR, String::compose("Exception caught in WorldRouter::idle() "
                                        "thrown while processing operation "
-                                       "sent to \"%1\" from \"%2\"",
-                                       oqe->getTo(), oqe->getFrom()));
+                                       "sent to \"%1\" from \"%2\": %3",
+                                       oqe->getTo(), oqe->getFrom(), ex.what()));
         }
         catch (...) {
-            log(ERROR, String::compose("Exception caught in world.idle() "
+            log(ERROR, String::compose("Unspecified exception caught in WorldRouter::idle() "
                                        "thrown while processing operation "
                                        "sent to \"%1\" from \"%2\"",
                                        oqe->getTo(), oqe->getFrom()));
@@ -627,7 +654,7 @@ bool WorldRouter::idle(const SystemTime & time)
 /// @param name string specifying name of the instance required.
 /// @return a pointer to an entity with the type required, or zero if an
 /// instance with this name was not found.
-Entity * WorldRouter::findByName(const std::string & name)
+LocatedEntity * WorldRouter::findByName(const std::string & name)
 {
     Element name_attr;
     EntityDict::const_iterator Iend = m_eobjects.end();
@@ -647,7 +674,7 @@ Entity * WorldRouter::findByName(const std::string & name)
 /// @param type string specifying the class name of the instance required.
 /// @return a pointer to an entity of the type required, or zero if no
 /// instance was found.
-Entity * WorldRouter::findByType(const std::string & type)
+LocatedEntity * WorldRouter::findByType(const std::string & type)
 {
     EntityDict::const_iterator Iend = m_eobjects.end();
     for(EntityDict::const_iterator I = m_eobjects.begin(); I != Iend; ++I) {
