@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 2c243c1f3ad23f7662ed8ed754d529155acd11d4 $
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -51,7 +50,6 @@
 
 #include "rulesets/BulletDomain.h"
 #include "rulesets/Python_API.h"
-#include "rulesets/Entity.h"
 
 #include "common/id.h"
 #include "common/log.h"
@@ -95,7 +93,6 @@ BOOL_OPTION(useMetaserver, true, CYPHESIS, "usemetaserver",
 STRING_OPTION(mserver, "metaserver.worldforge.org", CYPHESIS, "metaserver",
               "Hostname to use as the metaserver");
 
-
 int main(int argc, char ** argv)
 {
     if (security_init() != 0) {
@@ -108,6 +105,9 @@ int main(int argc, char ** argv)
         return EXIT_SECURITY_ERROR;
     }
 
+    //Turn on soft exits so we get a chance to persist external clients' thoughts.
+    exit_soft_enabled = true;
+
     interactive_signals();
 
     int config_status = loadConfig(argc, argv, USAGE_SERVER);
@@ -142,7 +142,7 @@ int main(int argc, char ** argv)
     // If we are a daemon logging to syslog, we need to set it up.
     initLogger();
 
-    // Initialise the persistance subsystem. If we have been built with
+    // Initialise the persistence subsystem. If we have been built with
     // database support, this will open the various databases used to
     // store server data.
     if (database_flag) {
@@ -190,7 +190,7 @@ int main(int argc, char ** argv)
     int nice = 1;
     readConfigItem(instance, "nice", nice);
     
-    // Start up the python subsystem.
+    // Start up the Python subsystem.
     init_python_api(ruleset_name);
 
     Inheritance::instance();
@@ -243,6 +243,8 @@ int main(int argc, char ** argv)
     // not creating a new world using the contents of the database as a
     // template
 
+    IdleConnector* storage_idle = nullptr;
+
     if (database_flag) {
         // log(INFO, _("Restoring world from database..."));
 
@@ -260,7 +262,7 @@ int main(int argc, char ** argv)
         commServer->addSocket(dbsocket);
         commServer->addIdle(dbsocket);
 
-        IdleConnector * storage_idle = new IdleConnector(*commServer);
+        storage_idle = new IdleConnector(*commServer);
         storage_idle->idling.connect(sigc::mem_fun(store, &StorageManager::tick));
         commServer->addIdle(storage_idle);
     } else {
@@ -388,6 +390,8 @@ int main(int argc, char ** argv)
         reduce_priority(nice);
     }
 
+    bool soft_exit_in_progess = false;
+    time_t soft_exit_deadline = 0;
     // Loop until the exit flag is set. The exit flag can be set anywhere in
     // the code easily.
     while (!exit_flag) {
@@ -396,12 +400,46 @@ int main(int argc, char ** argv)
             bool busy = world->idle(time);
             commServer->idle(time, busy);
             commServer->poll(busy);
-        }
-        catch (...) {
-            // It is hoped that commonly thrown exception, particularly
-            // exceptions that can be caused  by external influences
-            // should be caught close to where they are thrown. If
-            // an exception makes it here then it should be debugged.
+            if (soft_exit_in_progess) {
+                //If we're in soft exit mode and either the deadline has been exceeded
+                //or we've persisted all minds we should shut down normally.
+                if (store->numberOfOutstandingThoughtRequests() == 0) {
+                    log(NOTICE, "All entity thoughts were persisted.");
+                    exit_flag = true;
+                }
+                if (time.seconds() + time.microseconds()
+                        >= soft_exit_deadline) {
+                    log(WARNING,
+                            "Waiting for persisting thoughts timed out. This might "
+                                    "lead to lost entity thoughts.");
+                    exit_flag = true;
+                }
+            } else if (exit_flag_soft) {
+                soft_exit_in_progess = true;
+                //Set a deadline for five seconds.
+                static const time_t mind_persistence_deadline = 5;
+                size_t requestNumber = store->requestMinds(
+                        world->getEntities());
+                log(INFO,
+                        String::compose(
+                                "Soft exit requested, persisting %1 minds.",
+                                requestNumber));
+                soft_exit_deadline = time.seconds() + time.microseconds()
+                        + (mind_persistence_deadline * 1000000L);
+                log(NOTICE,
+                        String::compose(
+                                "Deadline for mind persistence set to %1 seconds.",
+                                mind_persistence_deadline));
+            }
+        // It is hoped that commonly thrown exception, particularly
+        // exceptions that can be caused  by external influences
+        // should be caught close to where they are thrown. If
+        // an exception makes it here then it should be debugged.
+        } catch (const std::exception& e) {
+            log(ERROR,
+                    String::compose("Exception caught in main(): %1",
+                            e.what()));
+        } catch (...) {
             log(ERROR, "Exception caught in main()");
         }
     }
@@ -411,6 +449,28 @@ int main(int argc, char ** argv)
     // by the game has been done before exit flag was set.
     log(NOTICE, "Performing clean shutdown...");
 
+    //Actually, there's no way for the world to know that it's shutting down,
+    //as the shutdown signal most probably comes from a sighandler. We need to
+    //tell it it's shutting down so it can do some housekeeping.
+    try {
+        exit_flag = false;
+        if (store->shutdown(exit_flag, world->getEntities()) != 0) {
+            //Ignore this error and carry on with shutting down.
+            log(ERROR, "Error when shutting down");
+        }
+    } catch (const std::exception& e) {
+        log(ERROR,
+                String::compose("Exception caught when shutting down: %1",
+                        e.what()));
+    } catch (...) {
+        //Ignore this error and carry on with shutting down.
+        log(ERROR, "Exception caught when shutting down");
+    }
+
+    //the Idle destructor will remove itself from commServer;
+    //thus we must delete storage_idle before we destroy commServer
+    delete storage_idle;
+
     delete commServer;
 
     delete server;
@@ -428,9 +488,9 @@ int main(int argc, char ** argv)
 
     Inheritance::clear();
 
-    // Shutdown the python interpretter. This frees lots of memory, and if
+    // Shutdown the Python interpreter. This frees lots of memory, and if
     // the malloc heap is in any way corrupt, a segfault is likely to
-    // occur at this point. Previous occassions where pointers have been
+    // occur at this point. Previous occasions where pointers have been
     // deleted twice elsewhere in the code, have resulted in a segfault
     // at this point. AlRiddoch 10th November 2001
     shutdown_python_api();
