@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 6097bd9278c8a58326951174ef25689ca64fc779 $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -24,6 +23,7 @@
 #define DEBUG
 #endif
 
+#include "TestBase.h"
 #include "TestWorld.h"
 #include "null_stream.h"
 
@@ -92,7 +92,7 @@ class TestCommClient : public CommClient<null_stream> {
     TestCommClient(CommServer & cs) : CommClient<null_stream>(cs, "") { }
 };
 
-class TestContext {
+class AccountConnectionintegration : public Cyphesis::TestBase {
   protected:
     Entity * m_tlve;
     BaseWorld * m_world;
@@ -100,46 +100,54 @@ class TestContext {
     CommServer * m_cs;
     Connection * m_connection;
   public:
-    TestContext()
-    {
-        m_tlve = new Entity("0", 0);
-        m_world = new SpawningTestWorld(*m_tlve);
-        m_server = new ServerRouting(*m_world,
-                                     "testrules",
-                                     "testname",
-                                     "1", 1, "2", 2);
-        m_cs = new CommServer;
-        m_connection = new Connection(*new TestCommClient(*m_cs),
-                                      *m_server,
-                                      "test_addr",
-                                      "3", 3);
+    AccountConnectionintegration();
 
-    }
+    void setup();
+    void teardown();
 
-    ~TestContext()
-    {
-        delete m_connection;
-        delete m_cs;
-        delete m_server;
-        delete m_world;
-    }
+    void test_account_creation();
 
     Connection * connection() const { return m_connection; }
     ServerRouting * server() const { return m_server; }
 };
 
-int main()
+AccountConnectionintegration::AccountConnectionintegration()
 {
-    {
-        TestContext scope;
-    }
+    ADD_TEST(AccountConnectionintegration::test_account_creation);
+}
 
+void AccountConnectionintegration::setup()
+{
+    m_tlve = new Entity("0", 0);
+    m_world = new SpawningTestWorld(*m_tlve);
+    m_server = new ServerRouting(*m_world,
+                                 "testrules",
+                                 "testname",
+                                 "1", 1, "2", 2);
+    m_cs = new CommServer;
+    m_connection = new Connection(*new TestCommClient(*m_cs),
+                                  *m_server,
+                                  "test_addr",
+                                  "3", 3);
+}
+
+void AccountConnectionintegration::teardown()
+{
+    delete m_connection;
+    delete m_cs;
+    delete m_server;
+    delete m_world;
+}
+
+static OpVector test_sent_ops;
+
+void AccountConnectionintegration::test_account_creation()
+{
     // Basic player account creation
     {
-        TestContext scope;
 
-        assert(scope.connection() != 0);
-        assert(scope.connection()->objects().empty());
+        ASSERT_NOT_NULL(m_connection);
+        ASSERT_TRUE(m_connection->objects().empty());
 
         Create op;
         Anonymous create_arg;
@@ -148,45 +156,44 @@ int main()
         create_arg->setAttr("password", "6a6e71bab281");
         op->setArgs1(create_arg);
 
-        OpVector res;
-        assert(res.empty());
+        ASSERT_TRUE(test_sent_ops.empty());
 
         // Send the operation to create the account
-        scope.connection()->operation(op, res);
+        m_connection->externalOperation(op, *m_connection);
 
         // There should be a response op
-        assert(!res.empty());
-        assert(res.size() == 1);
+        ASSERT_TRUE(!test_sent_ops.empty());
+        ASSERT_EQUAL(test_sent_ops.size(), 1u);
         // and the account creation should have created an object bound
         // to this connection.
-        assert(!scope.connection()->objects().empty());
+        ASSERT_TRUE(!m_connection->objects().empty());
 
         // Check the response is an info indicating successful account
         // creation.
-        const Operation & reply = res.front();
-        assert(reply->getClassNo() == Atlas::Objects::Operation::INFO_NO);
+        const Operation & reply = test_sent_ops.front();
+        ASSERT_EQUAL(reply->getClassNo(), Atlas::Objects::Operation::INFO_NO);
         // The Info response should have an argument describing the created
         // account
         const std::vector<Root> & reply_args = reply->getArgs();
-        assert(!reply_args.empty());
+        ASSERT_TRUE(!reply_args.empty());
         RootEntity account = smart_dynamic_cast<RootEntity>(reply_args.front());
-        assert(account.isValid());
+        ASSERT_TRUE(account.isValid());
 
         // The account ID should be provided
-        assert(!account->isDefaultId());
+        ASSERT_TRUE(!account->isDefaultId());
         const std::string account_id = account->getId();
-        assert(!account_id.empty());
+        ASSERT_TRUE(!account_id.empty());
 
         // Check the account has been registered in the server object
-        Router * account_router_ptr = scope.server()->getObject(account_id);
-        assert(account_router_ptr != 0);
+        Router * account_router_ptr = m_server->getObject(account_id);
+        ASSERT_NOT_NULL(account_router_ptr);
 
         // Check the account has been logged into the lobby
-        const AccountDict & lobby_dict = scope.server()->m_lobby.getAccounts();
+        const AccountDict & lobby_dict = m_server->m_lobby.getAccounts();
         AccountDict::const_iterator I = lobby_dict.find(account_id);
-        assert(I != lobby_dict.end());
+        ASSERT_TRUE(I != lobby_dict.end());
         Account * account_ptr = I->second;
-        assert(account_router_ptr == account_ptr);
+        ASSERT_EQUAL(account_router_ptr, account_ptr);
 
         // Basic login as now been established by account creation
 
@@ -197,15 +204,14 @@ int main()
         // and try an additional account creation, which should fail.
         // Multiple logins are ok, but there is no reason to allow multiple
         // account creations.
-        res.clear();
-        scope.connection()->operation(op, res);
-        assert(!res.empty());
-        assert(res.size() == 1);
+        test_sent_ops.clear();
+        m_connection->externalOperation(op, *m_connection);
+        ASSERT_TRUE(!test_sent_ops.empty());
+        ASSERT_EQUAL(test_sent_ops.size(), 1u);
 
-        const Operation & error_reply = res.front();
-        assert(error_reply->getClassNo() == Atlas::Objects::Operation::ERROR_NO);
-
-        res.clear();
+        const Operation & error_reply = test_sent_ops.front();
+        ASSERT_EQUAL(error_reply->getClassNo(),
+                     Atlas::Objects::Operation::ERROR_NO);
 
         Player::playableTypes.insert(test_valid_character_type);
 
@@ -217,12 +223,17 @@ int main()
         character_op->setArgs1(character_arg);
         character_op->setFrom(account_id);
 
-        scope.connection()->operation(character_op, res);
-        assert(!res.empty());
-        assert(res.size() == 2);
+        test_sent_ops.clear();
+        m_connection->externalOperation(character_op, *m_connection);
+        // FIXME the above went through Account::externalOperation, so there
+        // is no reply in res. The reply has gone directly to the Link::send
+        // method. Add a way of checking, once there are better stubs.
+        ASSERT_TRUE(!test_sent_ops.empty());
+        ASSERT_EQUAL(test_sent_ops.size(), 2u);
 
-        const Operation & create_reply = res.front();
-        assert(create_reply->getClassNo() == Atlas::Objects::Operation::INFO_NO);
+        const Operation & create_reply = test_sent_ops.front();
+        ASSERT_EQUAL(create_reply->getClassNo(),
+                     Atlas::Objects::Operation::INFO_NO);
 
 
         // TODO Character creation etc?
@@ -231,21 +242,28 @@ int main()
     }
 }
 
+int main()
+{
+    AccountConnectionintegration t;
+
+    return t.run();
+}
+
 // stubs
 
-void TestWorld::message(const Operation & op, Entity & ent)
+void TestWorld::message(const Operation & op, LocatedEntity & ent)
 {
 }
 
-Entity * TestWorld::addNewEntity(const std::string &,
+LocatedEntity * TestWorld::addNewEntity(const std::string &,
                                  const Atlas::Objects::Entity::RootEntity &)
 {
     return 0;
 }
 
 #include "server/CommClient.h"
-#include "server/ExternalMind.h"
-#include "server/ExternalProperty.h"
+#include "rulesets/ExternalMind.h"
+#include "rulesets/ExternalProperty.h"
 #include "server/Juncture.h"
 #include "server/Persistence.h"
 #include "server/Ruleset.h"
@@ -305,7 +323,7 @@ int CommSocket::flush()
     return 0;
 }
 
-ExternalMind::ExternalMind(Entity & e) : Router(e.getId(), e.getIntId()),
+ExternalMind::ExternalMind(LocatedEntity & e) : Router(e.getId(), e.getIntId()),
                                          m_external(0), m_entity(e)
 {
 }
@@ -314,6 +332,10 @@ ExternalMind::~ExternalMind()
 {
 }
 
+void ExternalMind::externalOperation(const Operation & op, Link &)
+{
+}
+
 void ExternalMind::operation(const Operation & op, OpVector & res)
 {
 }
@@ -329,7 +351,7 @@ void ExternalMind::linkUp(Link * c)
     m_external = c;
 }
 
-ExternalProperty::ExternalProperty(Router * & data) : m_data(data)
+ExternalProperty::ExternalProperty(ExternalMind * & data) : m_data(data)
 {
 }
 
@@ -352,9 +374,14 @@ void ExternalProperty::add(const std::string & s,
 {
 }
 
+ExternalProperty * ExternalProperty::copy() const
+{
+    return 0;
+}
+
 Juncture::Juncture(Connection * c,
                    const std::string & id, long iid) :
-          ConnectedRouter(id, iid, c),
+          ConnectableRouter(id, iid, c),
                                                        m_socket(0),
                                                        m_peer(0)
 {
@@ -364,6 +391,10 @@ Juncture::~Juncture()
 {
 }
 
+void Juncture::externalOperation(const Operation & op, Link &)
+{
+}
+
 void Juncture::operation(const Operation & op, OpVector & res)
 {
 }
@@ -376,6 +407,30 @@ void Juncture::addToEntity(const RootEntity & ent) const
 {
 }
 
+Link::Link(CommSocket & socket, const std::string & id, long iid) :
+            Router(id, iid), m_encoder(0), m_commSocket(socket)
+{
+}
+
+Link::~Link()
+{
+}
+
+void Link::send(const Operation & op) const
+{
+    test_sent_ops.push_back(op);
+}
+
+void Link::sendError(const Operation & op,
+                     const std::string &,
+                     const std::string &) const
+{
+}
+
+void Link::disconnect()
+{
+}
+
 Ruleset * Ruleset::m_instance = NULL;
 
 int Ruleset::installRule(const std::string & class_name,
@@ -404,7 +459,7 @@ int TeleportAuthenticator::removeTeleport(const std::string &entity_id)
     return 0;
 }
 
-Entity *TeleportAuthenticator::authenticateTeleport(const std::string &entity_id,
+LocatedEntity *TeleportAuthenticator::authenticateTeleport(const std::string &entity_id,
                                             const std::string &possess_key)
 {
     return 0;
@@ -438,6 +493,14 @@ void Persistence::putAccount(const Account & ac)
 {
 }
 
+void Persistence::addCharacter(const Account &, const LocatedEntity &)
+{
+}
+
+void Persistence::delCharacter(const std::string &)
+{
+}
+
 void log(LogLevel lvl, const std::string & msg)
 {
     std::cout << msg << std::endl;
@@ -448,7 +511,7 @@ void logEvent(LogEvent lev, const std::string & msg)
 }
 
 Creator::Creator(const std::string & id, long intId) :
-         Creator_parent(id, intId)
+         Character(id, intId)
 {
 }
 
@@ -460,7 +523,7 @@ void Creator::operation(const Operation & op, OpVector & res)
 {
 }
 
-void Creator::externalOperation(const Operation & op)
+void Creator::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -469,7 +532,7 @@ void Creator::mindLookOperation(const Operation & op, OpVector & res)
 }
 
 Character::Character(const std::string & id, long intId) :
-           Character_parent(id, intId),
+           Thing(id, intId),
                m_movement(*(Movement*)0),
                m_mind(0), m_externalMind(0)
 {
@@ -479,11 +542,21 @@ Character::~Character()
 {
 }
 
+int Character::linkExternal(Link * link)
+{
+    return 0;
+}
+
+int Character::unlinkExternal(Link * link)
+{
+    return 0;
+}
+
 void Character::operation(const Operation & op, OpVector &)
 {
 }
 
-void Character::externalOperation(const Operation & op)
+void Character::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -524,6 +597,10 @@ void Character::ActuateOperation(const Operation & op, OpVector &)
 {
 }
 
+void Character::RelayOperation(const Operation & op, OpVector &)
+{
+}
+
 void Character::mindActuateOperation(const Operation &, OpVector &)
 {
 }
@@ -608,9 +685,13 @@ void Character::mindOtherOperation(const Operation &, OpVector &)
 {
 }
 
+void Character::sendMind(const Operation & op, OpVector & res)
+{
+}
+
 
 Thing::Thing(const std::string & id, long intId) :
-       Thing_parent(id, intId)
+       Entity(id, intId)
 {
 }
 
@@ -643,7 +724,7 @@ void Thing::UpdateOperation(const Operation & op, OpVector & res)
 }
 
 Entity::Entity(const std::string & id, long intId) :
-        LocatedEntity(id, intId), m_motion(0), m_flags(0)
+        LocatedEntity(id, intId), m_motion(0)
 {
 }
 
@@ -752,7 +833,11 @@ void Entity::WieldOperation(const Operation &, OpVector &)
 {
 }
 
-void Entity::externalOperation(const Operation & op)
+void Entity::RelayOperation(const Operation &, OpVector &)
+{
+}
+
+void Entity::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -785,7 +870,25 @@ PropertyBase * Entity::setProperty(const std::string & name,
     return m_properties[name] = prop;
 }
 
-void Entity::onContainered()
+PropertyBase * Entity::modProperty(const std::string & name)
+{
+    return 0;
+}
+
+void Entity::installDelegate(int class_no, const std::string & delegate)
+{
+}
+
+Domain * Entity::getMovementDomain()
+{
+    return 0;
+}
+
+void Entity::sendWorld(const Operation & op)
+{
+}
+
+void Entity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -796,7 +899,7 @@ void Entity::onUpdated()
 LocatedEntity::LocatedEntity(const std::string & id, long intId) :
                Router(id, intId),
                m_refCount(0), m_seq(0),
-               m_script(0), m_type(0), m_contains(0)
+               m_script(0), m_type(0), m_flags(0), m_contains(0)
 {
 }
 
@@ -833,7 +936,35 @@ const PropertyBase * LocatedEntity::getProperty(const std::string & name) const
     return 0;
 }
 
-void LocatedEntity::onContainered()
+PropertyBase * LocatedEntity::modProperty(const std::string & name)
+{
+    return 0;
+}
+
+PropertyBase * LocatedEntity::setProperty(const std::string & name,
+                                          PropertyBase * prop)
+{
+    return 0;
+}
+
+void LocatedEntity::installDelegate(int, const std::string &)
+{
+}
+
+void LocatedEntity::destroy()
+{
+}
+
+Domain * LocatedEntity::getMovementDomain()
+{
+    return 0;
+}
+
+void LocatedEntity::sendWorld(const Operation & op)
+{
+}
+
+void LocatedEntity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -935,3 +1066,18 @@ bool_config_register::bool_config_register(bool & var,
                                            const char * help)
 {
 }
+void hash_password(const std::string & pwd, const std::string & salt,
+                   std::string & hash)
+{
+}
+
+#include <common/Shaker.h>
+
+Shaker::Shaker()
+{
+}
+
+std::string Shaker::generateSalt(size_t length)
+{
+    return "";
+}
