@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 87016c64e3bfa4af1710860254928be54920f098 $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -29,13 +28,13 @@
 
 #include "server/Admin.h"
 
-#include "server/CommSocket.h"
 #include "server/Connection.h"
 #include "server/Ruleset.h"
 #include "server/ServerRouting.h"
 
 #include "rulesets/Entity.h"
 
+#include "common/CommSocket.h"
 #include "common/compose.hpp"
 #include "common/debug.h"
 #include "common/Inheritance.h"
@@ -84,6 +83,7 @@ class TestObject : public Router
   public:
     explicit TestObject(const std::string & id, long intId);
 
+    virtual void externalOperation(const Operation &, Link &);
     virtual void operation(const Operation &, OpVector &);
 };
 
@@ -91,6 +91,10 @@ TestObject::TestObject(const std::string & id, long intId) : Router(id, intId)
 {
 }
 
+void TestObject::externalOperation(const Operation & op, Link &)
+{
+}
+
 void TestObject::operation(const Operation &, OpVector &)
 {
 }
@@ -1350,11 +1354,11 @@ void Admintest::test_createObject_fallthrough()
                  m_account);
 }
 
-void TestWorld::message(const Operation & op, Entity & ent)
+void TestWorld::message(const Operation & op, LocatedEntity & ent)
 {
 }
 
-Entity * TestWorld::addNewEntity(const std::string &,
+LocatedEntity * TestWorld::addNewEntity(const std::string &,
                                  const Atlas::Objects::Entity::RootEntity &)
 {
     return 0;
@@ -1391,7 +1395,7 @@ Account::Account(Connection * conn,
                  const std::string & passwd,
                  const std::string & id,
                  long intId) :
-         ConnectedRouter(id, intId, conn),
+         ConnectableRouter(id, intId, conn),
          m_username(uname), m_password(passwd)
 {
 }
@@ -1400,14 +1404,14 @@ Account::~Account()
 {
 }
 
-Entity * Account::addNewCharacter(const std::string & typestr,
-                                  const RootEntity & ent,
-                                  const Root & arg)
+LocatedEntity * Account::addNewCharacter(const std::string & typestr,
+                                         const RootEntity & ent,
+                                         const Root & arg)
 {
     return 0;
 }
 
-int Account::connectCharacter(Entity *chr)
+int Account::connectCharacter(LocatedEntity *chr)
 {
     return 0;
 }
@@ -1421,6 +1425,10 @@ void Account::store() const
 {
 }
 
+bool Account::isPersisted() const {
+    return true;
+}
+
 void Account::createObject(const std::string & type_str,
                            const Root & arg,
                            const Operation & op,
@@ -1437,6 +1445,10 @@ void Account::addToEntity(const RootEntity & ent) const
 {
 }
 
+void Account::externalOperation(const Operation & op, Link &)
+{
+}
+
 void Account::operation(const Operation & op, OpVector & res)
 {
     if (op->getClassNo() == Atlas::Objects::Operation::LOGOUT_NO) {
@@ -1509,6 +1521,10 @@ void Connection::addObject(Router * obj)
 {
 }
 
+void Connection::externalOperation(const Operation & op, Link &)
+{
+}
+
 void Connection::operation(const Operation &, OpVector &)
 {
 }
@@ -1529,15 +1545,11 @@ void Connection::GetOperation(const Operation &, OpVector &)
 {
 }
 
-void Connection::connectAvatar(Character * chr)
+void Connection::addEntity(LocatedEntity * ent)
 {
 }
 
-void Connection::addEntity(Entity * ent)
-{
-}
-
-ConnectedRouter::ConnectedRouter(const std::string & id,
+ConnectableRouter::ConnectableRouter(const std::string & id,
                                  long iid,
                                  Connection *c) :
                  Router(id, iid),
@@ -1545,14 +1557,15 @@ ConnectedRouter::ConnectedRouter(const std::string & id,
 {
 }
 
-ConnectedRouter::~ConnectedRouter()
+ConnectableRouter::~ConnectableRouter()
 {
 }
 
 Ruleset::Ruleset(EntityBuilder * eb) :
       m_taskHandler(0),
       m_entityHandler(0),
-      m_opHandler(0)
+      m_opHandler(0),
+      m_propertyHandler(0)
 {
 }
 
@@ -1579,7 +1592,7 @@ int Ruleset::installRule(const std::string & class_name,
 }
 
 Juncture::Juncture(Connection * c, const std::string & id, long iid) :
-          ConnectedRouter(id, iid, c),
+          ConnectableRouter(id, iid, c),
           m_address(0),
           m_socket(0),
           m_peer(0),
@@ -1591,6 +1604,10 @@ Juncture::~Juncture()
 {
 }
 
+void Juncture::externalOperation(const Operation & op, Link &)
+{
+}
+
 void Juncture::operation(const Operation & op, OpVector & res)
 {
 }
@@ -1651,6 +1668,14 @@ void ServerRouting::addAccount(Account * a)
 {
 }
 
+void ServerRouting::externalOperation(const Operation & op, Link &)
+{
+}
+
+void ServerRouting::operation(const Operation &, OpVector &)
+{
+}
+
 TeleportAuthenticator * TeleportAuthenticator::m_instance = NULL;
 
 int TeleportAuthenticator::removeTeleport(const std::string &entity_id)
@@ -1658,7 +1683,7 @@ int TeleportAuthenticator::removeTeleport(const std::string &entity_id)
     return 0;
 }
 
-Entity *TeleportAuthenticator::authenticateTeleport(const std::string &entity_id,
+LocatedEntity *TeleportAuthenticator::authenticateTeleport(const std::string &entity_id,
                                             const std::string &possess_key)
 {
     return 0;
@@ -1683,7 +1708,7 @@ void Persistence::putAccount(const Account & ac)
 }
 
 Character::Character(const std::string & id, long intId) :
-           Character_parent(id, intId),
+           Thing(id, intId),
                m_movement(*(Movement*)0),
                m_mind(0), m_externalMind(0)
 {
@@ -1697,7 +1722,7 @@ void Character::operation(const Operation & op, OpVector &)
 {
 }
 
-void Character::externalOperation(const Operation & op)
+void Character::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -1738,6 +1763,10 @@ void Character::ActuateOperation(const Operation & op, OpVector &)
 {
 }
 
+void Character::RelayOperation(const Operation & op, OpVector &)
+{
+}
+
 void Character::mindActuateOperation(const Operation &, OpVector &)
 {
 }
@@ -1828,7 +1857,7 @@ void Character::sendMind(const Operation & op, OpVector & res)
 }
 
 Thing::Thing(const std::string & id, long intId) :
-       Thing_parent(id, intId)
+       Entity(id, intId)
 {
 }
 
@@ -1861,7 +1890,7 @@ void Thing::UpdateOperation(const Operation & op, OpVector & res)
 }
 
 Entity::Entity(const std::string & id, long intId) :
-        LocatedEntity(id, intId), m_motion(0), m_flags(0)
+        LocatedEntity(id, intId), m_motion(0)
 {
 }
 
@@ -1970,7 +1999,11 @@ void Entity::WieldOperation(const Operation &, OpVector &)
 {
 }
 
-void Entity::externalOperation(const Operation & op)
+void Entity::RelayOperation(const Operation &, OpVector &)
+{
+}
+
+void Entity::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -2003,7 +2036,26 @@ PropertyBase * Entity::modProperty(const std::string & name)
     return 0;
 }
 
-void Entity::onContainered()
+PropertyBase * Entity::setProperty(const std::string & name,
+                                   PropertyBase * prop)
+{
+    return 0;
+}
+
+void Entity::installDelegate(int class_no, const std::string & delegate)
+{
+}
+
+Domain * Entity::getMovementDomain()
+{
+    return 0;
+}
+
+void Entity::sendWorld(const Operation & op)
+{
+}
+
+void Entity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -2018,7 +2070,7 @@ void Entity::callOperation(const Operation & op, OpVector & res)
 LocatedEntity::LocatedEntity(const std::string & id, long intId) :
                Router(id, intId),
                m_refCount(0), m_seq(0),
-               m_script(0), m_type(0), m_contains(0)
+               m_script(0), m_type(0), m_flags(0), m_contains(0)
 {
 }
 
@@ -2055,7 +2107,35 @@ const PropertyBase * LocatedEntity::getProperty(const std::string & name) const
     return 0;
 }
 
-void LocatedEntity::onContainered()
+PropertyBase * LocatedEntity::modProperty(const std::string & name)
+{
+    return 0;
+}
+
+PropertyBase * LocatedEntity::setProperty(const std::string & name,
+                                          PropertyBase * prop)
+{
+    return 0;
+}
+
+void LocatedEntity::installDelegate(int, const std::string &)
+{
+}
+
+void LocatedEntity::destroy()
+{
+}
+
+Domain * LocatedEntity::getMovementDomain()
+{
+    return 0;
+}
+
+void LocatedEntity::sendWorld(const Operation & op)
+{
+}
+
+void LocatedEntity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -2209,7 +2289,7 @@ TypeNode::~TypeNode()
 
 BaseWorld * BaseWorld::m_instance = 0;
 
-BaseWorld::BaseWorld(Entity & gw) : m_gameWorld(gw)
+BaseWorld::BaseWorld(LocatedEntity & gw) : m_gameWorld(gw)
 {
     m_instance = this;
 }
@@ -2220,12 +2300,12 @@ BaseWorld::~BaseWorld()
     delete &m_gameWorld;
 }
 
-Entity * BaseWorld::getEntity(const std::string & id) const
+LocatedEntity * BaseWorld::getEntity(const std::string & id) const
 {
     return 0;
 }
 
-Entity * BaseWorld::getEntity(long id) const
+LocatedEntity * BaseWorld::getEntity(long id) const
 {
     return 0;
 }
@@ -2302,5 +2382,18 @@ void log(LogLevel lvl, const std::string & msg)
 bool database_flag = false;
 
 namespace Atlas { namespace Objects { namespace Operation {
+
 int MONITOR_NO = -1;
+int THOUGHT_NO = -1;
+int GOAL_INFO_NO=-1;
 } } }
+
+#include <common/Shaker.h>
+
+Shaker::Shaker()
+{
+}
+std::string Shaker::generateSalt(size_t length)
+{
+    return "";
+}
