@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: af5fbe9997947d1414c1b63d06a80c557c65f348 $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -32,7 +31,7 @@
 class TestArithmeticFactory : public ArithmeticKit
 {
   public:
-    ArithmeticScript * newScript(Entity * owner) { return 0; }
+    ArithmeticScript * newScript(LocatedEntity * owner) { return 0; }
 };
 
 int main()
