@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: dc13d77281f5cdec793196ad2e154f90e5cdb15e $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -24,6 +23,7 @@
 #define DEBUG
 #endif
 
+#include "TestBase.h"
 #include "null_stream.h"
 
 #include "server/Connection.h"
@@ -31,8 +31,8 @@
 #include "server/Account.h"
 #include "server/CommClient.h"
 #include "server/CommServer.h"
-#include "server/ExternalMind.h"
-#include "server/ExternalProperty.h"
+#include "rulesets/ExternalMind.h"
+#include "rulesets/ExternalProperty.h"
 #include "server/Lobby.h"
 #include "server/Player.h"
 #include "server/ServerRouting.h"
@@ -69,157 +69,471 @@ class TestCommClient : public CommClient<null_stream> {
     TestCommClient(CommServer & cs) : CommClient<null_stream>(cs, "") { }
 };
 
-class TestConnection : public Connection {
+class Connectiontest : public Cyphesis::TestBase
+{
+  private:
+    ServerRouting * m_server;
+    CommServer * m_commServer;
+    CommClient<null_stream> * m_tcc;
+    Connection * m_connection;
+
+    static bool Router_error_called;
+    static bool Router_clientError_called;
   public:
-    TestConnection(CommSocket & cc, ServerRouting & svr,
-                   const std::string & addr, const std::string & id, long iid) :
-        Connection(cc, svr, addr, id, iid) {
-      
-    }
+    Connectiontest();
 
-    Account * testAddNewAccount(const std::string & username,
-                            const std::string & password) {
-        return addNewAccount("player", username, password);
-    }
+    void setup();
+    void teardown();
 
-    void test_disconnectObject(RouterMap::iterator I) {
-        return disconnectObject(I, "test_event");
-    }
+    void test_addNewAccount();
+    void test_CreateOperation_empty();
+    void test_CreateOperation_root_arg();
+    void test_CreateOperation_restricted();
+    void test_CreateOperation_empty_arg();
+    void test_CreateOperation_account_by_id();
+    void test_CreateOperation_number_username();
+    void test_CreateOperation_no_passed();
+    void test_CreateOperation_empty_password();
+    void test_CreateOperation_username();
+    void test_CreateOperation();
+    void test_foo();
+    void test_disconnectAccount_empty();
+    void test_disconnectAccount_unused_Character();
+    void test_disconnectAccount_used_Character();
+    void test_disconnectAccount_others_used_Character();
+    void test_disconnectAccount_unlinked_Character();
+    void test_disconnectAccount_non_Character();
 
-    size_t numObjects() const {
-        return m_objects.size();
-    }
-
-    const RouterMap & getObjects() const {
-        return m_objects;
-    }
-
-    void removeObject(Router * obj) {
-        RouterMap::iterator I = m_objects.find(obj->getIntId());
-        if (I != m_objects.end()) {
-            m_objects.erase(I);
-        }
-    }
+    static void set_Router_error_called();
+    static void set_Router_clientError_called();
 };
 
-int main()
+bool Connectiontest::Router_error_called = false;
+bool Connectiontest::Router_clientError_called = false;
+
+void Connectiontest::set_Router_error_called()
 {
-    // WorldRouter world(SystemTime());
-    // Entity & e = world.m_gameWorld;
+    Router_error_called = true;
+}
 
-    ServerRouting server(*(BaseWorld*)0, "noruleset", "unittesting",
-                         "1", 1, "2", 2);
+void Connectiontest::set_Router_clientError_called()
+{
+    Router_clientError_called = true;
+}
 
-    CommServer commServer;
+Connectiontest::Connectiontest()
+{
+    ADD_TEST(Connectiontest::test_addNewAccount);
+    ADD_TEST(Connectiontest::test_CreateOperation_empty);
+    ADD_TEST(Connectiontest::test_CreateOperation_root_arg);
+    ADD_TEST(Connectiontest::test_CreateOperation_restricted);
+    ADD_TEST(Connectiontest::test_CreateOperation_empty_arg);
+    ADD_TEST(Connectiontest::test_CreateOperation_account_by_id);
+    ADD_TEST(Connectiontest::test_CreateOperation_number_username);
+    ADD_TEST(Connectiontest::test_CreateOperation_no_passed);
+    ADD_TEST(Connectiontest::test_CreateOperation_empty_password);
+    ADD_TEST(Connectiontest::test_CreateOperation_username);
+    ADD_TEST(Connectiontest::test_CreateOperation);
+    ADD_TEST(Connectiontest::test_foo);
+    ADD_TEST(Connectiontest::test_disconnectAccount_empty);
+    ADD_TEST(Connectiontest::test_disconnectAccount_empty);
+    ADD_TEST(Connectiontest::test_disconnectAccount_unused_Character);
+    ADD_TEST(Connectiontest::test_disconnectAccount_used_Character);
+    ADD_TEST(Connectiontest::test_disconnectAccount_others_used_Character);
+    ADD_TEST(Connectiontest::test_disconnectAccount_unlinked_Character);
+    ADD_TEST(Connectiontest::test_disconnectAccount_non_Character);
+}
 
-    TestCommClient * tcc = new TestCommClient(commServer);
-    TestConnection * tc = new TestConnection(*tcc, server, "addr", "3", 3);
+void Connectiontest::setup()
+{
+    Router_error_called = false;
 
-    Account * ac = tc->testAddNewAccount("bob", "foo");
-    assert(ac != 0);
+    m_server = new ServerRouting(*(BaseWorld*)0, "noruleset", "unittesting",
+                                 "1", 1, "2", 2);
+                         
+    m_commServer = new CommServer;
 
-    tc->test_disconnectObject(tc->objects().find(ac->getIntId()));
+    m_tcc = new TestCommClient(*m_commServer);
+    m_connection = new Connection(*m_tcc, *m_server, "addr", "3", 3);
+}
 
-    assert(tc->numObjects() == 0);
+void Connectiontest::teardown()
+{
+}
 
-    {
-        Create op;
-        OpVector res;
-        tc->operation(op, res);
-        op->setArgs1(Root());
-        tc->operation(op, res);
-        restricted_flag = true;
-        tc->operation(op, res);
-        restricted_flag = false;
-        Anonymous op_arg;
-        op->setArgs1(op_arg);
-        tc->operation(op, res);
-        op_arg->setId("jim");
-        // Legacy op
-        tc->operation(op, res);
-        op_arg->setAttr("username", 1);
-        // Malformed username
-        tc->operation(op, res);
-        op_arg->setAttr("username", "jim");
-        // username, no password
-        tc->operation(op, res);
-        op_arg->setAttr("password", "");
-        // zero length password
-        tc->operation(op, res);
-        op_arg->setAttr("username", "");
-        op_arg->setAttr("password", "foo");
-        // zero length username
-        tc->operation(op, res);
-        op_arg->setAttr("username", "jim");
-        // valid username and password
-        tc->operation(op, res);
-        assert(tc->numObjects() != 0);
-    }
+void Connectiontest::test_addNewAccount()
+{
+    Account * ac = m_connection->addNewAccount("player", "bob", "foo");
 
+    ASSERT_NOT_NULL(ac);
+
+    m_connection->disconnectObject(m_connection->m_objects.find(ac->getIntId()),
+                                   "test_event");
+
+    ASSERT_EQUAL(m_connection->m_objects.size(), 0u);
+}
+
+void Connectiontest::test_CreateOperation_empty()
+{
+    Create op;
+    OpVector res;
+    m_connection->operation(op, res);
+    ASSERT_EQUAL(m_connection->m_objects.size(), 0u);
+    ASSERT_TRUE(Router_error_called);
+}
+
+void Connectiontest::test_CreateOperation_root_arg()
+{
+    Create op;
+    OpVector res;
+    op->setArgs1(Root());
+    m_connection->operation(op, res);
+    ASSERT_EQUAL(m_connection->m_objects.size(), 0u);
+    ASSERT_TRUE(Router_error_called);
+}
+
+void Connectiontest::test_CreateOperation_restricted()
+{
+    Create op;
+    OpVector res;
+    restricted_flag = true;
+    m_connection->operation(op, res);
+    ASSERT_EQUAL(m_connection->m_objects.size(), 0u);
+    ASSERT_TRUE(Router_error_called);
+}
+
+void Connectiontest::test_CreateOperation_empty_arg()
+{
+    Create op;
+    OpVector res;
+    restricted_flag = false;
+    Anonymous op_arg;
+    op->setArgs1(op_arg);
+    m_connection->operation(op, res);
+    ASSERT_EQUAL(m_connection->m_objects.size(), 0u);
+    ASSERT_TRUE(Router_error_called);
+}
+
+void Connectiontest::test_CreateOperation_account_by_id()
+{
+    Create op;
+    OpVector res;
+    Anonymous op_arg;
+    op->setArgs1(op_arg);
+    op_arg->setId("jim");
+    // Legacy op
+    m_connection->operation(op, res);
+    ASSERT_EQUAL(m_connection->m_objects.size(), 0u);
+    ASSERT_TRUE(Router_error_called);
+}
+
+void Connectiontest::test_CreateOperation_number_username()
+{
+    Create op;
+    OpVector res;
+    Anonymous op_arg;
+    op->setArgs1(op_arg);
+    op_arg->setAttr("username", 1);
+    // Malformed username
+    m_connection->operation(op, res);
+    ASSERT_EQUAL(m_connection->m_objects.size(), 0u);
+    ASSERT_TRUE(Router_error_called);
+}
+
+void Connectiontest::test_CreateOperation_no_passed()
+{
+    Create op;
+    OpVector res;
+    Anonymous op_arg;
+    op->setArgs1(op_arg);
+    op_arg->setAttr("username", "jim");
+    // username, no password
+    m_connection->operation(op, res);
+    ASSERT_EQUAL(m_connection->m_objects.size(), 0u);
+    ASSERT_TRUE(Router_error_called);
+}
+
+void Connectiontest::test_CreateOperation_empty_password()
+{
+    Create op;
+    OpVector res;
+    Anonymous op_arg;
+    op->setArgs1(op_arg);
+    op_arg->setAttr("username", "jim");
+    op_arg->setAttr("password", "");
+    // zero length password
+    m_connection->operation(op, res);
+    ASSERT_EQUAL(m_connection->m_objects.size(), 0u);
+    ASSERT_TRUE(Router_clientError_called);
+}
+
+void Connectiontest::test_CreateOperation_username()
+{
+    Create op;
+    OpVector res;
+    Anonymous op_arg;
+    op->setArgs1(op_arg);
+    op_arg->setAttr("username", "");
+    op_arg->setAttr("password", "foo");
+    // zero length username
+    m_connection->operation(op, res);
+    ASSERT_EQUAL(m_connection->m_objects.size(), 0u);
+    ASSERT_TRUE(Router_clientError_called);
+}
+
+void Connectiontest::test_CreateOperation()
+{
+    Create op;
+    OpVector res;
+    Anonymous op_arg;
+    op->setArgs1(op_arg);
+    op_arg->setAttr("username", "jim");
+    op_arg->setAttr("password", "foo");
+    // valid username and password
+    m_connection->operation(op, res);
+    ASSERT_EQUAL(m_connection->m_objects.size(), 1u);
+}
+
+void Connectiontest::test_foo()
+{
     {
         Login op;
         OpVector res;
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         op->setArgs1(Root());
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         Anonymous op_arg;
         op->setArgs1(op_arg);
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         op_arg->setId("bob");
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         op_arg->setAttr("username", 1);
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         op_arg->setAttr("username", "");
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         op_arg->setAttr("username", "bob");
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         op_arg->setAttr("password", "foo");
-        tc->operation(op, res);
-        tc->operation(op, res);
+        m_connection->operation(op, res);
+        m_connection->operation(op, res);
     }
 
     {
         Get op;
         OpVector res;
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         Root op_arg;
         op->setArgs1(op_arg);
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         op_arg->setId("1");
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         op_arg->setId("game_entity");
-        tc->operation(op, res);
+        m_connection->operation(op, res);
     }
 
     {
         Logout op;
         OpVector res;
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         op->setSerialno(24);
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         Root op_arg;
         op->setArgs1(op_arg);
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         op_arg->setId("-1");
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         op_arg->setId("23");
-        tc->operation(op, res);
+        m_connection->operation(op, res);
         // How to determine the real ID?
-        const RouterMap rm = tc->getObjects();
+        const RouterMap rm = m_connection->m_objects;
         RouterMap::const_iterator I = rm.begin();
         for (;I != rm.end(); ++I) {
             std::string object_id = String::compose("%1", I->first);
             std::cout << "ID: " << object_id << std::endl;
             op_arg->setId(object_id);
-            tc->operation(op, res);
+            m_connection->operation(op, res);
         }
     }
 
-    delete tc;
+}
+
+void Connectiontest::test_disconnectAccount_empty()
+{
+    // setup
+    Account * ac = new Player(m_connection,
+                              "jim",
+                              "1e0ce8e9-304b-470c-83c4-feab11f9a2e4",
+                              "4", 4);
+
+    ac->m_connection = m_connection;
+    m_connection->m_objects[ac->getIntId()] = ac;
+
+    RouterMap::iterator I = m_connection-> m_objects.find(ac->getIntId());
+    assert(I != m_connection->m_objects.end());
+
+    m_connection->disconnectAccount(ac, I, "test_disconnect_account");
+
+    ASSERT_TRUE(m_connection-> m_objects.find(ac->getIntId()) == 
+                m_connection->m_objects.end());
+}
+
+void Connectiontest::test_disconnectAccount_unused_Character()
+{
+    // setup
+    Account * ac = new Player(m_connection,
+                              "jim",
+                              "1e0ce8e9-304b-470c-83c4-feab11f9a2e4",
+                              "4", 4);
+
+    ac->m_connection = m_connection;
+    m_connection->m_objects[ac->getIntId()] = ac;
+
+    RouterMap::iterator I = m_connection-> m_objects.find(ac->getIntId());
+    assert(I != m_connection->m_objects.end());
+
+    Character * avatar = new Character("5", 5);
+    m_connection->m_objects[avatar->getIntId()] = avatar;
+    ac->addCharacter(avatar);
+
+    m_connection->disconnectAccount(ac, I, "test_disconnect_account");
+
+    ASSERT_TRUE(m_connection-> m_objects.find(ac->getIntId()) == 
+                m_connection->m_objects.end());
+
+    ASSERT_TRUE(m_connection-> m_objects.find(avatar->getIntId()) == 
+                m_connection->m_objects.end());
+}
+
+void Connectiontest::test_disconnectAccount_used_Character()
+{
+    // setup
+    Account * ac = new Player(m_connection,
+                              "jim",
+                              "1e0ce8e9-304b-470c-83c4-feab11f9a2e4",
+                              "4", 4);
+
+    ac->m_connection = m_connection;
+    m_connection->m_objects[ac->getIntId()] = ac;
+
+    RouterMap::iterator I = m_connection-> m_objects.find(ac->getIntId());
+    assert(I != m_connection->m_objects.end());
+
+    Character * avatar = new Character("5", 5);
+    avatar->m_externalMind = new ExternalMind(*avatar);
+    avatar->m_externalMind->linkUp(m_connection);
+    m_connection->m_objects[avatar->getIntId()] = avatar;
+    ac->addCharacter(avatar);
+
+    m_connection->disconnectAccount(ac, I, "test_disconnect_account");
+
+    ASSERT_TRUE(m_connection-> m_objects.find(ac->getIntId()) == 
+                m_connection->m_objects.end());
+
+    // The Character was in use, so it stays connected
+    ASSERT_TRUE(m_connection-> m_objects.find(avatar->getIntId()) != 
+                m_connection->m_objects.end());
+}
+
+void Connectiontest::test_disconnectAccount_others_used_Character()
+{
+    // setup
+    Account * ac = new Player(m_connection,
+                              "jim",
+                              "1e0ce8e9-304b-470c-83c4-feab11f9a2e4",
+                              "4", 4);
+
+    ac->m_connection = m_connection;
+    m_connection->m_objects[ac->getIntId()] = ac;
+
+    RouterMap::iterator I = m_connection-> m_objects.find(ac->getIntId());
+    assert(I != m_connection->m_objects.end());
+
+    CommClient<null_stream> * otcc = new TestCommClient(*m_commServer);
+    Connection * other_con = new Connection(*otcc, *m_server, "addr", "6", 6);
+
+    Character * avatar = new Character("5", 5);
+    avatar->m_externalMind = new ExternalMind(*avatar);
+    avatar->m_externalMind->linkUp(other_con);
+    m_connection->m_objects[avatar->getIntId()] = avatar;
+    ac->addCharacter(avatar);
+
+    m_connection->disconnectAccount(ac, I, "test_disconnect_account");
+
+    ASSERT_TRUE(m_connection-> m_objects.find(ac->getIntId()) == 
+                m_connection->m_objects.end());
+
+    // The Character was in use by another connection, so it is removed
+    // from this one.
+    ASSERT_TRUE(m_connection-> m_objects.find(avatar->getIntId()) == 
+                m_connection->m_objects.end());
+}
+
+void Connectiontest::test_disconnectAccount_unlinked_Character()
+{
+    // setup
+    Account * ac = new Player(m_connection,
+                              "jim",
+                              "1e0ce8e9-304b-470c-83c4-feab11f9a2e4",
+                              "4", 4);
+
+    ac->m_connection = m_connection;
+    m_connection->m_objects[ac->getIntId()] = ac;
+
+    RouterMap::iterator I = m_connection-> m_objects.find(ac->getIntId());
+    assert(I != m_connection->m_objects.end());
+
+    Character * avatar = new Character("5", 5);
+    avatar->m_externalMind = new ExternalMind(*avatar);
+    m_connection->m_objects[avatar->getIntId()] = avatar;
+    ac->addCharacter(avatar);
+
+    m_connection->disconnectAccount(ac, I, "test_disconnect_account");
+
+    ASSERT_TRUE(m_connection-> m_objects.find(ac->getIntId()) == 
+                m_connection->m_objects.end());
+
+    ASSERT_TRUE(m_connection-> m_objects.find(avatar->getIntId()) == 
+                m_connection->m_objects.end());
+}
+
+void Connectiontest::test_disconnectAccount_non_Character()
+{
+    // setup
+    Account * ac = new Player(m_connection,
+                              "jim",
+                              "1e0ce8e9-304b-470c-83c4-feab11f9a2e4",
+                              "4", 4);
+
+    ac->m_connection = m_connection;
+    m_connection->m_objects[ac->getIntId()] = ac;
+
+    RouterMap::iterator I = m_connection-> m_objects.find(ac->getIntId());
+    assert(I != m_connection->m_objects.end());
+
+    Entity * avatar = new Thing("5", 5);
+    m_connection->m_objects[avatar->getIntId()] = avatar;
+    ac->addCharacter(avatar);
+
+    m_connection->disconnectAccount(ac, I, "test_disconnect_account");
+
+    ASSERT_TRUE(m_connection-> m_objects.find(ac->getIntId()) == 
+                m_connection->m_objects.end());
+
+    ASSERT_TRUE(m_connection-> m_objects.find(avatar->getIntId()) == 
+                m_connection->m_objects.end());
+}
+
+int main()
+{
+    Connectiontest t;
+
+    return t.run();
 }
 
 // Stubs
 
+#include "common/BaseWorld.h"
+
 bool restricted_flag;
 
 namespace Atlas { namespace Objects { namespace Operation {
@@ -289,7 +603,7 @@ Account::Account(Connection * conn,
                  const std::string & passwd,
                  const std::string & id,
                  long intId) :
-         ConnectedRouter(id, intId, conn),
+         ConnectableRouter(id, intId, conn),
          m_username(uname), m_password(passwd)
 {
 }
@@ -303,10 +617,20 @@ const char * Account::getType() const
     return "testaccount";
 }
 
+// Simplified stub version to allow us to test Connection::disconnectObject
+void Account::addCharacter(LocatedEntity * chr)
+{
+    m_charactersDict[chr->getIntId()] = chr;
+}
+
 void Account::store() const
 {
 }
 
+bool Account::isPersisted() const {
+    return true;
+}
+
 void Account::addToMessage(Atlas::Message::MapType &) const
 {
 }
@@ -322,10 +646,13 @@ void Account::createObject(const std::string & type_str,
 {
 }
 
-void Account::operation(const Operation &, OpVector &)
+void Account::externalOperation(const Operation &, Link &)
 {
 }
 
+void Account::operation(const Operation &, OpVector &)
+{
+}
 
 void Account::LogoutOperation(const Operation &, OpVector &)
 {
@@ -359,7 +686,7 @@ void Account::OtherOperation(const Operation &, OpVector &)
 {
 }
 
-ConnectedRouter::ConnectedRouter(const std::string & id,
+ConnectableRouter::ConnectableRouter(const std::string & id,
                                  long iid,
                                  Connection *c) :
                  Router(id, iid),
@@ -367,7 +694,7 @@ ConnectedRouter::ConnectedRouter(const std::string & id,
 {
 }
 
-ConnectedRouter::~ConnectedRouter()
+ConnectableRouter::~ConnectableRouter()
 {
 }
 
@@ -403,6 +730,14 @@ void ServerRouting::addAccount(Account * a)
 {
 }
 
+void ServerRouting::externalOperation(const Operation & op, Link &)
+{
+}
+
+void ServerRouting::operation(const Operation &, OpVector &)
+{
+}
+
 Lobby::Lobby(ServerRouting & s, const std::string & id, long intId) :
        Router(id, intId),
        m_server(s)
@@ -429,11 +764,15 @@ void Lobby::addAccount(Account * ac)
 {
 }
 
+void Lobby::externalOperation(const Operation &, Link &)
+{
+}
+
 void Lobby::operation(const Operation & op, OpVector & res)
 {
 }
 
-ExternalMind::ExternalMind(Entity & e) : Router(e.getId(), e.getIntId()),
+ExternalMind::ExternalMind(LocatedEntity & e) : Router(e.getId(), e.getIntId()),
                                          m_external(0), m_entity(e)
 {
 }
@@ -442,11 +781,15 @@ ExternalMind::~ExternalMind()
 {
 }
 
+void ExternalMind::externalOperation(const Operation &, Link &)
+{
+}
+
 void ExternalMind::operation(const Operation & op, OpVector & res)
 {
 }
 
-ExternalProperty::ExternalProperty(Router * & data) : m_data(data)
+ExternalProperty::ExternalProperty(ExternalMind * & data) : m_data(data)
 {
 }
 
@@ -469,6 +812,11 @@ void ExternalProperty::add(const std::string & s,
 {
 }
 
+ExternalProperty * ExternalProperty::copy() const
+{
+    return 0;
+}
+
 const std::string & ExternalMind::connectionId()
 {
     assert(m_external != 0);
@@ -481,7 +829,7 @@ void ExternalMind::linkUp(Link * c)
 }
 
 Character::Character(const std::string & id, long intId) :
-           Character_parent(id, intId),
+           Thing(id, intId),
                m_movement(*(Movement*)0),
                m_mind(0), m_externalMind(0)
 {
@@ -491,11 +839,21 @@ Character::~Character()
 {
 }
 
+int Character::linkExternal(Link * link)
+{
+    return 0;
+}
+
+int Character::unlinkExternal(Link * link)
+{
+    return 0;
+}
+
 void Character::operation(const Operation & op, OpVector &)
 {
 }
 
-void Character::externalOperation(const Operation & op)
+void Character::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -536,6 +894,10 @@ void Character::ActuateOperation(const Operation & op, OpVector &)
 {
 }
 
+void Character::RelayOperation(const Operation & op, OpVector &)
+{
+}
+
 void Character::mindActuateOperation(const Operation &, OpVector &)
 {
 }
@@ -623,7 +985,7 @@ void Character::mindOtherOperation(const Operation &, OpVector &)
 
 
 Thing::Thing(const std::string & id, long intId) :
-       Thing_parent(id, intId)
+       Entity(id, intId)
 {
 }
 
@@ -656,7 +1018,7 @@ void Thing::UpdateOperation(const Operation & op, OpVector & res)
 }
 
 Entity::Entity(const std::string & id, long intId) :
-        LocatedEntity(id, intId), m_motion(0), m_flags(0)
+        LocatedEntity(id, intId), m_motion(0)
 {
 }
 
@@ -765,7 +1127,11 @@ void Entity::WieldOperation(const Operation &, OpVector &)
 {
 }
 
-void Entity::externalOperation(const Operation & op)
+void Entity::RelayOperation(const Operation &, OpVector &)
+{
+}
+
+void Entity::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -798,7 +1164,25 @@ PropertyBase * Entity::setProperty(const std::string & name,
     return m_properties[name] = prop;
 }
 
-void Entity::onContainered()
+PropertyBase * Entity::modProperty(const std::string & name)
+{
+    return 0;
+}
+
+void Entity::installDelegate(int class_no, const std::string & delegate)
+{
+}
+
+Domain * Entity::getMovementDomain()
+{
+    return 0;
+}
+
+void Entity::sendWorld(const Operation & op)
+{
+}
+
+void Entity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -809,7 +1193,7 @@ void Entity::onUpdated()
 LocatedEntity::LocatedEntity(const std::string & id, long intId) :
                Router(id, intId),
                m_refCount(0), m_seq(0),
-               m_script(0), m_type(0), m_contains(0)
+               m_script(0), m_type(0), m_flags(0), m_contains(0)
 {
 }
 
@@ -846,7 +1230,35 @@ const PropertyBase * LocatedEntity::getProperty(const std::string & name) const
     return 0;
 }
 
-void LocatedEntity::onContainered()
+PropertyBase * LocatedEntity::modProperty(const std::string & name)
+{
+    return 0;
+}
+
+PropertyBase * LocatedEntity::setProperty(const std::string & name,
+                                          PropertyBase * prop)
+{
+    return 0;
+}
+
+void LocatedEntity::installDelegate(int, const std::string &)
+{
+}
+
+void LocatedEntity::destroy()
+{
+}
+
+Domain * LocatedEntity::getMovementDomain()
+{
+    return 0;
+}
+
+void LocatedEntity::sendWorld(const Operation & op)
+{
+}
+
+void LocatedEntity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -867,6 +1279,12 @@ void Link::send(const Operation & op) const
 {
 }
 
+void Link::sendError(const Operation & op,
+                     const std::string &,
+                     const std::string &) const
+{
+}
+
 void Link::disconnect()
 {
 }
@@ -893,6 +1311,7 @@ void Router::error(const Operation & op,
                    OpVector & res,
                    const std::string & to) const
 {
+    Connectiontest::set_Router_error_called();
 }
 
 void Router::clientError(const Operation & op,
@@ -900,6 +1319,7 @@ void Router::clientError(const Operation & op,
                          OpVector & res,
                          const std::string & to) const
 {
+    Connectiontest::set_Router_clientError_called();
 }
 
 Location::Location() : m_loc(0)
@@ -914,11 +1334,11 @@ PropertyBase::~PropertyBase()
 {
 }
 
-void PropertyBase::install(Entity *)
+void PropertyBase::install(LocatedEntity *, const std::string & name)
 {
 }
 
-void PropertyBase::apply(Entity *)
+void PropertyBase::apply(LocatedEntity *)
 {
 }
 
@@ -932,9 +1352,16 @@ void PropertyBase::add(const std::string & s,
 {
 }
 
+HandlerResult PropertyBase::operation(LocatedEntity *,
+                                      const Operation &,
+                                      OpVector &)
+{
+    return OPERATION_IGNORED;
+}
+
 BaseWorld * BaseWorld::m_instance = 0;
 
-BaseWorld::BaseWorld(Entity & gw) : m_gameWorld(gw)
+BaseWorld::BaseWorld(LocatedEntity & gw) : m_gameWorld(gw)
 {
 }
 
@@ -942,12 +1369,12 @@ BaseWorld::~BaseWorld()
 {
 }
 
-Entity * BaseWorld::getEntity(const std::string & id) const
+LocatedEntity * BaseWorld::getEntity(const std::string & id) const
 {
     return 0;
 }
 
-Entity * BaseWorld::getEntity(long id) const
+LocatedEntity * BaseWorld::getEntity(long id) const
 {
     return 0;
 }
@@ -980,14 +1407,13 @@ const Root & Inheritance::getClass(const std::string & parent)
     return noClass;
 }
 
-void encrypt_password(const std::string & pwd, std::string & hash)
-{
-}
-
 void log(LogLevel lvl, const std::string & msg)
 {
 }
-
+void hash_password(const std::string & pwd, const std::string & salt,
+                   std::string & hash )
+{
+}
 void logEvent(LogEvent lev, const std::string & msg)
 {
 }
@@ -1026,3 +1452,13 @@ int check_password(const std::string & pwd, const std::string & hash)
 {
     return 0;
 }
+
+#include <common/Shaker.h>
+
+Shaker::Shaker()
+{
+}
+std::string Shaker::generateSalt(size_t length)
+{
+    return "";
+}
