@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: d3d7f78abd131b4c06891202782b1eb7e19543a7 $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -24,16 +23,14 @@
 #define DEBUG
 #endif
 
+#include "TestBase.h"
 #include "TestWorld.h"
 
 #include "server/CorePropertyManager.h"
 #include "server/EntityBuilder.h"
 #include "server/EntityFactory.h"
 
-#include "rulesets/World.h"
-#include "rulesets/Creator.h"
-#include "rulesets/Plant.h"
-#include "rulesets/Stackable.h"
+#include "rulesets/Entity.h"
 #include "rulesets/Script.h"
 #include "rulesets/Task.h"
 
@@ -46,6 +43,7 @@
 #include "common/TypeNode.h"
 #include "common/Variable.h"
 #include "common/ScriptKit.h"
+#include "common/TaskKit.h"
 
 #include <Atlas/Objects/Anonymous.h>
 #include <Atlas/Objects/RootOperation.h>
@@ -60,248 +58,318 @@ using Atlas::Message::MapType;
 using Atlas::Objects::Entity::Anonymous;
 using Atlas::Objects::Root;
 
-class ExposedEntityBuilder : public EntityBuilder {
-  public:
-    explicit ExposedEntityBuilder(BaseWorld & w) : EntityBuilder() { }
-
-    const FactoryDict & factoryDict() const { return m_entityFactories; }
-
-};
-
-class TestScriptFactory : public ScriptKit<Entity> {
+class TestScriptFactory : public ScriptKit<LocatedEntity> {
   protected:
     std::string m_package;
   public:
     TestScriptFactory() { }
 
     const std::string & package() const { return m_package; }
-    int addScript(Entity * entity) const { return 0; }
+    int addScript(LocatedEntity * entity) const { return 0; }
     int refreshClass() { return 0; }
 };
 
+class TestTaskFactory : public TaskKit
+{
+  public:
+    virtual int checkTarget(LocatedEntity * target) { return 0; }
+    virtual Task * newTask(LocatedEntity & chr) { return 0; }
+};
+
+class EntityBuildertest : public Cyphesis::TestBase
+{
+  private:
+    Entity * e;
+    BaseWorld * test_world;
+  public:
+    EntityBuildertest();
+
+    void setup();
+    void teardown();
+
+    void test_sequence1();
+    void test_sequence2();
+    void test_sequence3();
+    void test_sequence4();
+    void test_sequence5();
+    void test_installFactory_duplicate();
+    void test_installTaskFactory_duplicate();
+};
+
+EntityBuildertest::EntityBuildertest()
+{
+    ADD_TEST(EntityBuildertest::test_sequence1);
+    ADD_TEST(EntityBuildertest::test_sequence2);
+    ADD_TEST(EntityBuildertest::test_sequence3);
+    ADD_TEST(EntityBuildertest::test_sequence4);
+    ADD_TEST(EntityBuildertest::test_sequence5);
+    ADD_TEST(EntityBuildertest::test_installFactory_duplicate);
+    ADD_TEST(EntityBuildertest::test_installTaskFactory_duplicate);
+}
+
+void EntityBuildertest::setup()
+{
+    e = new Entity("1", 1);
+    test_world = new TestWorld(*e);
+    EntityBuilder::init();
+}
+
+void EntityBuildertest::teardown()
+{
+    delete test_world;
+    delete e;
+    EntityBuilder::del();
+    assert(EntityBuilder::instance() == 0);
+    Inheritance::clear();
+}
+
 enum action {
   DO_NOTHING,
   SET_POS,
   SET_VELOCITY } LocatedEntity_merge_action = DO_NOTHING;
 
+void EntityBuildertest::test_sequence1()
+{
+    Anonymous attributes;
+
+    assert(EntityBuilder::instance() != 0);
+
+    assert(EntityBuilder::instance()->newEntity("1", 1, "world", attributes, BaseWorld::instance()) == 0);
+    assert(EntityBuilder::instance()->newEntity("1", 1, "nonexistant", attributes, BaseWorld::instance()) == 0);
+    assert(EntityBuilder::instance()->newEntity("1", 1, "thing", attributes, BaseWorld::instance()) != 0);
+}
+
+void EntityBuildertest::test_sequence2()
+{
+    Anonymous attributes;
+
+    assert(EntityBuilder::instance() != 0);
+
+    // Create a normal Entity
+    LocatedEntity * test_ent = EntityBuilder::instance()->newEntity("1", 1, "thing", attributes, BaseWorld::instance());
+    assert(test_ent != 0);
+
+    // Create an entity specifying an attrbute
+    attributes->setAttr("funky", "true");
+
+    test_ent = EntityBuilder::instance()->newEntity("1", 1, "thing", attributes, BaseWorld::instance());
+    assert(test_ent != 0);
+
+    // Create an entity causing VELOCITY to be set
+    attributes = Anonymous();
+
+    attributes->setVelocity(std::vector<double>(3, 1.5));
+
+    LocatedEntity_merge_action = SET_VELOCITY;
+
+    test_ent = EntityBuilder::instance()->newEntity("1", 1, "thing", attributes, BaseWorld::instance());
+    assert(test_ent != 0);
+
+    LocatedEntity_merge_action = DO_NOTHING;
+
+    // Create an entity causing VELOCITY to be set for no obvious reason
+    attributes = Anonymous();
+
+    LocatedEntity_merge_action = SET_VELOCITY;
+
+    test_ent = EntityBuilder::instance()->newEntity("1", 1, "thing", attributes, BaseWorld::instance());
+    assert(test_ent != 0);
+
+    LocatedEntity_merge_action = DO_NOTHING;
+
+    // Create an entity specifying a LOC
+    attributes = Anonymous();
+
+    attributes->setLoc("1");
+
+    test_ent = EntityBuilder::instance()->newEntity("1", 1, "thing", attributes, BaseWorld::instance());
+    assert(test_ent != 0);
+}
+
+void EntityBuildertest::test_sequence3()
+{
+    EntityBuilder & entity_factory = *EntityBuilder::instance();
+
+    // Attributes for test entities being created
+    Anonymous attributes;
+
+    // Create an entity which is an instance of one of the core classes
+    LocatedEntity * test_ent = entity_factory.newEntity("1", 1, "thing", attributes, BaseWorld::instance());
+    assert(test_ent != 0);
+}
+
+void EntityBuildertest::test_sequence4()
+{
+    EntityBuilder & entity_factory = *EntityBuilder::instance();
+    // Attributes for test entities being created
+    Anonymous attributes;
+
+    // Check that creating an entity of a type we know we have not yet
+    // installed results in a null pointer.
+    assert(entity_factory.newEntity("1", 1, "custom_type", attributes, BaseWorld::instance()) == 0);
+
+    // Get a reference to the internal dictionary of entity factories.
+    const FactoryDict & factory_dict = entity_factory.m_entityFactories;
+
+    // Make sure it has some factories in it already.
+    assert(!factory_dict.empty());
+
+    // Assert the dictionary does not contain the factory we know we have
+    // have not yet installed.
+    assert(factory_dict.find("custom_type") == factory_dict.end());
+
+    // Set up a type description for a new type, and install it
+    EntityKit * custom_type_factory = new EntityFactory<Entity>();
+    custom_type_factory->m_attributes["test_custom_type_attr"] =
+          "test_value";
+    {
+        int ret;
+        ret = entity_factory.installFactory("custom_type",
+                                            atlasClass("custom_type", "thing"),
+                                            custom_type_factory);
+        custom_type_factory->m_type = new TypeNode("custom_type");
+
+        ASSERT_EQUAL(ret, 0);
+    }
+
+    PropertyBase * p = new Property<std::string>; 
+    custom_type_factory->m_type->addProperty("test_custom_type_attr", p);
+    p->set("test_value");
+
+    // Check that the factory dictionary now contains a factory for
+    // the custom type we just installed.
+    FactoryDict::const_iterator I = factory_dict.find("custom_type");
+    assert(I != factory_dict.end());
+    assert(custom_type_factory == I->second);
+
+    MapType::const_iterator J;
+    // Check the factory has the attributes we described on the custom
+    // type.
+    J = custom_type_factory->m_attributes.find("test_custom_type_attr");
+    assert(J != custom_type_factory->m_attributes.end());
+    assert(J->second.isString());
+    assert(J->second.String() == "test_value");
+
+    // Create an instance of our custom type, ensuring that it works.
+    LocatedEntity * test_ent = entity_factory.newEntity("1", 1, "custom_type", attributes, BaseWorld::instance());
+    assert(test_ent != 0);
+
+    assert(test_ent->getType() == custom_type_factory->m_type);
+
+    // Check that creating an entity of a type we know we have not yet
+    // installed results in a null pointer.
+    assert(entity_factory.newEntity("1", 1, "custom_inherited_type", attributes, BaseWorld::instance()) == 0);
+
+    // Assert the dictionary does not contain the factory we know we have
+    // have not yet installed.
+    assert(factory_dict.find("custom_inherited_type") == factory_dict.end());
+}
+
+void EntityBuildertest::test_sequence5()
+{
+    EntityBuilder & entity_factory = *EntityBuilder::instance();
+    Anonymous attributes;
+
+    // Get a reference to the internal dictionary of entity factories.
+    const FactoryDict & factory_dict = entity_factory.m_entityFactories;
+
+    // Make sure it has some factories in it already.
+    assert(!factory_dict.empty());
+
+    // Assert the dictionary does not contain the factory we know we have
+    // have not yet installed.
+    assert(factory_dict.find("custom_scripted_type") == factory_dict.end());
+
+    // Set up a type description for a new type, and install it
+    EntityKit * custom_type_factory = new EntityFactory<Entity>();
+    custom_type_factory->m_attributes["test_custom_type_attr"] =
+          "test_value";
+
+    custom_type_factory->m_scriptFactory = new TestScriptFactory();
+
+    {
+        entity_factory.installFactory("custom_scripted_type",
+              atlasClass("custom_scripted_type", "thing"),
+              custom_type_factory);
+        custom_type_factory->m_type = new TypeNode("custom_scripted_type");
+    }
+
+    // Check that the factory dictionary now contains a factory for
+    // the custom type we just installed.
+    FactoryDict::const_iterator I = factory_dict.find("custom_scripted_type");
+    assert(I != factory_dict.end());
+    assert(custom_type_factory == I->second);
+
+    // Create an instance of our custom type, ensuring that it works.
+    LocatedEntity * test_ent = entity_factory.newEntity("1", 1, "custom_scripted_type", attributes, BaseWorld::instance());
+    assert(test_ent != 0);
+
+    assert(test_ent->getType() == custom_type_factory->m_type);
+}
+
+void EntityBuildertest::test_installFactory_duplicate()
+{
+    EntityBuilder & entity_factory = *EntityBuilder::instance();
+    FactoryDict & factories = entity_factory.m_entityFactories;
+
+    EntityKit * custom_type_factory = new EntityFactory<Entity>();
+
+    int ret = entity_factory.installFactory("custom_type",
+                                            atlasClass("custom_type", "thing"),
+                                            custom_type_factory);
+
+    ASSERT_EQUAL(ret, 0);
+    ASSERT_TRUE(factories.find("custom_type") != factories.end());
+    ASSERT_EQUAL(factories.find("custom_type")->second, custom_type_factory);
+
+    EntityKit * custom_type_factory2 = new EntityFactory<Entity>();
+
+    ret = entity_factory.installFactory("custom_type",
+                                        atlasClass("custom_type", "thing"),
+                                        custom_type_factory2);
+
+    ASSERT_EQUAL(ret, -1);
+    ASSERT_TRUE(factories.find("custom_type") != factories.end());
+    ASSERT_EQUAL(factories.find("custom_type")->second, custom_type_factory);
+}
+
+void EntityBuildertest::test_installTaskFactory_duplicate()
+{
+    EntityBuilder & entity_factory = *EntityBuilder::instance();
+    TaskFactoryDict & factories = entity_factory.m_taskFactories;
+
+    std::string class_name("custom_task_type");
+
+    TaskKit * factory = new TestTaskFactory();
+
+    entity_factory.installTaskFactory(class_name, factory);
+
+    ASSERT_TRUE(factories.find(class_name) != factories.end());
+    ASSERT_EQUAL(factories.find(class_name)->second, factory);
+
+    TaskKit * factory2 = new TestTaskFactory();
+
+    entity_factory.installTaskFactory(class_name, factory2);
+
+    // Check factory2 hasn't replaced the first one inserted
+    ASSERT_TRUE(factories.find(class_name) != factories.end());
+    ASSERT_EQUAL(factories.find(class_name)->second, factory);
+}
+
 int main(int argc, char ** argv)
 {
-    {
-        Entity e("1", 1);
-        TestWorld test_world(e);
-        Anonymous attributes;
+    EntityBuildertest t;
 
-        EntityBuilder::init();
-
-        assert(EntityBuilder::instance() != 0);
-
-        assert(EntityBuilder::instance()->newEntity("1", 1, "world", attributes, test_world) == 0);
-        assert(EntityBuilder::instance()->newEntity("1", 1, "nonexistant", attributes, test_world) == 0);
-        assert(EntityBuilder::instance()->newEntity("1", 1, "thing", attributes, test_world) != 0);
-
-        EntityBuilder::del();
-        assert(EntityBuilder::instance() == 0);
-        Inheritance::clear();
-    }
-
-    {
-        Entity e("1", 1);
-        TestWorld test_world(e);
-        Anonymous attributes;
-
-        EntityBuilder::init();
-
-        assert(EntityBuilder::instance() != 0);
-
-        // Create a normal Entity
-        Entity * test_ent = EntityBuilder::instance()->newEntity("1", 1, "thing", attributes, test_world);
-        assert(test_ent != 0);
-
-        // Create an entity specifying an attrbute
-        attributes->setAttr("funky", "true");
-
-        test_ent = EntityBuilder::instance()->newEntity("1", 1, "thing", attributes, test_world);
-        assert(test_ent != 0);
-
-        // Create an entity causing VELOCITY to be set
-        attributes = Anonymous();
-
-        attributes->setVelocity(std::vector<double>(3, 1.5));
-
-        LocatedEntity_merge_action = SET_VELOCITY;
-
-        test_ent = EntityBuilder::instance()->newEntity("1", 1, "thing", attributes, test_world);
-        assert(test_ent != 0);
-
-        LocatedEntity_merge_action = DO_NOTHING;
-
-        // Create an entity causing VELOCITY to be set for no obvious reason
-        attributes = Anonymous();
-
-        LocatedEntity_merge_action = SET_VELOCITY;
-
-        test_ent = EntityBuilder::instance()->newEntity("1", 1, "thing", attributes, test_world);
-        assert(test_ent != 0);
-
-        LocatedEntity_merge_action = DO_NOTHING;
-
-        // Create an entity specifying a LOC
-        attributes = Anonymous();
-
-        attributes->setLoc("1");
-
-        test_ent = EntityBuilder::instance()->newEntity("1", 1, "thing", attributes, test_world);
-        assert(test_ent != 0);
-
-        EntityBuilder::del();
-        assert(EntityBuilder::instance() == 0);
-        Inheritance::clear();
-    }
-
-    {
-        // Create a test world.
-        Entity e("1", 1);
-        TestWorld test_world(e);
-
-        // Instance of EntityBuilder with all protected methods exposed
-        // for testing
-        ExposedEntityBuilder entity_factory(test_world);
-
-        // Attributes for test entities being created
-        Anonymous attributes;
-
-        // Create an entity which is an instance of one of the core classes
-        Entity * test_ent = entity_factory.newEntity("1", 1, "thing", attributes, test_world);
-        assert(test_ent != 0);
-
-        Inheritance::clear();
-    }
-
-    {
-        // Create a test world.
-        Entity e("1", 1);
-        TestWorld test_world(e);
-
-        // Instance of EntityBuilder with all protected methods exposed
-        // for testing
-        ExposedEntityBuilder entity_factory(test_world);
-
-        // Attributes for test entities being created
-        Anonymous attributes;
-
-
-        // Check that creating an entity of a type we know we have not yet
-        // installed results in a null pointer.
-        assert(entity_factory.newEntity("1", 1, "custom_type", attributes, test_world) == 0);
-
-        // Get a reference to the internal dictionary of entity factories.
-        const FactoryDict & factory_dict = entity_factory.factoryDict();
-
-        // Make sure it has some factories in it already.
-        assert(!factory_dict.empty());
-
-        // Assert the dictionary does not contain the factory we know we have
-        // have not yet installed.
-        assert(factory_dict.find("custom_type") == factory_dict.end());
-
-        // Set up a type description for a new type, and install it
-        EntityKit * custom_type_factory = new EntityFactory<Entity>();
-        custom_type_factory->m_attributes["test_custom_type_attr"] =
-              "test_value";
-        {
-            entity_factory.installFactory("custom_type",
-                                          atlasClass("custom_type", "thing"),
-                                          custom_type_factory);
-            custom_type_factory->m_type = new TypeNode("custom_type");
-        }
-
-        PropertyBase * p = new Property<std::string>; 
-        custom_type_factory->m_type->addProperty("test_custom_type_attr", p);
-        p->set("test_value");
-
-        // Check that the factory dictionary now contains a factory for
-        // the custom type we just installed.
-        FactoryDict::const_iterator I = factory_dict.find("custom_type");
-        assert(I != factory_dict.end());
-        assert(custom_type_factory == I->second);
-
-        MapType::const_iterator J;
-        // Check the factory has the attributes we described on the custom
-        // type.
-        J = custom_type_factory->m_attributes.find("test_custom_type_attr");
-        assert(J != custom_type_factory->m_attributes.end());
-        assert(J->second.isString());
-        assert(J->second.String() == "test_value");
-
-        // Create an instance of our custom type, ensuring that it works.
-        Entity * test_ent = entity_factory.newEntity("1", 1, "custom_type", attributes, test_world);
-        assert(test_ent != 0);
-
-        assert(test_ent->getType() == custom_type_factory->m_type);
-
-        // Check that creating an entity of a type we know we have not yet
-        // installed results in a null pointer.
-        assert(entity_factory.newEntity("1", 1, "custom_inherited_type", attributes, test_world) == 0);
-
-        // Assert the dictionary does not contain the factory we know we have
-        // have not yet installed.
-        assert(factory_dict.find("custom_inherited_type") == factory_dict.end());
-        Inheritance::clear();
-    }
-
-    {
-        Entity e("1", 1);
-        TestWorld test_world(e);
-        ExposedEntityBuilder entity_factory(test_world);
-        Anonymous attributes;
-
-        // Get a reference to the internal dictionary of entity factories.
-        const FactoryDict & factory_dict = entity_factory.factoryDict();
-
-        // Make sure it has some factories in it already.
-        assert(!factory_dict.empty());
-
-        // Assert the dictionary does not contain the factory we know we have
-        // have not yet installed.
-        assert(factory_dict.find("custom_scripted_type") == factory_dict.end());
-
-        // Set up a type description for a new type, and install it
-        EntityKit * custom_type_factory = new EntityFactory<Entity>();
-        custom_type_factory->m_attributes["test_custom_type_attr"] =
-              "test_value";
-
-        custom_type_factory->m_scriptFactory = new TestScriptFactory();
-
-        {
-            entity_factory.installFactory("custom_scripted_type",
-                  atlasClass("custom_scripted_type", "thing"),
-                  custom_type_factory);
-            custom_type_factory->m_type = new TypeNode("custom_scripted_type");
-        }
-
-        // Check that the factory dictionary now contains a factory for
-        // the custom type we just installed.
-        FactoryDict::const_iterator I = factory_dict.find("custom_scripted_type");
-        assert(I != factory_dict.end());
-        assert(custom_type_factory == I->second);
-
-        // Create an instance of our custom type, ensuring that it works.
-        Entity * test_ent = entity_factory.newEntity("1", 1, "custom_scripted_type", attributes, test_world);
-        assert(test_ent != 0);
-
-        assert(test_ent->getType() == custom_type_factory->m_type);
-
-        Inheritance::clear();
-    }
+    return t.run();
 }
 
 // stubs
 
-void TestWorld::message(const Operation & op, Entity & ent)
+void TestWorld::message(const Operation & op, LocatedEntity & ent)
 {
 }
 
-Entity * TestWorld::addNewEntity(const std::string &,
+LocatedEntity * TestWorld::addNewEntity(const std::string &,
                                  const Atlas::Objects::Entity::RootEntity &)
 {
     return 0;
@@ -340,8 +408,10 @@ EntityKit::~EntityKit()
     }
 }
 
+class World;
+
 template <>
-Entity * EntityFactory<World>::newEntity(const std::string & id, long intId)
+LocatedEntity * EntityFactory<World>::newEntity(const std::string & id, long intId)
 {
     return 0;
 }
@@ -362,7 +432,7 @@ EntityFactory<T>::~EntityFactory()
 }
 
 template <class T>
-Entity * EntityFactory<T>::newEntity(const std::string & id, long intId)
+LocatedEntity * EntityFactory<T>::newEntity(const std::string & id, long intId)
 {
     ++m_createdCount;
     return new Entity(id, intId);
@@ -376,6 +446,12 @@ EntityKit * EntityFactory<T>::duplicateFactory()
     return f;
 }
 
+class Thing;
+class Character;
+class Creator;
+class Plant;
+class Stackable;
+
 template class EntityFactory<Entity>;
 template class EntityFactory<Thing>;
 template class EntityFactory<Character>;
@@ -385,7 +461,7 @@ template class EntityFactory<Stackable>;
 template class EntityFactory<World>;
 
 Entity::Entity(const std::string & id, long intId) :
-        LocatedEntity(id, intId), m_motion(0), m_flags(0)
+        LocatedEntity(id, intId), m_motion(0)
 {
 }
 
@@ -494,7 +570,11 @@ void Entity::WieldOperation(const Operation &, OpVector &)
 {
 }
 
-void Entity::externalOperation(const Operation & op)
+void Entity::RelayOperation(const Operation &, OpVector &)
+{
+}
+
+void Entity::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -526,7 +606,26 @@ PropertyBase * Entity::modProperty(const std::string & name)
     return 0;
 }
 
-void Entity::onContainered()
+PropertyBase * Entity::setProperty(const std::string & name,
+                                   PropertyBase * prop)
+{
+    return 0;
+}
+
+void Entity::installDelegate(int class_no, const std::string & delegate)
+{
+}
+
+Domain * Entity::getMovementDomain()
+{
+    return 0;
+}
+
+void Entity::sendWorld(const Operation & op)
+{
+}
+
+void Entity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -537,7 +636,7 @@ void Entity::onUpdated()
 LocatedEntity::LocatedEntity(const std::string & id, long intId) :
                Router(id, intId),
                m_refCount(0), m_seq(0),
-               m_script(0), m_type(0), m_contains(0)
+               m_script(0), m_type(0), m_flags(0), m_contains(0)
 {
 }
 
@@ -574,7 +673,35 @@ const PropertyBase * LocatedEntity::getProperty(const std::string & name) const
     return 0;
 }
 
-void LocatedEntity::onContainered()
+PropertyBase * LocatedEntity::modProperty(const std::string & name)
+{
+    return 0;
+}
+
+PropertyBase * LocatedEntity::setProperty(const std::string & name,
+                                          PropertyBase * prop)
+{
+    return 0;
+}
+
+void LocatedEntity::installDelegate(int, const std::string &)
+{
+}
+
+void LocatedEntity::destroy()
+{
+}
+
+Domain * LocatedEntity::getMovementDomain()
+{
+    return 0;
+}
+
+void LocatedEntity::sendWorld(const Operation & op)
+{
+}
+
+void LocatedEntity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -736,11 +863,11 @@ PropertyBase::~PropertyBase()
 {
 }
 
-void PropertyBase::install(Entity *)
+void PropertyBase::install(LocatedEntity *, const std::string & name)
 {
 }
 
-void PropertyBase::apply(Entity *)
+void PropertyBase::apply(LocatedEntity *)
 {
 }
 
@@ -755,6 +882,13 @@ void PropertyBase::add(const std::string & s,
 {
 }
 
+HandlerResult PropertyBase::operation(LocatedEntity *,
+                                      const Operation &,
+                                      OpVector &)
+{
+    return OPERATION_IGNORED;
+}
+
 template<>
 void Property<int>::set(const Atlas::Message::Element & e)
 {
@@ -874,7 +1008,7 @@ void Task::setScript(Script*)
 
 BaseWorld * BaseWorld::m_instance = 0;
 
-BaseWorld::BaseWorld(Entity & gw) : m_gameWorld(gw)
+BaseWorld::BaseWorld(LocatedEntity & gw) : m_gameWorld(gw)
 {
     m_instance = this;
 }
@@ -884,7 +1018,7 @@ BaseWorld::~BaseWorld()
     m_instance = 0;
 }
 
-Entity * BaseWorld::getEntity(const std::string & id) const
+LocatedEntity * BaseWorld::getEntity(const std::string & id) const
 {
     long intId = integerId(id);
 
@@ -911,6 +1045,13 @@ PropertyBase * CorePropertyManager::addProperty(const std::string & name,
     return 0;
 }
 
+int CorePropertyManager::installFactory(const std::string & type_name,
+                                        const Root & type_desc,
+                                        PropertyKit * factory)
+{
+    return 0;
+}
+
 PropertyManager * PropertyManager::m_instance = 0;
 
 PropertyManager::PropertyManager()
@@ -924,6 +1065,13 @@ PropertyManager::~PropertyManager()
    m_instance = 0;
 }
 
+int PropertyManager::installFactory(const std::string & type_name,
+                                    const Atlas::Objects::Root & type_desc,
+                                    PropertyKit * factory)
+{
+    return 0;
+}
+
 long integerId(const std::string & id)
 {
     long intId = strtol(id.c_str(), 0, 10);
@@ -934,6 +1082,14 @@ long integerId(const std::string & id)
     return intId;
 }
 
+TaskKit::TaskKit() : m_target(0), m_scriptFactory(0)
+{
+}
+
+TaskKit::~TaskKit()
+{
+}
+
 VariableBase::~VariableBase()
 {
 }
