@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 00d1a61b8f5ead853ec7cf6bcb4316f48739bf96 $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -32,7 +31,7 @@
 
 #include "server/CommPeer.h"
 #include "server/CommServer.h"
-#include "server/ExternalMind.h"
+#include "rulesets/ExternalMind.h"
 
 #include "common/BaseWorld.h"
 
@@ -54,47 +53,49 @@ class TestCommClient : public CommClient<null_stream> {
 
 class TestWorld : public BaseWorld {
   public:
-    explicit TestWorld() : BaseWorld(*(Entity*)0) {
+    explicit TestWorld() : BaseWorld(*(LocatedEntity*)0) {
         m_realTime = 100000;
     }
 
     virtual bool idle(const SystemTime &) { return false; }
 
-    virtual Entity * addEntity(Entity * ent) { 
+    virtual LocatedEntity * addEntity(LocatedEntity * ent) { 
         return 0;
     }
 
-    Entity * test_addEntity(Entity * ent, long intId) { 
+    LocatedEntity * test_addEntity(LocatedEntity * ent, long intId) { 
         m_eobjects[intId] = ent;
         return 0;
     }
     void test_delEntity(long intId) { 
         m_eobjects.erase(intId);
     }
-    virtual Entity * addNewEntity(const std::string &,
+    virtual LocatedEntity * addNewEntity(const std::string &,
                                   const Atlas::Objects::Entity::RootEntity &) {
         return 0;
     }
     int createSpawnPoint(const Atlas::Message::MapType & data,
-                         Entity *) { return 0; }
+                         LocatedEntity *) { return 0; }
     int getSpawnList(Atlas::Message::ListType & data) { return 0; }
-    Entity * spawnNewEntity(const std::string & name,
-                            const std::string & type,
-                            const Atlas::Objects::Entity::RootEntity & desc) {
+    LocatedEntity * spawnNewEntity(const std::string & name,
+                                   const std::string & type,
+                                   const Atlas::Objects::Entity::RootEntity & desc) {
         return addNewEntity(type, desc);
     }
     virtual Task * newTask(const std::string &, LocatedEntity &) { return 0; }
     virtual Task * activateTask(const std::string &, const std::string &,
                                 LocatedEntity *, LocatedEntity &) { return 0; }
-    virtual ArithmeticScript * newArithmetic(const std::string &, Entity *) {
+    virtual ArithmeticScript * newArithmetic(const std::string &,
+                                             LocatedEntity *) {
         return 0;
     }
-    virtual void message(const Operation & op, Entity & ent) {
+    virtual void message(const Operation & op,
+                         LocatedEntity & ent) {
         // stub_baseworld_receieved_op = op->getClassNo();
     }
-    virtual Entity * findByName(const std::string & name) { return 0; }
-    virtual Entity * findByType(const std::string & type) { return 0; }
-    virtual void addPerceptive(Entity *) { }
+    virtual LocatedEntity * findByName(const std::string & name) { return 0; }
+    virtual LocatedEntity * findByType(const std::string & type) { return 0; }
+    virtual void addPerceptive(LocatedEntity *) { }
 };
 
 class TestPeer : public Peer {
@@ -535,7 +536,7 @@ Idle::~Idle()
 {
 }
 
-ExternalMind::ExternalMind(Entity & e) : Router(e.getId(), e.getIntId()),
+ExternalMind::ExternalMind(LocatedEntity & e) : Router(e.getId(), e.getIntId()),
                                          m_external(0), m_entity(e)
 {
 }
@@ -544,6 +545,10 @@ ExternalMind::~ExternalMind()
 {
 }
 
+void ExternalMind::externalOperation(const Operation &, Link &)
+{
+}
+
 void ExternalMind::operation(const Operation & op, OpVector & res)
 {
 }
@@ -554,7 +559,7 @@ void ExternalMind::linkUp(Link * c)
 }
 
 Character::Character(const std::string & id, long intId) :
-           Character_parent(id, intId),
+           Thing(id, intId),
                m_movement(*(Movement*)0),
                m_mind(0), m_externalMind(0)
 {
@@ -568,7 +573,7 @@ void Character::operation(const Operation & op, OpVector &)
 {
 }
 
-void Character::externalOperation(const Operation & op)
+void Character::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -609,6 +614,10 @@ void Character::ActuateOperation(const Operation & op, OpVector &)
 {
 }
 
+void Character::RelayOperation(const Operation & op, OpVector &)
+{
+}
+
 void Character::mindActuateOperation(const Operation &, OpVector &)
 {
 }
@@ -699,7 +708,7 @@ void Character::sendMind(const Operation & op, OpVector & res)
 }
 
 Thing::Thing(const std::string & id, long intId) :
-       Thing_parent(id, intId)
+       Entity(id, intId)
 {
 }
 
@@ -732,7 +741,7 @@ void Thing::UpdateOperation(const Operation & op, OpVector & res)
 }
 
 Entity::Entity(const std::string & id, long intId) :
-        LocatedEntity(id, intId), m_motion(0), m_flags(0)
+        LocatedEntity(id, intId), m_motion(0)
 {
 }
 
@@ -841,7 +850,11 @@ void Entity::WieldOperation(const Operation &, OpVector &)
 {
 }
 
-void Entity::externalOperation(const Operation & op)
+void Entity::RelayOperation(const Operation &, OpVector &)
+{
+}
+
+void Entity::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -873,7 +886,26 @@ PropertyBase * Entity::modProperty(const std::string & name)
     return 0;
 }
 
-void Entity::onContainered()
+PropertyBase * Entity::setProperty(const std::string & name,
+                                   PropertyBase * prop)
+{
+    return 0;
+}
+
+void Entity::installDelegate(int class_no, const std::string & delegate)
+{
+}
+
+Domain * Entity::getMovementDomain()
+{
+    return 0;
+}
+
+void Entity::sendWorld(const Operation & op)
+{
+}
+
+void Entity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -888,7 +920,7 @@ void Entity::callOperation(const Operation & op, OpVector & res)
 LocatedEntity::LocatedEntity(const std::string & id, long intId) :
                Router(id, intId),
                m_refCount(0), m_seq(0),
-               m_script(0), m_type(0), m_contains(0)
+               m_script(0), m_type(0), m_flags(0), m_contains(0)
 {
 }
 
@@ -925,7 +957,35 @@ const PropertyBase * LocatedEntity::getProperty(const std::string & name) const
     return 0;
 }
 
-void LocatedEntity::onContainered()
+PropertyBase * LocatedEntity::modProperty(const std::string & name)
+{
+    return 0;
+}
+
+PropertyBase * LocatedEntity::setProperty(const std::string & name,
+                                          PropertyBase * prop)
+{
+    return 0;
+}
+
+void LocatedEntity::installDelegate(int, const std::string &)
+{
+}
+
+void LocatedEntity::destroy()
+{
+}
+
+Domain * LocatedEntity::getMovementDomain()
+{
+    return 0;
+}
+
+void LocatedEntity::sendWorld(const Operation & op)
+{
+}
+
+void LocatedEntity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -1032,7 +1092,7 @@ TypeNode::~TypeNode()
 
 BaseWorld * BaseWorld::m_instance = 0;
 
-BaseWorld::BaseWorld(Entity & gw) : m_gameWorld(gw)
+BaseWorld::BaseWorld(LocatedEntity & gw) : m_gameWorld(gw)
 {
     m_instance = this;
 }
@@ -1042,7 +1102,7 @@ BaseWorld::~BaseWorld()
     m_instance = 0;
 }
 
-Entity * BaseWorld::getEntity(const std::string & id) const
+LocatedEntity * BaseWorld::getEntity(const std::string & id) const
 {
     long intId = integerId(id);
 
@@ -1055,7 +1115,7 @@ Entity * BaseWorld::getEntity(const std::string & id) const
     }
 }
 
-Entity * BaseWorld::getEntity(long id) const
+LocatedEntity * BaseWorld::getEntity(long id) const
 {
     EntityDict::const_iterator I = m_eobjects.find(id);
     if (I != m_eobjects.end()) {
