@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 649caf92e4d5e28b238bc6830ad62af956b2c23e $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -29,13 +28,13 @@
 
 #include "server/Player.h"
 
-#include "server/CommSocket.h"
 #include "server/Connection.h"
 #include "server/Ruleset.h"
 #include "server/ServerRouting.h"
 
 #include "rulesets/Entity.h"
 
+#include "common/CommSocket.h"
 #include "common/compose.hpp"
 #include "common/debug.h"
 
@@ -192,7 +191,7 @@ void Playertest::test_characterError_no_name()
 
     int result = m_account->characterError(op, description, res);
 
-    ASSERT_EQUAL(result, 1);
+    ASSERT_NOT_EQUAL(result, 0);
     ASSERT_EQUAL(res.size(), 1u);
     ASSERT_EQUAL(res.front()->getClassNo(),
                  Atlas::Objects::Operation::ERROR_NO);
@@ -210,7 +209,7 @@ void Playertest::test_characterError_admin_name()
 
     int result = m_account->characterError(op, description, res);
 
-    ASSERT_EQUAL(result, 1);
+    ASSERT_NOT_EQUAL(result, 0);
     ASSERT_EQUAL(res.size(), 1u);
     ASSERT_EQUAL(res.front()->getClassNo(),
                  Atlas::Objects::Operation::ERROR_NO);
@@ -228,7 +227,7 @@ void Playertest::test_characterError_not_playable()
 
     int result = m_account->characterError(op, description, res);
 
-    ASSERT_EQUAL(result, 1);
+    ASSERT_NOT_EQUAL(result, 0);
     ASSERT_EQUAL(res.size(), 1u);
     ASSERT_EQUAL(res.front()->getClassNo(),
                  Atlas::Objects::Operation::ERROR_NO);
@@ -250,11 +249,11 @@ void Playertest::test_characterError_playable()
     ASSERT_EQUAL(res.size(), 0u);
 }
 
-void TestWorld::message(const Operation & op, Entity & ent)
+void TestWorld::message(const Operation & op, LocatedEntity & ent)
 {
 }
 
-Entity * TestWorld::addNewEntity(const std::string &,
+LocatedEntity * TestWorld::addNewEntity(const std::string &,
                                  const Atlas::Objects::Entity::RootEntity &)
 {
     return 0;
@@ -291,7 +290,7 @@ Account::Account(Connection * conn,
                  const std::string & passwd,
                  const std::string & id,
                  long intId) :
-         ConnectedRouter(id, intId, conn),
+         ConnectableRouter(id, intId, conn),
          m_username(uname), m_password(passwd)
 {
 }
@@ -300,14 +299,14 @@ Account::~Account()
 {
 }
 
-Entity * Account::addNewCharacter(const std::string & typestr,
+LocatedEntity * Account::addNewCharacter(const std::string & typestr,
                                   const RootEntity & ent,
                                   const Root & arg)
 {
     return 0;
 }
 
-int Account::connectCharacter(Entity *chr)
+int Account::connectCharacter(LocatedEntity *chr)
 {
     return 0;
 }
@@ -321,6 +320,10 @@ void Account::store() const
 {
 }
 
+bool Account::isPersisted() const {
+    return true;
+}
+
 void Account::createObject(const std::string & type_str,
                            const Root & arg,
                            const Operation & op,
@@ -336,6 +339,10 @@ void Account::addToEntity(const RootEntity & ent) const
 {
 }
 
+void Account::externalOperation(const Operation & op, Link &)
+{
+}
+
 void Account::operation(const Operation & op, OpVector & res)
 {
 }
@@ -403,6 +410,10 @@ void Connection::addObject(Router * obj)
 {
 }
 
+void Connection::externalOperation(const Operation & op, Link &)
+{
+}
+
 void Connection::operation(const Operation &, OpVector &)
 {
 }
@@ -423,15 +434,11 @@ void Connection::GetOperation(const Operation &, OpVector &)
 {
 }
 
-void Connection::connectAvatar(Character * chr)
+void Connection::addEntity(LocatedEntity * ent)
 {
 }
 
-void Connection::addEntity(Entity * ent)
-{
-}
-
-ConnectedRouter::ConnectedRouter(const std::string & id,
+ConnectableRouter::ConnectableRouter(const std::string & id,
                                  long iid,
                                  Connection *c) :
                  Router(id, iid),
@@ -439,14 +446,15 @@ ConnectedRouter::ConnectedRouter(const std::string & id,
 {
 }
 
-ConnectedRouter::~ConnectedRouter()
+ConnectableRouter::~ConnectableRouter()
 {
 }
 
 Ruleset::Ruleset(EntityBuilder * eb) :
       m_taskHandler(0),
       m_entityHandler(0),
-      m_opHandler(0)
+      m_opHandler(0),
+      m_propertyHandler(0)
 {
 }
 
@@ -471,7 +479,7 @@ int Ruleset::installRule(const std::string & class_name,
 }
 
 Juncture::Juncture(Connection * c, const std::string & id, long iid) :
-          ConnectedRouter(id, iid, c),
+          ConnectableRouter(id, iid, c),
           m_address(0),
           m_socket(0),
           m_peer(0),
@@ -483,6 +491,10 @@ Juncture::~Juncture()
 {
 }
 
+void Juncture::externalOperation(const Operation & op, Link &)
+{
+}
+
 void Juncture::operation(const Operation & op, OpVector & res)
 {
 }
@@ -537,6 +549,14 @@ void ServerRouting::addAccount(Account * a)
 {
 }
 
+void ServerRouting::externalOperation(const Operation & op, Link &)
+{
+}
+
+void ServerRouting::operation(const Operation &, OpVector &)
+{
+}
+
 TeleportAuthenticator * TeleportAuthenticator::m_instance = NULL;
 
 int TeleportAuthenticator::removeTeleport(const std::string &entity_id)
@@ -544,7 +564,7 @@ int TeleportAuthenticator::removeTeleport(const std::string &entity_id)
     return 0;
 }
 
-Entity *TeleportAuthenticator::authenticateTeleport(const std::string &entity_id,
+LocatedEntity *TeleportAuthenticator::authenticateTeleport(const std::string &entity_id,
                                             const std::string &possess_key)
 {
     return 0;
@@ -569,7 +589,7 @@ void Persistence::putAccount(const Account & ac)
 }
 
 Character::Character(const std::string & id, long intId) :
-           Character_parent(id, intId),
+           Thing(id, intId),
                m_movement(*(Movement*)0),
                m_mind(0), m_externalMind(0)
 {
@@ -583,7 +603,7 @@ void Character::operation(const Operation & op, OpVector &)
 {
 }
 
-void Character::externalOperation(const Operation & op)
+void Character::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -624,6 +644,10 @@ void Character::ActuateOperation(const Operation & op, OpVector &)
 {
 }
 
+void Character::RelayOperation(const Operation & op, OpVector &)
+{
+}
+
 void Character::mindActuateOperation(const Operation &, OpVector &)
 {
 }
@@ -714,7 +738,7 @@ void Character::sendMind(const Operation & op, OpVector & res)
 }
 
 Thing::Thing(const std::string & id, long intId) :
-       Thing_parent(id, intId)
+       Entity(id, intId)
 {
 }
 
@@ -747,7 +771,7 @@ void Thing::UpdateOperation(const Operation & op, OpVector & res)
 }
 
 Entity::Entity(const std::string & id, long intId) :
-        LocatedEntity(id, intId), m_motion(0), m_flags(0)
+        LocatedEntity(id, intId), m_motion(0)
 {
 }
 
@@ -856,7 +880,11 @@ void Entity::WieldOperation(const Operation &, OpVector &)
 {
 }
 
-void Entity::externalOperation(const Operation & op)
+void Entity::RelayOperation(const Operation &, OpVector &)
+{
+}
+
+void Entity::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -888,7 +916,26 @@ PropertyBase * Entity::modProperty(const std::string & name)
     return 0;
 }
 
-void Entity::onContainered()
+PropertyBase * Entity::setProperty(const std::string & name,
+                                   PropertyBase * prop)
+{
+    return 0;
+}
+
+void Entity::installDelegate(int class_no, const std::string & delegate)
+{
+}
+
+Domain * Entity::getMovementDomain()
+{
+    return 0;
+}
+
+void Entity::sendWorld(const Operation & op)
+{
+}
+
+void Entity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -903,7 +950,7 @@ void Entity::callOperation(const Operation & op, OpVector & res)
 LocatedEntity::LocatedEntity(const std::string & id, long intId) :
                Router(id, intId),
                m_refCount(0), m_seq(0),
-               m_script(0), m_type(0), m_contains(0)
+               m_script(0), m_type(0), m_flags(0), m_contains(0)
 {
 }
 
@@ -940,7 +987,35 @@ const PropertyBase * LocatedEntity::getProperty(const std::string & name) const
     return 0;
 }
 
-void LocatedEntity::onContainered()
+PropertyBase * LocatedEntity::modProperty(const std::string & name)
+{
+    return 0;
+}
+
+PropertyBase * LocatedEntity::setProperty(const std::string & name,
+                                          PropertyBase * prop)
+{
+    return 0;
+}
+
+void LocatedEntity::installDelegate(int, const std::string &)
+{
+}
+
+void LocatedEntity::destroy()
+{
+}
+
+Domain * LocatedEntity::getMovementDomain()
+{
+    return 0;
+}
+
+void LocatedEntity::sendWorld(const Operation & op)
+{
+}
+
+void LocatedEntity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -1015,7 +1090,7 @@ bool Inheritance::hasClass(const std::string & parent)
 
 BaseWorld * BaseWorld::m_instance = 0;
 
-BaseWorld::BaseWorld(Entity & gw) : m_gameWorld(gw)
+BaseWorld::BaseWorld(LocatedEntity & gw) : m_gameWorld(gw)
 {
     m_instance = this;
 }
@@ -1026,12 +1101,12 @@ BaseWorld::~BaseWorld()
     delete &m_gameWorld;
 }
 
-Entity * BaseWorld::getEntity(const std::string & id) const
+LocatedEntity * BaseWorld::getEntity(const std::string & id) const
 {
     return 0;
 }
 
-Entity * BaseWorld::getEntity(long id) const
+LocatedEntity * BaseWorld::getEntity(long id) const
 {
     return 0;
 }
@@ -1106,3 +1181,13 @@ bool database_flag = false;
 namespace Atlas { namespace Objects { namespace Operation {
 int MONITOR_NO = -1;
 } } }
+
+#include <common/Shaker.h>
+
+Shaker::Shaker()
+{
+}
+std::string Shaker::generateSalt(size_t length)
+{
+    return "";
+}
