@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 5f0301c68974a2933616683ef90a147e78a492f8 $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -24,22 +23,60 @@
 #define DEBUG
 #endif
 
+#include "TestBase.h"
+
 #include "common/PropertyFactory_impl.h"
 #include "common/Property.h"
 
 #include <cassert>
 
-void testFactory(PropertyKit & pk)
+class PropertyFactorytest : public Cyphesis::TestBase
 {
-    PropertyBase * p = pk.newProperty();
-    assert(p != 0);
+  public:
+    PropertyFactorytest();
+
+    void setup();
+    void teardown();
+
+    template <class PropertyT>
+    void test_factory();
+};
+
+PropertyFactorytest::PropertyFactorytest()
+{
+    ADD_TEST(PropertyFactorytest::test_factory<Property<int>>);
+    ADD_TEST(PropertyFactorytest::test_factory<Property<long>>);
+    ADD_TEST(PropertyFactorytest::test_factory<Property<double>>);
+    ADD_TEST(PropertyFactorytest::test_factory<Property<std::string>>);
+}
+
+void PropertyFactorytest::setup()
+{
+}
+
+void PropertyFactorytest::teardown()
+{
+}
+
+template <class PropertyT>
+void PropertyFactorytest::test_factory()
+{
+    PropertyFactory<PropertyT> pf;
+
+    PropertyBase * p = pf.newProperty();
+
+    ASSERT_NOT_NULL(p);
+    ASSERT_NOT_NULL(dynamic_cast<PropertyT *>(p));
+
+    PropertyKit * pk = pf.duplicateFactory();
+
+    ASSERT_NOT_NULL(pk);
+    ASSERT_NOT_NULL(dynamic_cast<PropertyFactory<PropertyT> *>(pk));
 }
 
 int main()
 {
-    PropertyFactory<Property<int> > pf;
+    PropertyFactorytest t;
 
-    testFactory(pf);
-
-    return 0;
+    return t.run();
 }
