@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 378d24485af0d8ad26378cb94d3b73f1aab59caa $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -371,6 +370,7 @@ int main(int argc, char ** argv)
 
 #include "server/EntityRuleHandler.h"
 #include "server/OpRuleHandler.h"
+#include "server/PropertyRuleHandler.h"
 #include "server/TaskRuleHandler.h"
 #include "server/Persistence.h"
 
@@ -401,6 +401,29 @@ int OpRuleHandler::update(const std::string & name,
     return 0;
 }
 
+int PropertyRuleHandler::check(const Atlas::Objects::Root & desc)
+{
+    if (desc->getObjtype() != "type") {
+        return -1;
+    }
+    return 0;
+}
+
+int PropertyRuleHandler::install(const std::string & name,
+                             const std::string & parent,
+                             const Atlas::Objects::Root & description,
+                             std::string & dependent,
+                             std::string & reason)
+{
+    return 0;
+}
+
+int PropertyRuleHandler::update(const std::string & name,
+                            const Atlas::Objects::Root & desc)
+{
+    return 0;
+}
+
 int EntityRuleHandler::check(const Atlas::Objects::Root & desc)
 {
     if (desc->getObjtype() != "class") {
