@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 26f98ecd1876ba5cb9bada262d9a3e7f0bdaa0fb $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -26,12 +25,14 @@
 
 #include "common/ScriptKit.h"
 
-class TestScriptKit : public ScriptKit<Entity>
+class LocatedEntity;
+
+class TestScriptKit : public ScriptKit<LocatedEntity>
 {
   public:
     std::string m_package;
     virtual const std::string & package() const { return m_package; }
-    virtual int addScript(Entity * entity) const { return 0; }
+    virtual int addScript(LocatedEntity * entity) const { return 0; }
     virtual int refreshClass() { return 0; }
 };
 
@@ -39,7 +40,7 @@ int main()
 {
     // The is no code in ScriptKit.cpp to execute, but we need coverage.
     {
-        ScriptKit<Entity> * sk = new TestScriptKit;
+        ScriptKit<LocatedEntity> * sk = new TestScriptKit;
 
         delete sk;
     }
