@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 2a04c2d731dcb59d36be7fb14a16a82cb1054f18 $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -32,7 +31,7 @@ int main()
 {
     SolidProperty * ap = new SolidProperty;
 
-    PropertyCoverage pc(ap);
+    PropertyChecker<SolidProperty> pc(ap);
 
     // Coverage is complete, but it wouldn't hurt to add some bad data here.
 
@@ -44,11 +43,11 @@ int main()
 
 #include "TestWorld.h"
 
-void TestWorld::message(const Operation & op, Entity & ent)
+void TestWorld::message(const Operation & op, LocatedEntity & ent)
 {
 }
 
-Entity * TestWorld::addNewEntity(const std::string &,
+LocatedEntity * TestWorld::addNewEntity(const std::string &,
                                  const Atlas::Objects::Entity::RootEntity &)
 {
     return 0;
