@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: d603fbc90735eac91f71b583effb7fdbd0a425ce $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -27,12 +26,16 @@
 #include "server/StorageManager.h"
 
 #include "server/WorldRouter.h"
+#include "server/MindInspector.h"
 
 #include "rulesets/Entity.h"
+#include "rulesets/Character.h"
+#include "rulesets/MindProperty.h"
 
 #include "common/SystemTime.h"
 
 #include <cassert>
+using Atlas::Message::Element;
 
 class TestStorageManager : public StorageManager
 {
@@ -40,27 +43,27 @@ class TestStorageManager : public StorageManager
     TestStorageManager(WorldRouter&w) : StorageManager(w) { }
 
     
-    void test_entityInserted(Entity * e) {
+    void test_entityInserted(LocatedEntity * e) {
         entityInserted(e);
     }
-    void test_entityUpdated(Entity * e) {
+    void test_entityUpdated(LocatedEntity * e) {
         entityUpdated(e);
     }
 
     void test_encodeProperty(PropertyBase * p, std::string & s) {
         encodeProperty(p, s);
     }
-    void test_restoreProperties(Entity * e) {
+    void test_restoreProperties(LocatedEntity * e) {
         restoreProperties(e);
     }
 
-    void test_insertEntity(Entity * e) {
+    void test_insertEntity(LocatedEntity * e) {
         insertEntity(e);
     }
-    void test_updateEntity(Entity * e) {
+    void test_updateEntity(LocatedEntity * e) {
         updateEntity(e);
     }
-    void test_restoreChildren(Entity * e) {
+    void test_restoreChildren(LocatedEntity * e) {
         restoreChildren(e);
     }
 
@@ -244,18 +247,18 @@ WorldRouter::~WorldRouter()
 {
 }
 
-Entity * WorldRouter::addEntity(Entity * ent)
+LocatedEntity * WorldRouter::addEntity(LocatedEntity * ent)
 {
     return 0;
 }
 
-Entity * WorldRouter::addNewEntity(const std::string & typestr,
-                                   const RootEntity & attrs)
+LocatedEntity * WorldRouter::addNewEntity(const std::string & typestr,
+                                          const RootEntity & attrs)
 {
     return 0;
 }
 
-int WorldRouter::createSpawnPoint(const MapType & data, Entity * ent)
+int WorldRouter::createSpawnPoint(const MapType & data, LocatedEntity * ent)
 {
     return 0;
 }
@@ -265,9 +268,9 @@ int WorldRouter::getSpawnList(Atlas::Message::ListType & data)
     return 0;
 }
 
-Entity * WorldRouter::spawnNewEntity(const std::string & name,
-                                     const std::string & type,
-                                     const RootEntity & desc)
+LocatedEntity * WorldRouter::spawnNewEntity(const std::string & name,
+                                            const std::string & type,
+                                            const RootEntity & desc)
 {
     return 0;
 }
@@ -285,7 +288,7 @@ Task * WorldRouter::activateTask(const std::string & tool,
     return 0;
 }
 
-void WorldRouter::message(const Operation & op, Entity & ent)
+void WorldRouter::message(const Operation & op, LocatedEntity & ent)
 {
 }
 
@@ -294,23 +297,27 @@ bool WorldRouter::idle(const SystemTime &)
     return false;
 }
 
-Entity * WorldRouter::findByName(const std::string & name)
+LocatedEntity * WorldRouter::findByName(const std::string & name)
 {
     return 0;
 }
 
-Entity * WorldRouter::findByType(const std::string & type)
+LocatedEntity * WorldRouter::findByType(const std::string & type)
 {
     return 0;
 }
 
 ArithmeticScript * WorldRouter::newArithmetic(const std::string & name,
-                                              Entity * owner)
+                                              LocatedEntity * owner)
 {
     return 0;
 }
 
-void WorldRouter::addPerceptive(Entity * perceptive)
+void WorldRouter::addPerceptive(LocatedEntity * perceptive)
+{
+}
+
+void WorldRouter::resumeWorld()
 {
 }
 
@@ -324,16 +331,198 @@ EntityBuilder::~EntityBuilder()
 {
 }
 
-Entity * EntityBuilder::newEntity(const std::string & id, long intId,
-                                  const std::string & type,
-                                  const RootEntity & attributes,
-                                  const BaseWorld &) const
+LocatedEntity * EntityBuilder::newEntity(const std::string & id, long intId,
+                                         const std::string & type,
+                                         const RootEntity & attributes,
+                                         const BaseWorld &) const
 {
     return 0;
 }
 
+Character::Character(const std::string & id, long intId) :
+           Thing(id, intId),
+               m_movement(*(Movement*)0),
+               m_mind(0), m_externalMind(0)
+{
+}
+
+Character::~Character()
+{
+}
+
+void Character::operation(const Operation & op, OpVector &)
+{
+}
+
+void Character::externalOperation(const Operation & op, Link &)
+{
+}
+
+
+void Character::ImaginaryOperation(const Operation & op, OpVector &)
+{
+}
+
+void Character::InfoOperation(const Operation & op, OpVector &)
+{
+}
+
+void Character::TickOperation(const Operation & op, OpVector &)
+{
+}
+
+void Character::TalkOperation(const Operation & op, OpVector &)
+{
+}
+
+void Character::NourishOperation(const Operation & op, OpVector &)
+{
+}
+
+void Character::UseOperation(const Operation & op, OpVector &)
+{
+}
+
+void Character::WieldOperation(const Operation & op, OpVector &)
+{
+}
+
+void Character::AttackOperation(const Operation & op, OpVector &)
+{
+}
+
+void Character::ActuateOperation(const Operation & op, OpVector &)
+{
+}
+
+void Character::RelayOperation(const Operation & op, OpVector &)
+{
+}
+
+void Character::mindActuateOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindAttackOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindCombineOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindCreateOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindDeleteOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindDivideOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindEatOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindGoalInfoOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindImaginaryOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindLookOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindMoveOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindSetOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindSetupOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindTalkOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindThoughtOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindTickOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindTouchOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindUpdateOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindUseOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::mindWieldOperation(const Operation &, OpVector &)
+{
+}
+
+
+void Character::mindOtherOperation(const Operation &, OpVector &)
+{
+}
+
+void Character::sendMind(const Operation & op, OpVector & res)
+{
+}
+
+Thing::Thing(const std::string & id, long intId) :
+       Entity(id, intId)
+{
+}
+
+Thing::~Thing()
+{
+}
+
+void Thing::DeleteOperation(const Operation & op, OpVector & res)
+{
+}
+
+void Thing::MoveOperation(const Operation & op, OpVector & res)
+{
+}
+
+void Thing::SetOperation(const Operation & op, OpVector & res)
+{
+}
+
+void Thing::LookOperation(const Operation & op, OpVector & res)
+{
+}
+
+void Thing::CreateOperation(const Operation & op, OpVector & res)
+{
+}
+
+void Thing::UpdateOperation(const Operation & op, OpVector & res)
+{
+}
+
 Entity::Entity(const std::string & id, long intId) :
-        LocatedEntity(id, intId), m_motion(0), m_flags(0)
+        LocatedEntity(id, intId), m_motion(0)
 {
 }
 
@@ -442,7 +631,11 @@ void Entity::WieldOperation(const Operation &, OpVector &)
 {
 }
 
-void Entity::externalOperation(const Operation & op)
+void Entity::RelayOperation(const Operation &, OpVector &)
+{
+}
+
+void Entity::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -480,7 +673,20 @@ PropertyBase * Entity::setProperty(const std::string & name,
     return 0;
 }
 
-void Entity::onContainered()
+void Entity::installDelegate(int class_no, const std::string & delegate)
+{
+}
+
+Domain * Entity::getMovementDomain()
+{
+    return 0;
+}
+
+void Entity::sendWorld(const Operation & op)
+{
+}
+
+void Entity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -491,7 +697,7 @@ void Entity::onUpdated()
 LocatedEntity::LocatedEntity(const std::string & id, long intId) :
                Router(id, intId),
                m_refCount(0), m_seq(0),
-               m_script(0), m_type(0), m_contains(0)
+               m_script(0), m_type(0), m_flags(0), m_contains(0)
 {
 }
 
@@ -528,7 +734,35 @@ const PropertyBase * LocatedEntity::getProperty(const std::string & name) const
     return 0;
 }
 
-void LocatedEntity::onContainered()
+PropertyBase * LocatedEntity::modProperty(const std::string & name)
+{
+    return 0;
+}
+
+PropertyBase * LocatedEntity::setProperty(const std::string & name,
+                                          PropertyBase * prop)
+{
+    return 0;
+}
+
+void LocatedEntity::installDelegate(int, const std::string &)
+{
+}
+
+void LocatedEntity::destroy()
+{
+}
+
+Domain * LocatedEntity::getMovementDomain()
+{
+    return 0;
+}
+
+void LocatedEntity::sendWorld(const Operation & op)
+{
+}
+
+void LocatedEntity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -584,6 +818,13 @@ PropertyManager::~PropertyManager()
    m_instance = 0;
 }
 
+int PropertyManager::installFactory(const std::string & type_name,
+                                    const Atlas::Objects::Root & type_desc,
+                                    PropertyKit * factory)
+{
+    return 0;
+}
+
 void Location::addToMessage(MapType & omap) const
 {
 }
@@ -620,7 +861,7 @@ void Script::hook(const std::string & function, LocatedEntity * entity)
 {
 }
 
-EntityRef::EntityRef(Entity* e) : m_inner(e)
+EntityRef::EntityRef(LocatedEntity* e) : m_inner(e)
 {
 }
 
@@ -693,7 +934,15 @@ int Database::insertEntity(const std::string & id,
 
 int Database::updateEntity(const std::string & id,
                            int seq,
-                           const std::string & value)
+                           const std::string & location_data,
+                           const std::string & location)
+{
+    return 0;
+}
+
+int Database::updateEntityWithoutLoc(const std::string & id,
+                           int seq,
+                           const std::string & location_data)
 {
     return 0;
 }
@@ -715,6 +964,31 @@ int Database::updateProperties(const std::string & id,
     return 0;
 }
 
+int Database::registerThoughtsTable()
+{
+    return 0;
+}
+const DatabaseResult Database::selectThoughts(const std::string & loc)
+{
+    return DatabaseResult(0);
+}
+int Database::replaceThoughts(const std::string & id,
+                     const std::vector<std::string>& thoughts)
+{
+    return 0;
+}
+
+int Database::launchNewQuery()
+{
+    return 0;
+}
+int Database::clearPendingQuery()
+{
+    return 0;
+}
+
+
+
 const char * DatabaseResult::const_iterator::column(const char * column) const
 {
     return "";
@@ -773,7 +1047,7 @@ void Monitors::watch(const::std::string & name, VariableBase * monitor)
 
 BaseWorld * BaseWorld::m_instance = 0;
 
-BaseWorld::BaseWorld(Entity & gw) : m_gameWorld(gw)
+BaseWorld::BaseWorld(LocatedEntity & gw) : m_gameWorld(gw)
 {
     m_instance = this;
 }
@@ -783,6 +1057,90 @@ BaseWorld::~BaseWorld()
     m_instance = 0;
 }
 
+MindInspector::MindInspector() :
+        m_serial(0)
+{
+}
+
+MindInspector::~MindInspector()
+{
+}
+
+void MindInspector::queryEntityForThoughts(const std::string& entityId)
+{
+}
+
+void MindInspector::relayResponseReceived(const Operation& op,
+        const std::string& entityId)
+{
+}
+
+PropertyBase::PropertyBase(unsigned int flags) : m_flags(flags)
+{
+}
+
+PropertyBase::~PropertyBase()
+{
+}
+
+void PropertyBase::install(LocatedEntity *, const std::string & name)
+{
+}
+
+void PropertyBase::apply(LocatedEntity *)
+{
+}
+
+void PropertyBase::add(const std::string & s,
+                       Atlas::Message::MapType & ent) const
+{
+    get(ent[s]);
+}
+
+void PropertyBase::add(const std::string & s,
+                       const Atlas::Objects::Entity::RootEntity & ent) const
+{
+}
+
+HandlerResult PropertyBase::operation(LocatedEntity *,
+                                      const Operation &,
+                                      OpVector &)
+{
+    return OPERATION_IGNORED;
+}
+
+
+bool MindProperty::isMindEnabled() const {
+    return false;
+}
+
+MindProperty::MindProperty() : m_factory(0)
+{
+}
+
+MindProperty::~MindProperty()
+{
+}
+
+int MindProperty::get(Element & val) const
+{
+    return 0;
+}
+
+void MindProperty::set(const Element & val)
+{
+}
+
+MindProperty * MindProperty::copy() const
+{
+    return 0;
+}
+
+void MindProperty::apply(LocatedEntity * ent)
+{
+}
+
+
 long forceIntegerId(const std::string & id)
 {
     long intId = strtol(id.c_str(), 0, 10);
@@ -807,3 +1165,7 @@ namespace consts {
   const long rootWorldIntId = 0L;
 
 }
+
+namespace Atlas { namespace Objects { namespace Operation {
+int THINK_NO = -1;
+} } }
