@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 6aa65b6459659f49ea326b78003003f467ad2728 $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -44,6 +43,8 @@ int main()
 
 // stubs
 
-EntityRef::EntityRef(Entity* e) : m_inner(e)
+#include "modules/EntityRef.h"
+
+EntityRef::EntityRef(LocatedEntity* e) : m_inner(e)
 {
 }
