@@ -15,19 +15,28 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 1d2cfc4ac308d5b83db22483e2b3d8d3f913be6f $
 
 #ifndef TESTS_TEST_PROPERTY_MANAGER_H
 #define TESTS_TEST_PROPERTY_MANAGER_H
 
 #include "common/PropertyManager.h"
 
+#include <map>
+
+class PropertyKit;
+
+typedef std::map<std::string, PropertyKit *> PropertyFactoryDict;
+
 class TestPropertyManager : public PropertyManager {
+  private:
+    std::map<std::string, PropertyKit *> m_propertyFactories;
   public:
     TestPropertyManager();
     virtual ~TestPropertyManager();
 
     virtual PropertyBase * addProperty(const std::string & name, int type);
+
+    void installPropertyFactory(const std::string &, PropertyKit *);
 };
 
 #endif // TESTS_TEST_PROPERTY_MANAGER_H
