@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: b02b81576e22a491dfe290c274ffed901de5856d $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -31,8 +30,8 @@
 #include "server/Account.h"
 #include "server/CommClient.h"
 #include "server/CommServer.h"
-#include "server/ExternalMind.h"
-#include "server/ExternalProperty.h"
+#include "rulesets/ExternalMind.h"
+#include "rulesets/ExternalProperty.h"
 #include "server/Lobby.h"
 #include "server/Player.h"
 #include "server/ServerRouting.h"
@@ -310,8 +309,8 @@ const char * SystemAccount::getType() const
     return "sys";
 }
 
-void SystemAccount::store() const
-{
+bool SystemAccount::isPersisted() const {
+    return false;
 }
 
 Account::Account(Connection * conn,
@@ -319,7 +318,7 @@ Account::Account(Connection * conn,
                  const std::string & passwd,
                  const std::string & id,
                  long intId) :
-         ConnectedRouter(id, intId, conn),
+         ConnectableRouter(id, intId, conn),
          m_username(uname), m_password(passwd)
 {
 }
@@ -337,6 +336,10 @@ void Account::store() const
 {
 }
 
+bool Account::isPersisted() const {
+    return true;
+}
+
 void Account::addToMessage(Atlas::Message::MapType &) const
 {
 }
@@ -352,6 +355,10 @@ void Account::createObject(const std::string & type_str,
 {
 }
 
+void Account::externalOperation(const Operation &, Link &)
+{
+}
+
 void Account::operation(const Operation &, OpVector &)
 {
 }
@@ -389,7 +396,7 @@ void Account::OtherOperation(const Operation &, OpVector &)
 {
 }
 
-ConnectedRouter::ConnectedRouter(const std::string & id,
+ConnectableRouter::ConnectableRouter(const std::string & id,
                                  long iid,
                                  Connection *c) :
                  Router(id, iid),
@@ -397,7 +404,7 @@ ConnectedRouter::ConnectedRouter(const std::string & id,
 {
 }
 
-ConnectedRouter::~ConnectedRouter()
+ConnectableRouter::~ConnectableRouter()
 {
 }
 
@@ -430,6 +437,10 @@ Connection::~Connection()
 }
 
 
+void Connection::externalOperation(const Operation &, Link &)
+{
+}
+
 void Connection::operation(const Operation &, OpVector &)
 {
 }
@@ -494,6 +505,14 @@ void ServerRouting::addAccount(Account * a)
 {
 }
 
+void ServerRouting::externalOperation(const Operation & op, Link &)
+{
+}
+
+void ServerRouting::operation(const Operation &, OpVector &)
+{
+}
+
 Lobby::Lobby(ServerRouting & s, const std::string & id, long intId) :
        Router(id, intId),
        m_server(s)
@@ -520,11 +539,15 @@ void Lobby::addAccount(Account * ac)
 {
 }
 
+void Lobby::externalOperation(const Operation &, Link &)
+{
+}
+
 void Lobby::operation(const Operation & op, OpVector & res)
 {
 }
 
-ExternalMind::ExternalMind(Entity & e) : Router(e.getId(), e.getIntId()),
+ExternalMind::ExternalMind(LocatedEntity & e) : Router(e.getId(), e.getIntId()),
                                          m_external(0), m_entity(e)
 {
 }
@@ -533,11 +556,15 @@ ExternalMind::~ExternalMind()
 {
 }
 
+void ExternalMind::externalOperation(const Operation &, Link &)
+{
+}
+
 void ExternalMind::operation(const Operation & op, OpVector & res)
 {
 }
 
-ExternalProperty::ExternalProperty(Router * & data) : m_data(data)
+ExternalProperty::ExternalProperty(ExternalMind * & data) : m_data(data)
 {
 }
 
@@ -560,6 +587,11 @@ void ExternalProperty::add(const std::string & s,
 {
 }
 
+ExternalProperty * ExternalProperty::copy() const
+{
+    return 0;
+}
+
 const std::string & ExternalMind::connectionId()
 {
     assert(m_external != 0);
@@ -572,7 +604,7 @@ void ExternalMind::linkUp(Link * c)
 }
 
 Character::Character(const std::string & id, long intId) :
-           Character_parent(id, intId),
+           Thing(id, intId),
                m_movement(*(Movement*)0),
                m_mind(0), m_externalMind(0)
 {
@@ -586,7 +618,7 @@ void Character::operation(const Operation & op, OpVector &)
 {
 }
 
-void Character::externalOperation(const Operation & op)
+void Character::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -627,6 +659,10 @@ void Character::ActuateOperation(const Operation & op, OpVector &)
 {
 }
 
+void Character::RelayOperation(const Operation & op, OpVector &)
+{
+}
+
 void Character::mindActuateOperation(const Operation &, OpVector &)
 {
 }
@@ -714,7 +750,7 @@ void Character::mindOtherOperation(const Operation &, OpVector &)
 
 
 Thing::Thing(const std::string & id, long intId) :
-       Thing_parent(id, intId)
+       Entity(id, intId)
 {
 }
 
@@ -747,7 +783,7 @@ void Thing::UpdateOperation(const Operation & op, OpVector & res)
 }
 
 Entity::Entity(const std::string & id, long intId) :
-        LocatedEntity(id, intId), m_motion(0), m_flags(0)
+        LocatedEntity(id, intId), m_motion(0)
 {
 }
 
@@ -856,7 +892,11 @@ void Entity::WieldOperation(const Operation &, OpVector &)
 {
 }
 
-void Entity::externalOperation(const Operation & op)
+void Entity::RelayOperation(const Operation &, OpVector &)
+{
+}
+
+void Entity::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -889,7 +929,25 @@ PropertyBase * Entity::setProperty(const std::string & name,
     return m_properties[name] = prop;
 }
 
-void Entity::onContainered()
+PropertyBase * Entity::modProperty(const std::string & name)
+{
+    return 0;
+}
+
+void Entity::installDelegate(int class_no, const std::string & delegate)
+{
+}
+
+Domain * Entity::getMovementDomain()
+{
+    return 0;
+}
+
+void Entity::sendWorld(const Operation & op)
+{
+}
+
+void Entity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -900,7 +958,7 @@ void Entity::onUpdated()
 LocatedEntity::LocatedEntity(const std::string & id, long intId) :
                Router(id, intId),
                m_refCount(0), m_seq(0),
-               m_script(0), m_type(0), m_contains(0)
+               m_script(0), m_type(0), m_flags(0), m_contains(0)
 {
 }
 
@@ -937,7 +995,35 @@ const PropertyBase * LocatedEntity::getProperty(const std::string & name) const
     return 0;
 }
 
-void LocatedEntity::onContainered()
+PropertyBase * LocatedEntity::modProperty(const std::string & name)
+{
+    return 0;
+}
+
+PropertyBase * LocatedEntity::setProperty(const std::string & name,
+                                          PropertyBase * prop)
+{
+    return 0;
+}
+
+void LocatedEntity::installDelegate(int, const std::string &)
+{
+}
+
+void LocatedEntity::destroy()
+{
+}
+
+Domain * LocatedEntity::getMovementDomain()
+{
+    return 0;
+}
+
+void LocatedEntity::sendWorld(const Operation & op)
+{
+}
+
+void LocatedEntity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -1005,11 +1091,11 @@ PropertyBase::~PropertyBase()
 {
 }
 
-void PropertyBase::install(Entity *)
+void PropertyBase::install(LocatedEntity *, const std::string & name)
 {
 }
 
-void PropertyBase::apply(Entity *)
+void PropertyBase::apply(LocatedEntity *)
 {
 }
 
@@ -1023,9 +1109,16 @@ void PropertyBase::add(const std::string & s,
 {
 }
 
+HandlerResult PropertyBase::operation(LocatedEntity *,
+                                      const Operation &,
+                                      OpVector &)
+{
+    return OPERATION_IGNORED;
+}
+
 BaseWorld * BaseWorld::m_instance = 0;
 
-BaseWorld::BaseWorld(Entity & gw) : m_gameWorld(gw)
+BaseWorld::BaseWorld(LocatedEntity & gw) : m_gameWorld(gw)
 {
 }
 
@@ -1033,12 +1126,12 @@ BaseWorld::~BaseWorld()
 {
 }
 
-Entity * BaseWorld::getEntity(const std::string & id) const
+LocatedEntity * BaseWorld::getEntity(const std::string & id) const
 {
     return 0;
 }
 
-Entity * BaseWorld::getEntity(long id) const
+LocatedEntity * BaseWorld::getEntity(long id) const
 {
     return 0;
 }
@@ -1117,3 +1210,14 @@ int check_password(const std::string & pwd, const std::string & hash)
 {
     return 0;
 }
+
+#include <common/Shaker.h>
+
+Shaker::Shaker()
+{
+}
+
+std::string Shaker::generateSalt(size_t length)
+{
+return "";
+}
