@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: 4d30e664db74e0ef946e800ce719fbdb075c2ece $
 
 #ifdef NDEBUG
 #undef NDEBUG
@@ -24,6 +23,8 @@
 #define DEBUG
 #endif
 
+#include "TestBase.h"
+
 #include "server/WorldRouter.h"
 
 #include "server/ArithmeticBuilder.h"
@@ -55,225 +56,233 @@ using Atlas::Objects::Entity::Anonymous;
 using Atlas::Objects::Entity::RootEntity;
 using Atlas::Objects::Operation::Tick;
 
-class TestWorldRouter : public WorldRouter
+static bool stub_deny_newid = false;
+
+class WorldRoutertest : public Cyphesis::TestBase
 {
+    WorldRouter * test_world;
   public:
-    TestWorldRouter() : WorldRouter(SystemTime()) { }
+    WorldRoutertest();
 
-    Operation test_getOperationFromQueue() {
-        return getOperationFromQueue();
-    }
+    void setup();
+    void teardown();
 
-    void test_delEntity(Entity * e) {
-        delEntity(e);
-    }
+    void test_constructor();
+    void test_addNewEntity_unknown();
+    void test_addNewEntity_thing();
+    void test_addNewEntity_idfail();
+    void test_addEntity();
+    void test_getOperationFromQueue();
+    void test_addEntity_tick();
+    void test_addEntity_tick_get();
+    void test_spawnNewEntity_unknown();
+    void test_spawnNewEntity_thing();
+    void test_createSpawnPoint();
+    void test_delEntity();
+    void test_delEntity_world();
 };
 
-static bool stub_deny_newid = false;
+WorldRoutertest::WorldRoutertest()
+{
+    ADD_TEST(WorldRoutertest::test_constructor);
+    ADD_TEST(WorldRoutertest::test_addNewEntity_unknown);
+    ADD_TEST(WorldRoutertest::test_addNewEntity_thing);
+    ADD_TEST(WorldRoutertest::test_addNewEntity_idfail);
+    ADD_TEST(WorldRoutertest::test_addEntity);
+    ADD_TEST(WorldRoutertest::test_getOperationFromQueue);
+    ADD_TEST(WorldRoutertest::test_addEntity_tick);
+    ADD_TEST(WorldRoutertest::test_addEntity_tick_get);
+    ADD_TEST(WorldRoutertest::test_spawnNewEntity_unknown);
+    ADD_TEST(WorldRoutertest::test_spawnNewEntity_thing);
+    ADD_TEST(WorldRoutertest::test_createSpawnPoint);
+    ADD_TEST(WorldRoutertest::test_delEntity);
+    ADD_TEST(WorldRoutertest::test_delEntity_world);
+}
+
+void WorldRoutertest::setup()
+{
+    test_world = new WorldRouter(SystemTime());
+}
+
+void WorldRoutertest::teardown()
+{
+    delete test_world;
+
+    EntityBuilder::del();
+}
+
+void WorldRoutertest::test_constructor()
+{
+}
+
+void WorldRoutertest::test_addNewEntity_unknown()
+{
+
+    LocatedEntity * ent1 = test_world->addNewEntity("__no_such_type__",
+                                                    Anonymous());
+    assert(ent1 == 0);
+}
+
+void WorldRoutertest::test_addNewEntity_thing()
+{
+    LocatedEntity * ent1 = test_world->addNewEntity("thing", Anonymous());
+    assert(ent1 != 0);
+}
+
+
+void WorldRoutertest::test_addNewEntity_idfail()
+{
+    stub_deny_newid = true;
+
+    LocatedEntity * ent1 = test_world->addNewEntity("thing", Anonymous());
+    assert(ent1 == 0);
+
+    stub_deny_newid = false;
+}
+
+void WorldRoutertest::test_addEntity()
+{
+    std::string id;
+    long int_id = newId(id);
+
+    Entity * ent2 = new Entity(id, int_id);
+    assert(ent2 != 0);
+    ent2->m_location.m_loc = &test_world->m_gameWorld;
+    ent2->m_location.m_pos = Point3D(0,0,0);
+    test_world->addEntity(ent2);
+}
+
+void WorldRoutertest::test_getOperationFromQueue()
+{
+    test_world->getOperationFromQueue();
+}
+
+void WorldRoutertest::test_addEntity_tick()
+{
+    std::string id;
+    long int_id = newId(id);
+
+    Entity * ent2 = new Entity(id, int_id);
+    assert(ent2 != 0);
+    ent2->m_location.m_loc = &test_world->m_gameWorld;
+    ent2->m_location.m_pos = Point3D(0,0,0);
+    test_world->addEntity(ent2);
+
+    Tick tick;
+    tick->setFutureSeconds(0);
+    tick->setTo(ent2->getId());
+    test_world->message(tick, *ent2);
+}
+
+
+void WorldRoutertest::test_addEntity_tick_get()
+{
+    std::string id;
+    long int_id = newId(id);
+
+    Entity * ent2 = new Entity(id, int_id);
+    assert(ent2 != 0);
+    ent2->m_location.m_loc = &test_world->m_gameWorld;
+    ent2->m_location.m_pos = Point3D(0,0,0);
+    test_world->addEntity(ent2);
+
+    Tick tick;
+    tick->setFutureSeconds(0);
+    tick->setTo(ent2->getId());
+    test_world->message(tick, *ent2);
+
+    test_world->getOperationFromQueue();
+}
+
+void WorldRoutertest::test_spawnNewEntity_unknown()
+{
+    LocatedEntity * ent3 = test_world->spawnNewEntity("__no_spawn__",
+                                                      "thing",
+                                                      Anonymous());
+    assert(ent3 == 0);
+}
+
+void WorldRoutertest::test_spawnNewEntity_thing()
+{
+    LocatedEntity * ent3 = test_world->spawnNewEntity("bob",
+                                                      "thing",
+                                                      Anonymous());
+    assert(ent3 == 0);
+}
+
+void WorldRoutertest::test_createSpawnPoint()
+{
+    std::string id;
+    long int_id = newId(id);
+
+    Entity * ent2 = new Entity(id, int_id);
+    assert(ent2 != 0);
+    ent2->m_location.m_loc = &test_world->m_gameWorld;
+    ent2->m_location.m_pos = Point3D(0,0,0);
+    test_world->addEntity(ent2);
+
+    {
+        int ret;
+
+        Atlas::Message::MapType spawn_data;
+        ret = test_world->createSpawnPoint(spawn_data, ent2);
+        assert(ret == -1);
+
+        spawn_data["name"] = 1;
+        ret = test_world->createSpawnPoint(spawn_data, ent2);
+        assert(ret == -1);
+
+        spawn_data["name"] = "bob";
+        ret = test_world->createSpawnPoint(spawn_data, ent2);
+        assert(ret == 0);
+
+        ret = test_world->createSpawnPoint(spawn_data, ent2);
+        assert(ret == 0);
+    }
+
+    {
+        Atlas::Message::ListType spawn_repr;
+        test_world->getSpawnList(spawn_repr);
+        assert(!spawn_repr.empty());
+        assert(spawn_repr.size() == 1u);
+    }
+
+    LocatedEntity * ent3 = test_world->spawnNewEntity("bob",
+                                                      "permitted_non_existant",
+                                                      Anonymous());
+    assert(ent3 == 0);
+
+    ent3 = test_world->spawnNewEntity("bob",
+                                      "thing",
+                                      Anonymous());
+    assert(ent3 != 0);
+}
+
+void WorldRoutertest::test_delEntity()
+{
+    std::string id;
+    long int_id = newId(id);
+
+    Entity * ent2 = new Entity(id, int_id);
+    assert(ent2 != 0);
+    ent2->m_location.m_loc = &test_world->m_gameWorld;
+    ent2->m_location.m_pos = Point3D(0,0,0);
+    test_world->addEntity(ent2);
+
+    test_world->delEntity(ent2);
+    test_world->delEntity(&test_world->m_gameWorld);
+}
+
+void WorldRoutertest::test_delEntity_world()
+{
+    test_world->delEntity(&test_world->m_gameWorld);
+}
 
 int main()
 {
-    {
-        new TestWorldRouter;
-    }
+    WorldRoutertest t;
 
-    {
-        TestWorldRouter * test_world = new TestWorldRouter;
-        delete test_world;
-    }
-
-    {
-        TestWorldRouter * test_world = new TestWorldRouter;
-
-        Entity * ent1 = test_world->addNewEntity("__no_such_type__", Anonymous());
-        assert(ent1 == 0);
-
-        delete test_world;
-    }
-
-    {
-        TestWorldRouter * test_world = new TestWorldRouter;
-
-        Entity * ent1 = test_world->addNewEntity("thing", Anonymous());
-        assert(ent1 != 0);
-
-        delete test_world;
-    }
-
-
-    {
-        TestWorldRouter * test_world = new TestWorldRouter;
-        stub_deny_newid = true;
-
-        Entity * ent1 = test_world->addNewEntity("thing", Anonymous());
-        assert(ent1 == 0);
-
-        stub_deny_newid = false;
-
-        delete test_world;
-    }
-
-    {
-        TestWorldRouter * test_world = new TestWorldRouter;
-
-        std::string id;
-        long int_id = newId(id);
-
-        Entity * ent2 = new Entity(id, int_id);
-        assert(ent2 != 0);
-        ent2->m_location.m_loc = &test_world->m_gameWorld;
-        ent2->m_location.m_pos = Point3D(0,0,0);
-        test_world->addEntity(ent2);
-
-        delete test_world;
-    }
-
-    {
-        TestWorldRouter * test_world = new TestWorldRouter;
-        test_world->test_getOperationFromQueue();
-        delete test_world;
-    }
-
-
-    {
-        TestWorldRouter * test_world = new TestWorldRouter;
-
-        std::string id;
-        long int_id = newId(id);
-
-        Entity * ent2 = new Entity(id, int_id);
-        assert(ent2 != 0);
-        ent2->m_location.m_loc = &test_world->m_gameWorld;
-        ent2->m_location.m_pos = Point3D(0,0,0);
-        test_world->addEntity(ent2);
-
-        Tick tick;
-        tick->setFutureSeconds(0);
-        tick->setTo(ent2->getId());
-        test_world->message(tick, *ent2);
-
-        delete test_world;
-    }
-
-
-    {
-        TestWorldRouter * test_world = new TestWorldRouter;
-
-        std::string id;
-        long int_id = newId(id);
-
-        Entity * ent2 = new Entity(id, int_id);
-        assert(ent2 != 0);
-        ent2->m_location.m_loc = &test_world->m_gameWorld;
-        ent2->m_location.m_pos = Point3D(0,0,0);
-        test_world->addEntity(ent2);
-
-        Tick tick;
-        tick->setFutureSeconds(0);
-        tick->setTo(ent2->getId());
-        test_world->message(tick, *ent2);
-
-        test_world->test_getOperationFromQueue();
-        delete test_world;
-    }
-
-    {
-        TestWorldRouter * test_world = new TestWorldRouter;
-
-        Entity * ent3 = test_world->spawnNewEntity("__no_spawn__",
-                                                   "thing",
-                                                   Anonymous());
-        assert(ent3 == 0);
-
-        delete test_world;
-    }
-
-    {
-        TestWorldRouter * test_world = new TestWorldRouter;
-        Entity * ent3 = test_world->spawnNewEntity("bob",
-                                                   "thing",
-                                                   Anonymous());
-        assert(ent3 == 0);
-        delete test_world;
-    }
-
-
-    {
-        TestWorldRouter * test_world = new TestWorldRouter;
-
-        std::string id;
-        long int_id = newId(id);
-
-        Entity * ent2 = new Entity(id, int_id);
-        assert(ent2 != 0);
-        ent2->m_location.m_loc = &test_world->m_gameWorld;
-        ent2->m_location.m_pos = Point3D(0,0,0);
-        test_world->addEntity(ent2);
-
-        {
-            int ret;
-
-            Atlas::Message::MapType spawn_data;
-            ret = test_world->createSpawnPoint(spawn_data, ent2);
-            assert(ret == -1);
-
-            spawn_data["name"] = 1;
-            ret = test_world->createSpawnPoint(spawn_data, ent2);
-            assert(ret == -1);
-
-            spawn_data["name"] = "bob";
-            ret = test_world->createSpawnPoint(spawn_data, ent2);
-            assert(ret == 0);
-
-            ret = test_world->createSpawnPoint(spawn_data, ent2);
-            assert(ret == 0);
-        }
-
-        {
-            Atlas::Message::ListType spawn_repr;
-            test_world->getSpawnList(spawn_repr);
-            assert(!spawn_repr.empty());
-        }
-
-        Entity * ent3 = test_world->spawnNewEntity("bob",
-                                          "permitted_non_existant",
-                                          Anonymous());
-        assert(ent3 == 0);
-
-        ent3 = test_world->spawnNewEntity("bob",
-                                          "thing",
-                                          Anonymous());
-        assert(ent3 != 0);
-
-    }
-
-    {
-        TestWorldRouter * test_world = new TestWorldRouter;
-
-        std::string id;
-        long int_id = newId(id);
-
-        Entity * ent2 = new Entity(id, int_id);
-        assert(ent2 != 0);
-        ent2->m_location.m_loc = &test_world->m_gameWorld;
-        ent2->m_location.m_pos = Point3D(0,0,0);
-        test_world->addEntity(ent2);
-
-        test_world->test_delEntity(ent2);
-        test_world->test_delEntity(&test_world->m_gameWorld);
-
-        delete test_world;
-    }
-
-    {
-        TestWorldRouter * test_world = new TestWorldRouter;
-
-        test_world->test_delEntity(&test_world->m_gameWorld);
-
-        delete test_world;
-    }
-
-    return 0;
+    return t.run();
 }
 
 // Stubs
@@ -289,7 +298,7 @@ namespace Atlas { namespace Objects { namespace Operation {
 int TICK_NO = -1;
 }}}
 
-World::World(const std::string & id, long intId) : World_parent(id, intId)
+World::World(const std::string & id, long intId) : Thing(id, intId)
 {
 }
 
@@ -313,8 +322,12 @@ void World::DeleteOperation(const Operation & op, OpVector & res)
 {
 }
 
+void World::RelayOperation(const Operation & op, OpVector &)
+{
+}
+
 Thing::Thing(const std::string & id, long intId) :
-       Thing_parent(id, intId)
+       Entity(id, intId)
 {
 }
 
@@ -347,7 +360,7 @@ void Thing::UpdateOperation(const Operation & op, OpVector & res)
 }
 
 Entity::Entity(const std::string & id, long intId) :
-        LocatedEntity(id, intId), m_motion(0), m_flags(0)
+        LocatedEntity(id, intId), m_motion(0)
 {
 }
 
@@ -483,7 +496,11 @@ void Entity::WieldOperation(const Operation &, OpVector &)
 {
 }
 
-void Entity::externalOperation(const Operation & op)
+void Entity::RelayOperation(const Operation &, OpVector &)
+{
+}
+
+void Entity::externalOperation(const Operation & op, Link &)
 {
 }
 
@@ -510,7 +527,26 @@ const PropertyBase * Entity::getProperty(const std::string & name) const
     return 0;
 }
 
-void Entity::onContainered()
+PropertyBase * Entity::modProperty(const std::string & name)
+{
+    return 0;
+}
+
+PropertyBase * Entity::setProperty(const std::string & name,
+                                   PropertyBase * prop)
+{
+    return 0;
+}
+
+void Entity::installDelegate(int class_no, const std::string & delegate)
+{
+}
+
+void Entity::sendWorld(const Operation & op)
+{
+}
+
+void Entity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -521,12 +557,17 @@ void Entity::onUpdated()
 LocatedEntity::LocatedEntity(const std::string & id, long intId) :
                Router(id, intId),
                m_refCount(0), m_seq(0),
-               m_script(0), m_type(0), m_contains(0)
+               m_script(0), m_type(0), m_flags(0), m_contains(0)
 {
 }
 
 LocatedEntity::~LocatedEntity()
 {
+    // Necessary to avoid memory leaks
+    if (m_location.m_loc != 0) {
+        m_location.m_loc->decRef();
+    }
+    delete m_contains;
 }
 
 void LocatedEntity::makeContainer()
@@ -565,7 +606,35 @@ const PropertyBase * LocatedEntity::getProperty(const std::string & name) const
     return 0;
 }
 
-void LocatedEntity::onContainered()
+PropertyBase * LocatedEntity::modProperty(const std::string & name)
+{
+    return 0;
+}
+
+PropertyBase * LocatedEntity::setProperty(const std::string & name,
+                                          PropertyBase * prop)
+{
+    return 0;
+}
+
+void LocatedEntity::installDelegate(int, const std::string &)
+{
+}
+
+void LocatedEntity::destroy()
+{
+}
+
+Domain * LocatedEntity::getMovementDomain()
+{
+    return 0;
+}
+
+void LocatedEntity::sendWorld(const Operation & op)
+{
+}
+
+void LocatedEntity::onContainered(const LocatedEntity*)
 {
 }
 
@@ -680,7 +749,7 @@ float squareDistance(const Location & self, const Location & other)
     return sqrMag(dist);
 }
 
-static long idGenerator = 0;
+static long idGenerator = 2;
 
 long newId(std::string & id)
 {
@@ -695,7 +764,7 @@ long newId(std::string & id)
     return new_id;
 }
 
-BaseWorld::BaseWorld(Entity & gw) : m_gameWorld(gw)
+BaseWorld::BaseWorld(LocatedEntity & gw) : m_gameWorld(gw)
 {
 }
 
@@ -703,7 +772,7 @@ BaseWorld::~BaseWorld()
 {
 }
 
-Entity * BaseWorld::getEntity(const std::string & id) const
+LocatedEntity * BaseWorld::getEntity(const std::string & id) const
 {
     long intId = integerId(id);
 
@@ -716,7 +785,7 @@ Entity * BaseWorld::getEntity(const std::string & id) const
     }
 }
 
-Entity * BaseWorld::getEntity(long id) const
+LocatedEntity * BaseWorld::getEntity(long id) const
 {
     EntityDict::const_iterator I = m_eobjects.find(id);
     if (I != m_eobjects.end()) {
@@ -792,6 +861,7 @@ Monitors * Monitors::instance()
 
 void Monitors::watch(const::std::string & name, VariableBase * monitor)
 {
+    delete monitor;
 }
 
 ArithmeticBuilder * ArithmeticBuilder::m_instance = 0;
@@ -802,7 +872,7 @@ ArithmeticBuilder * ArithmeticBuilder::instance()
 }
 
 ArithmeticScript * ArithmeticBuilder::newArithmetic(const std::string &,
-                                                    Entity *)
+                                                    LocatedEntity *)
 {
     return 0;
 }
@@ -817,10 +887,10 @@ EntityBuilder::~EntityBuilder()
 {
 }
 
-Entity * EntityBuilder::newEntity(const std::string & id, long intId,
-                                  const std::string & type,
-                                  const RootEntity & attributes,
-                                  const BaseWorld & world) const
+LocatedEntity * EntityBuilder::newEntity(const std::string & id, long intId,
+                                         const std::string & type,
+                                         const RootEntity & attributes,
+                                         const BaseWorld & world) const
 {
     if (type == "thing") {
         Entity * e = new Entity(id, intId);
@@ -844,10 +914,15 @@ Task * EntityBuilder::activateTask(const std::string & tool,
     return 0;
 }
 
-SpawnEntity::SpawnEntity(Entity * e, const MapType & data)
+SpawnEntity::SpawnEntity(LocatedEntity *)
 {
 }
 
+int SpawnEntity::setup(const MapType &)
+{
+    return 0;
+}
+
 int SpawnEntity::spawnEntity(const std::string & type,
                              const RootEntity & dsc)
 {
@@ -857,7 +932,7 @@ int SpawnEntity::spawnEntity(const std::string & type,
     return -1;
 }
 
-int SpawnEntity::populateEntity(Entity * ent,
+int SpawnEntity::populateEntity(LocatedEntity * ent,
                                 const RootEntity & dsc,
                                 OpVector & res)
 {
