@@ -15,7 +15,6 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: bb9962b56186eac4f5312915715391875155264a $
 
 #include "OperationMonitor.h"
 
@@ -24,6 +23,10 @@
 
 #include <iostream>
 
+OperationMonitor::~OperationMonitor()
+{
+}
+
 void OperationMonitor::setup(const std::string & arg, OpVector &)
 {
     start_time.update();
@@ -33,7 +36,8 @@ void OperationMonitor::setup(const std::string & arg, OpVector &)
     m_description = "monitoring";
 }
 
-void OperationMonitor::operation(const Operation & op, OpVector &) {
+void OperationMonitor::operation(const Operation & op, OpVector &)
+{
     ++op_count;
     std::cout << op->getParents().front() << "(from=\"" << op->getFrom()
               << "\",to=\"" << op->getTo() << "\")"
